@@ -54,7 +54,6 @@ public:
                     << dir.filePath("dde-trash.desktop")
                     << dir.filePath("dde-computer.desktop");
 
-        m_desktopSettings = new DGioSettings("com.deepin.dde.filemanager.desktop", "/com/deepin/dde/filemanager/desktop/");
         autoArrange = Config::instance()->getConfig(Config::groupGeneral, Config::keyAutoAlign).toBool();
 #ifdef ENABLE_AUTOMERGE  //sp2需求调整，屏蔽自动整理
         autoMerge = Config::instance()->getConfig(Config::groupGeneral, Config::keyAutoMerge, false).toBool();
@@ -782,6 +781,8 @@ void GridManager::initGridItemsInfos()
 #endif
         delaySyncAllProfile();
     }
+    //fixbug81490 栅格数据更新完成后，需要更新扩展显示图标的区域
+    emit sigSyncOperation(soExpandItemUpdate);
 }
 
 void GridManager::initAutoMerge(const QList<DAbstractFileInfoPointer> &items)
@@ -1372,6 +1373,11 @@ QPair<int, QPoint> GridManager::forwardFindEmpty(int screenNum, QPoint start) co
     return d->takeEmptyPos();
 }
 
+QList<int> GridManager::allScreenNum()
+{
+    return d->screensCoordInfo.keys();
+}
+
 QSize GridManager::gridSize(int screenNum) const
 {
     auto coordInfo = d->screensCoordInfo.value(screenNum);
@@ -1496,7 +1502,7 @@ void GridManager::delaySyncAllProfile(int ms)
 
     syncTimer = new QTimer;
     syncTimer->setSingleShot(true);
-    connect(syncTimer, &QTimer::timeout, [ = ]() {
+    connect(syncTimer, &QTimer::timeout, this, [ = ]() {
         syncTimer->stop();
         d->syncAllProfile();
     });
