@@ -184,27 +184,10 @@ void BackgroundManager::init()
 
 void BackgroundManager::pullImageSettings()
 {
-    QString defaultPath = getDefaultBackground();
     m_backgroundImagePath.clear();
-    if (wmInter) {
-        for (ScreenPointer sc : ScreenMrg->logicScreens()) {
-//            QString path = wmInter->GetCurrentWorkspaceBackground();//GetCurrentWorkspaceBackgroundForMonitor(sc->name());
-            QString path = wmInter->GetCurrentWorkspaceBackgroundForMonitor(sc->name());//wm 新接口获取屏幕壁纸
-            qDebug() << "pullImageSettings GetCurrentWorkspaceBackgroundForMonitor path :" << path << "screen" << sc->name();
-            if (path.isEmpty() || !QFile::exists(QUrl(path).toLocalFile())) {
-                qCritical() << "get background fail path :" << path << "screen" << sc->name();
-
-                path = getBackgroundFromWmConfig(sc->name());
-                if (path.isEmpty() || !QFile::exists(QUrl(path).toLocalFile())) {
-                    qCritical() << "get background fail from wm config file path :" << path << "screen" << sc->name();
-                    if (defaultPath.isEmpty())
-                        continue;
-                    path = defaultPath;
-                }
-            }
-            qInfo() << "screen" << sc->name() << "set background " << path;
-            m_backgroundImagePath.insert(sc->name(), path);
-        }
+    for (ScreenPointer sc : ScreenMrg->logicScreens()) {
+        QString path = getBackgroundFromWm(sc->name());
+        m_backgroundImagePath.insert(sc->name(), path);
     }
 }
 
@@ -212,24 +195,51 @@ QString BackgroundManager::getBackgroundFromWm(const QString &screen)
 {
     QString ret;
     if (!screen.isEmpty() && wmInter) {
-//        QString path = wmInter->GetCurrentWorkspaceBackground();//GetCurrentWorkspaceBackgroundForMonitor(screen);
-        QString path = wmInter->GetCurrentWorkspaceBackgroundForMonitor(screen);//wm 新接口获取屏幕壁纸
-        if (path.isEmpty() || !QFile::exists(QUrl(path).toLocalFile())) {
-            path = getBackgroundFromWmConfig(screen);
-            if (path.isEmpty() || !QFile::exists(QUrl(path).toLocalFile())) {
+
+        // 1.从窗管获取壁纸
+        int retry = 5;
+        static const int timeOut = 200;
+        int oldTimeOut = wmInter->timeout();
+        wmInter->setTimeout(timeOut);
+
+        while (retry--) {
+            qInfo() << "Get background by wm GetCurrentWorkspaceBackgroundForMonitor and sc:" << screen;
+            QDBusPendingReply<QString> reply = wmInter->GetCurrentWorkspaceBackgroundForMonitor(screen);
+            reply.waitForFinished();
+
+            if (reply.error().type() != QDBusError::NoError) {
+                qWarning() << "Get background failed by wmDBus and times:" << (5-retry)
+                           << reply.error().type() << reply.error().name() << reply.error().message();
+            } else {
+                ret = reply.argumentAt<0>();
+                qInfo() << "Get background path succeed:" << ret << "screen" << screen << "   times:" << (5 - retry);
+                break;
+            }
+        }
+        wmInter->setTimeout(oldTimeOut);
+
+        if (ret.isEmpty() || !QFile::exists(QUrl(ret).toLocalFile())) {
+
+            // 2.从配置文件解析壁纸
+            ret = getBackgroundFromWmConfig(screen);
+            if (ret.isEmpty() || !QFile::exists(QUrl(ret).toLocalFile())) {
+
+                // 3.使用默认壁纸
                 ret = getDefaultBackground();
-                qCritical() << "get background fail path :" << path << "screen" << screen
+                qCritical() << "get background fail path :" << ret << "screen" << screen
                             << "use default:" << ret;
             } else {
-                ret = path;
-                qCritical() << "get background fail path :" << path << "screen" << screen
+                qCritical() << "get background fail path :" << ret << "screen" << screen
                             << "use wm config file:" << ret;
             }
         } else {
-            qInfo() << "getBackgroundFromWm GetCurrentWorkspaceBackgroundForMonitor path :" << path << "screen" << screen;
-            ret = path;
+            qInfo() << "getBackgroundFromWm GetCurrentWorkspaceBackgroundForMonitor path :" << ret << "screen" << screen;
+            m_wmInited = true;
         }
+    } else {
+        qInfo() << "Get background path terminated screen:" << screen << wmInter;
     }
+
     return ret;
 }
 
@@ -350,9 +360,6 @@ void BackgroundManager::onBackgroundBuild()
     AbstractScreenManager::DisplayMode mode = ScreenMrg->lastChangedMode();
     qInfo() << "screen mode" << mode << "screen count" << ScreenMrg->screens().size();
 
-    //删除不存在的屏
-    m_backgroundMap.clear();
-
     //实际是单屏
     if ((AbstractScreenManager::Showonly == mode) || (AbstractScreenManager::Duplicate == mode) //仅显示和复制
             || (ScreenMrg->screens().count() == 1)) {  //单屏模式
@@ -366,7 +373,15 @@ void BackgroundManager::onBackgroundBuild()
             return;
         }
 
-        BackgroundWidgetPointer bwp = createBackgroundWidget(primary);
+        BackgroundWidgetPointer bwp = m_backgroundMap.value(primary);
+        m_backgroundMap.clear();
+        if (!bwp.isNull()) {
+            if (bwp->geometry() != primary->geometry())
+                bwp->setGeometry(primary->geometry());
+        } else {
+            bwp = createBackgroundWidget(primary);
+        }
+
         m_backgroundMap.insert(primary, bwp);
 
         //设置壁纸
@@ -377,9 +392,23 @@ void BackgroundManager::onBackgroundBuild()
         else
             qWarning() << "Disable show the background widget, of screen:" << primary->name() << primary->geometry();
     } else { //多屏
-        for (ScreenPointer sc : ScreenMrg->logicScreens()) {
-            BackgroundWidgetPointer bwp = createBackgroundWidget(sc);
-            m_backgroundMap.insert(sc, bwp);
+        auto screes = ScreenMrg->logicScreens();
+        for (auto sp : m_backgroundMap.keys()) {
+            if (!screes.contains(sp)) {
+                auto rmd = m_backgroundMap.take(sp);
+                qInfo() << "screen:" << rmd->property("myScreen") << "is invalid, delete it.";
+            }
+        }
+        for (ScreenPointer sc : screes) {
+            BackgroundWidgetPointer bwp = m_backgroundMap.value(sc);
+            if (!bwp.isNull()) {
+                if (bwp->geometry() != sc->geometry())
+                    bwp->setGeometry(sc->geometry());
+            } else {
+                qInfo() << "screen:" << sc->name() << "  added, create it.";
+                bwp = createBackgroundWidget(sc);
+                m_backgroundMap.insert(sc, bwp);
+            }
 
             if (m_visible)
                 bwp->show();
@@ -468,8 +497,12 @@ void BackgroundManager::onWmDbusStarted(QString name, QString oldOwner, QString
     Q_UNUSED(newOwner)
     //窗管服务注销也会进入该函数，因此需要判断服务是否已注册
     if (name == QString("com.deepin.wm") && QDBusConnection::sessionBus().interface()->isServiceRegistered("com.deepin.wm")) {
-        qInfo() << "dbus server com.deepin.wm started.";
-        pullImageSettings();
-        onResetBackgroundImage();
+        qInfo() << "dbus server com.deepin.wm started." << m_wmInited;
+        if (!m_wmInited) {
+            pullImageSettings();
+            onResetBackgroundImage();
+        }
+        m_wmInited = true;
+        QDBusConnection::sessionBus().disconnect("org.freedesktop.DBus", "/org/freedesktop/DBus", "org.freedesktop.DBus",  "NameOwnerChanged", this, SLOT(onWmDbusStarted(QString, QString, QString)));
     }
 }
