@@ -109,6 +109,7 @@ public:
 #if QT_CONFIG(draganddrop)
     virtual void startDrag(Qt::DropActions supportedActions) override;
 #endif
+    QPixmap renderToPixmap(const QModelIndexList &indexes) const;
     QString canvansScreenName() const;
     QRect rectForIndex(const QModelIndex &index) const;
     DUrl currentUrl() const;
@@ -117,6 +118,7 @@ public:
     bool setRootUrl(const DUrl &url);
     const DUrlList autoMergeSelectedUrls() const;
     const DUrlList selectedUrls() const;
+    void viewSelectedUrls(DUrlList &validSel, QModelIndexList &validIndexes);
     void setScreenNum(int num);
     void setScreenName(const QString &name);
     inline QString screenName() const {return m_screenName;}
@@ -147,6 +149,7 @@ public:
     inline int screenNum() const {return m_screenNum;}
     void syncIconLevel(int level);
     void updateHiddenItems();
+    void updateExpandItemGeometry();
 signals:
     void sortRoleChanged(int role, Qt::SortOrder order);
     void autoAlignToggled();
@@ -229,6 +232,7 @@ private:
     QTime m_rt; //刷新计时，可以删除
 
     DUrl m_currentTargetUrl; //缓存当前目标Url
+    int m_paintingLog = 3;
 };
 
 
