@@ -165,11 +165,9 @@ void DiskControlWidget::doStartupAutoMount()
     for (const QString &blDevStr : blDevList) {
         QScopedPointer<DBlockDevice> blDev(DDiskManager::createBlockDevice(blDevStr));
 
-        if (DiskGlobal::isWayLand() && blDevStr.contains(QRegularExpression("/sd[a-c][1-9]*$"))) {
-            continue;
-        }
-
         if (blDev->isEncrypted()) continue;
+        // 已经解锁一次的加密盘，在重新挂载时就不需要秘钥了，如果这时重启dock就会自动挂载上，所以这里扔需要排除加密明文设备
+        if (blDev->cryptoBackingDevice().length() > 1) continue;
         if (blDev->hintIgnore()) continue;
 
         QList<QByteArray> mountPoints = blDev->mountPoints();
@@ -213,8 +211,8 @@ void DiskControlWidget::popQueryScanningDialog(QObject *object, std::function<vo
     Qt::WindowFlags flags = d->windowFlags();
     d->setWindowFlags(flags | Qt::CustomizeWindowHint | Qt::WindowStaysOnTopHint);
     d->setIcon(QIcon::fromTheme("dialog-warning"));
-    d->addButton(QObject::tr("Cancel"));
-    d->addButton(QObject::tr("Stop"), true, DDialog::ButtonWarning); // 终止
+    d->addButton(QObject::tr("Cancel","button"));
+    d->addButton(QObject::tr("Stop","button"), true, DDialog::ButtonWarning); // 终止
     d->setMaximumWidth(640);
     d->show();
 
@@ -551,6 +549,8 @@ void DiskControlWidget::onBlockDeviceAdded(const QString &path)
     // 以下皆是以前的逻辑
     if (isProtectedDevice(blkDev.data())) return;
     if (blkDev->isEncrypted()) return;
+    // 加密盘解锁后 dock先挂载 会触发文管挂载时提示重复挂载 bugid: 77010
+    if (blkDev->cryptoBackingDevice().length() > 1) return;
     if (blkDev->hintIgnore()) return;
     if (!blkDev->hasFileSystem()) return;
 
