@@ -39,12 +39,14 @@
 #include "networkcontroller.h"
 #include "mergeddesktopcontroller.h"
 #include "dfmrootcontroller.h"
+#include "dfmappentrycontroller.h"
 #include "deviceinfo/udisklistener.h"
 #include "dfileservices.h"
 #include "fileoperations/filejob.h"
 #include "dfmeventdispatcher.h"
 #include "dfmapplication.h"
 #include "disomaster.h"
+#include "pathmanager.h"
 
 #include "app/filesignalmanager.h"
 #include "dfmevent.h"
@@ -70,6 +72,7 @@
 #include "recentcontroller.h"
 #include "views/drenamebar.h"
 #include "shutil/filebatchprocess.h"
+#include "utils.h"
 
 #include "../deviceinfo/udisklistener.h"
 
@@ -140,7 +143,7 @@ void AppController::registerUrlHandle()
     DFileService::dRegisterUrlHandler<FileController>(FILE_SCHEME, "");
     //    DFileService::dRegisterUrlHandler<TrashManager>(TRASH_SCHEME, "");
     //sanitinizer工具检测到DFileService::setFileUrlHandler(TRASH_SCHEME, "", new TrashManager());泄露
-    auto *tempTrashMgr = new TrashManager();
+    auto tempTrashMgr = new TrashManager();
     tempTrashMgr->setObjectName("trashMgr");
     DFileService::setFileUrlHandler(TRASH_SCHEME, "", tempTrashMgr);
     DFileService::dRegisterUrlHandler<SearchController>(SEARCH_SCHEME, "");
@@ -159,6 +162,7 @@ void AppController::registerUrlHandle()
     DFileService::dRegisterUrlHandler<MergedDesktopController>(DFMMD_SCHEME, "");
     DFileService::dRegisterUrlHandler<DFMRootController>(DFMROOT_SCHEME, "");
     DFileService::dRegisterUrlHandler<VaultController>(DFMVAULT_SCHEME, "");
+    DFileService::dRegisterUrlHandler<DFMAppEntryController>(APPENTRY_SCHEME, "");
 }
 
 void AppController::actionOpen(const QSharedPointer<DFMUrlListBaseEvent> &event, const bool isEnter)
@@ -441,7 +445,21 @@ void AppController::actionDelete(const QSharedPointer<DFMUrlListBaseEvent> &even
 
 void AppController::actionCompleteDeletion(const QSharedPointer<DFMUrlListBaseEvent> &event)
 {
-    fileService->deleteFiles(event->sender(), event->urlList());
+    auto &&list = event->urlList();
+    if (list.isEmpty())
+        return;
+
+    auto sender { event->sender() };
+    foreach (const DUrl &url, list) {
+        if (systemPathManager->isSystemPath(url.toLocalFile())) {
+            DThreadUtil::runInMainThread(dialogManager, &DialogManager::showDeleteSystemPathWarnDialog, DFMEvent::windowIdByQObject(sender));
+            return;
+        }
+    }
+
+    bool slient { false };
+    bool force { false };
+    DFMEventDispatcher::instance()->processEventAsync(dMakeEventPointer<DFMDeleteEvent>(sender, list, slient, force));
 }
 
 void AppController::actionCreateSymlink(const QSharedPointer<DFMUrlBaseEvent> &event)
@@ -549,6 +567,15 @@ void AppController::actionMount(const QSharedPointer<DFMUrlBaseEvent> &event)
     const DUrl &fileUrl = event->url();
 
     if (fileUrl.scheme() == DFMROOT_SCHEME) {
+        auto path = fileUrl.path();
+        // mount the stashed remote connections
+        if (path.endsWith(SUFFIX_STASHED_REMOTE)) {
+            path = RemoteMountsStashManager::normalizeConnUrl(path);
+            auto e = dMakeEventPointer<DFMUrlBaseEvent>(event->sender(), path);
+            GvfsMountManager::instance()->mount_sync(*e);
+            return;
+        }
+
         DAbstractFileInfoPointer fi = fileService->createFileInfo(event->sender(), fileUrl);
         QScopedPointer<DBlockDevice> blk(DDiskManager::createBlockDevice(fi->extraProperties()["udisksblk"].toString()));
         QScopedPointer<DDiskDevice> drv(DDiskManager::createDiskDevice(blk->drive()));
@@ -574,6 +601,10 @@ void AppController::actionMount(const QSharedPointer<DFMUrlBaseEvent> &event)
         const QSharedPointer<DFMUrlBaseEvent> &e = dMakeEventPointer<DFMUrlBaseEvent>(event->sender(), q);
         actionMount(e);
         return;
+    } else if (fileUrl.scheme() == APPENTRY_SCHEME) {
+        auto e = dMakeEventPointer<DFMUrlListBaseEvent>(event->sender(), DUrlList() << fileUrl);
+        actionOpen(e);
+        return;
     }
 
     QStringList deviceNode = DDiskManager::resolveDeviceNode(fileUrl.query(), {});
@@ -667,6 +698,17 @@ void AppController::popQueryScanningDialog(QObject *object, std::function<void()
         onStop();
 }
 
+void AppController::refreshDesktop()
+{
+    static const QString DesktopService = "com.deepin.dde.desktop";
+    static const QString DesktopPath = "/com/deepin/dde/desktop";
+    DesktopInterface desktop(DesktopService,
+                            DesktopPath,
+                            QDBusConnection::sessionBus(),
+                            this);
+    desktop.asyncCallWithArgumentList(QStringLiteral("Refresh"), QList<QVariant>());
+}
+
 void AppController::actionUnmount(const QSharedPointer<DFMUrlBaseEvent> &event)
 {
     const DUrl &fileUrl = event->url();
@@ -1066,13 +1108,40 @@ void AppController::actionOpticalBlank(const QSharedPointer<DFMUrlBaseEvent> &ev
 
             DUrl dev(event->url());
 
-            job->doOpticalBlank(dev);
+            job->doDiscBlank(dev);
             dialogManager->removeJob(job->getJobId());
             //job->deleteLater();
         });
     }
 }
 
+void AppController::actionRemoveStashedMount(const QSharedPointer<DFMUrlBaseEvent> &event)
+{
+    auto path = event->url().path(); // something like "/smb://1.2.3.4/shared-folder.remote"
+    path = RemoteMountsStashManager::normalizeConnUrl(path);
+    // then find the stashed key of it.
+    const auto &&stashedRemoteMounts = RemoteMountsStashManager::remoteMounts();
+    QString key;
+    for (const auto &mount: stashedRemoteMounts) {
+        auto protocol = mount.value(REMOTE_PROTOCOL).toString();
+        auto host = mount.value(REMOTE_HOST).toString();
+        auto share = mount.value(REMOTE_SHARE).toString();
+        if (protocol.isEmpty() || host.isEmpty()) {
+            qWarning() << "protocol or host is empty: " << mount;
+            continue;
+        }
+
+        QString connPath = QString("%1://%2/%3").arg(protocol).arg(host).arg(share);
+        if (connPath == path) {
+            key = mount.value(REMOTE_KEY).toString();
+            break;
+        }
+    }
+    if (!key.isEmpty()) {
+        RemoteMountsStashManager::removeRemoteMountItem(key);
+    }
+}
+
 void AppController::actionctrlL(quint64 winId)
 {
     emit fileSignalManager->requestSearchCtrlL(winId);
@@ -1123,30 +1192,6 @@ void AppController::actionForgetPassword(const QSharedPointer<DFMUrlBaseEvent> &
         path = QUrl(fi->extraProperties()["rooturi"].toString()).toString();
     }
     QJsonObject smbObj = secretManager->getLoginData(path);
-    if (smbObj.empty()) {
-        if (path.endsWith("/")) {
-            path = path.left(path.length() - 1);
-            smbObj = secretManager->getLoginData(path);
-
-            if (smbObj.isEmpty()) {
-                QString share = path.split("/").last();
-                path = path.left(path.length() - share.length());
-                path += share.toUpper();
-                smbObj = secretManager->getLoginData(path);
-            }
-        } else {
-            path += "/";
-            smbObj = secretManager->getLoginData(path);
-            if (smbObj.isEmpty()) {
-                QStringList _pl = path.split("/");
-                QString share = _pl.at(_pl.length() - 2);
-                path = path.left(path.length() - share.length() - 1);
-                path += share.toUpper();
-                path += "/";
-                smbObj = secretManager->getLoginData(path);
-            }
-        }
-    }
 
     qDebug() << path << smbObj;
 
@@ -1177,9 +1222,13 @@ void AppController::actionForgetPassword(const QSharedPointer<DFMUrlBaseEvent> &
         obj.insert("domain", smbObj.value("domain").toString());
         obj.insert("protocol", DUrl(smbObj.value("id").toString()).scheme());
         obj.insert("server", server);
+        obj.insert("key", smbObj.value("key").toString());
         secretManager->clearPasswordByLoginObj(obj);
     }
     actionUnmount(event);
+
+    auto stashKey = fi->extraProperties()["backer_url"].toString();
+    RemoteMountsStashManager::removeRemoteMountItem(stashKey);
 }
 
 void AppController::actionOpenFileByApp()
@@ -1458,6 +1507,8 @@ void AppController::initConnect()
     connect(m_unmountWorker, &UnmountWorker::unmountResult, this, &AppController::showErrorDialog);
     connect(this, &AppController::doUnmount, m_unmountWorker, &UnmountWorker::doUnmount);
     connect(this, &AppController::doSaveRemove, m_unmountWorker, &UnmountWorker::doSaveRemove);
+    connect(fileSignalManager, &FileSignalManager::requestFreshAllDesktop,
+                this, &AppController::refreshDesktop);
 
     m_unmountThread.start();
 
@@ -1569,3 +1620,12 @@ void UnmountWorker::doSaveRemove(const QString &blkStr)
     if (!manager.removeDrive(manager.getDriveName(blkStr)))
         emit unmountResult(tr("The device was not safely removed"), manager.getErrorMsg());
 }
+
+DesktopInterface::DesktopInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
+    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
+{
+}
+
+DesktopInterface::~DesktopInterface()
+{
+}
