@@ -33,6 +33,7 @@
 #include "shutil/fileutils.h"
 #include "dfmapplication.h"
 #include "dfmsettings.h"
+#include "utils.h"
 
 #include <dgiofile.h>
 #include <dgiofileinfo.h>
@@ -40,14 +41,11 @@
 #include <dgiovolume.h>
 #include <dgiovolumemanager.h>
 #include <ddiskmanager.h>
-#include <dblockdevice.h>
 #include <ddiskdevice.h>
-
+#include <dblockpartition.h>
 #include "dialogs/dialogmanager.h"
 #include "deviceinfo/udisklistener.h"
-
 #include <gvfs/networkmanager.h>
-
 #include <QProcessEnvironment>
 #include <QJsonDocument>
 #include <QJsonObject>
@@ -78,6 +76,65 @@ private:
     Q_DECLARE_PUBLIC(DFMRootFileWatcher)
 };
 
+static bool ignoreBlkDevice(const QString& blkPath, QSharedPointer<DBlockDevice> blk, QSharedPointer<DDiskDevice> drv)
+{
+    if (blk->hintIgnore()) {
+        qWarning()  << "block device is ignored by hintIgnore:"  << blkPath;
+        return true;
+    }
+
+    bool isOptical = drv->mediaCompatibility().join(",").contains("optical");
+    if (!blk->hasFileSystem() && !isOptical && !blk->isEncrypted()) {
+        if (!drv->removable()){ // 满足外围条件的本地磁盘，直接遵循以前的处理直接 continue
+            qWarning()  << "block device is ignored by wrong removeable set for system disk:"  << blkPath;
+            return true;
+        }
+    }
+
+    if (!blk->hasFileSystem() && blk->size() < 1024 && !isOptical) {   // a super block is at least 1024 bytes, a full filesystem always have a superblock.
+        qWarning() << "block device is ignored cause it's size is less than 1024";
+        return true;
+    }
+
+    if (blk->cryptoBackingDevice().length() > 1) {
+        qWarning()  << "block device is ignored by crypted back device:"  << blkPath;
+        return true;
+    }
+
+    // 是否是设备根节点，设备根节点无须记录
+    if(blk->hasPartitionTable()){ // 替换 FileUtils::deviceShouldBeIgnore
+        qDebug()  << "block device is ignored by parent node:"  << blkPath;
+        return true;
+    }
+
+    // 过滤snap产生的loop设备
+    if(blk->isLoopDevice() && DFMApplication::genericAttribute(DFMApplication::GA_HideLoopPartitions).toBool()){
+        qDebug()  << "block device is ignored by loop device:"  << blkPath;
+        return true;
+    }
+
+    if(blk->hasPartition()){
+        QSharedPointer<DBlockPartition> partition(DDiskManager::createBlockPartition(blkPath));
+        if(!partition.isNull()){
+            DBlockPartition::Type type = partition->eType();
+            switch (type) {
+            //Extended partition with CHS addressing. It must reside within the first physical 8 GB of disk, else use 0Fh instead (see 0Fh, 85h, C5h, D5h)
+            case DBlockPartition::Win95_Extended_LBA:
+            case DBlockPartition::Linux_extended:
+            case DBlockPartition::DRDOS_sec_extend:
+            case DBlockPartition::Multiuser_DOS_extend:
+            case DBlockPartition::Extended:{
+                    qWarning()  << "block device is ignored by partion type:"  << partition->type() <<","<< blkPath;
+                    return true;
+                }
+            default:
+                break;
+            }
+        }
+    }
+    return false;
+}
+
 DFMRootController::DFMRootController(QObject *parent) : DAbstractFileController(parent)
 {
 
@@ -111,6 +168,24 @@ bool DFMRootController::renameFile(const QSharedPointer<DFMRenameEvent> &event)
     return blk->lastError().type() == QDBusError::NoError;
 }
 
+void DFMRootController::reloadBlkName(const QString& blkPath, QSharedPointer<DBlockDevice> blk) const
+{
+    //检查挂载目录下是否存在diskinfo文件
+    QByteArrayList mps = blk->mountPoints();
+    if (mps.empty()) {
+        qWarning()  << "failed to reload block device name for:"  << blkPath;
+        return;
+    }
+    QString mpPath(mps.front());
+    if (mpPath.lastIndexOf("/") != (mpPath.length() - 1))
+        mpPath += "/";
+    QDir kidDir(mpPath + "UOSICON");
+    if (kidDir.exists()) {
+        QString jsonPath = kidDir.absolutePath();
+        loadDiskInfo(jsonPath);
+    }
+}
+
 const QList<DAbstractFileInfoPointer> DFMRootController::getChildren(const QSharedPointer<DFMGetChildrensEvent> &event) const
 {
     QList<DAbstractFileInfoPointer> ret;
@@ -127,41 +202,19 @@ const QList<DAbstractFileInfoPointer> DFMRootController::getChildren(const QShar
         }
     }
 
-    DDiskManager dummy;
-    QStringList blkds = dummy.blockDevices({});
+    QStringList blkds = DDiskManager::blockDevices({});
     for (auto blks : blkds) {
-        QScopedPointer<DBlockDevice> blk(DDiskManager::createBlockDevice(blks));
-        QScopedPointer<DDiskDevice> drv(DDiskManager::createDiskDevice(blk->drive()));
-        if (DFMGlobal::isWayLand() && blks.contains(QRegularExpression("/sd[a-c][1-9]*$"))) {
-            qDebug()  << " blDev->drive()"  << blks << blk->drive();
+        QSharedPointer<DBlockDevice> blk(DDiskManager::createBlockDevice(blks));
+        QSharedPointer<DDiskDevice> drv(DDiskManager::createDiskDevice(blk->drive()));
+        if(ignoreBlkDevice(blks, blk, drv)){
             continue;
         }
 
-        if (!blk->hasFileSystem() && !drv->mediaCompatibility().join(" ").contains("optical") && !blk->isEncrypted()) {
-            if (!drv->removable()) // 满足外围条件的本地磁盘，直接遵循以前的处理直接 continue
-                continue;
+        reloadBlkName(blks, blk);
 
-            if (FileUtils::deviceShouldBeIgnore(blk->device())) // 对于可移动设备，根据设备描述符选择过滤（sp3 需求，异常设备需要显示，以提供格式化入口）
-                continue;
-        }
-
-        //检查挂载目录下是否存在diskinfo文件
-        QByteArrayList mps = blk->mountPoints();
-        if (!mps.empty()) {
-            QString mpPath(mps.front());
-            if (mpPath.lastIndexOf("/") != (mpPath.length() - 1))
-                mpPath += "/";
-            QDir kidDir(mpPath + "UOSICON");
-            if (kidDir.exists()) {
-                QString jsonPath = kidDir.absolutePath();
-                loadDiskInfo(jsonPath);
-            }
-        }
-        if ((blk->hintIgnore() && !blk->isEncrypted()) || blk->cryptoBackingDevice().length() > 1) {
-            continue;
-        }
         using namespace DFM_NAMESPACE;
         if (DFMApplication::genericAttribute(DFMApplication::GA_HiddenSystemPartition).toBool() && blk->hintSystem()) {
+            qDebug()  << "block device is ignored by hintSystem&HiddenSystemPartition:"  << blks;
             continue;
         }
 
@@ -196,8 +249,14 @@ const QList<DAbstractFileInfoPointer> DFMRootController::getChildren(const QShar
         // 在这里的 gvfs 里又显示一次，且数据内容不一致。
         // 因此，在这里通过过滤 /meida/ 目录挂载点的方式，来过滤 udisks2 设备（udisks2 在默认情况下都是挂载磁盘到 /media/$USER/ 目录下）
         // 手动 sudo mount 挂载的设备不会被 Gio 捕获，因此不用考虑手动使用 mount 挂载到 /media 目录下的磁盘被过滤
-        if (rootFile->uri().startsWith("file:///media/"))
-            continue;
+        if (rootFile->uri().startsWith("file:///media/")) {
+            // fix bug 97468
+            // 仅在特殊场景下会触发此代码，因此不影响启动性能
+            // 原 bug 60719 修复会将块设备和协议设备全部跳过，因此造成了协议设备
+            // 挂载到 /media 下后无法在计算机页面显示的问题
+            if (deviceListener->isFromNativeBlockDev(rootFile->path()))
+                continue;
+        }
 
         DUrl url;
         url.setScheme(DFMROOT_SCHEME);
@@ -206,12 +265,57 @@ const QList<DAbstractFileInfoPointer> DFMRootController::getChildren(const QShar
         if (urllist.contains(QString("/" + QUrl::toPercentEncoding(rootFile->path()) + "." SUFFIX_GVFSMP)))
             continue;
         DAbstractFileInfoPointer fp(new DFMRootFileInfo(url));
+        urllist << QString("/" + QUrl::toPercentEncoding(rootFile->path()) + "." SUFFIX_GVFSMP);
         if (fp->exists()) {
-            urllist << QString("/" + QUrl::toPercentEncoding(rootFile->path()) + "." SUFFIX_GVFSMP);
             ret.push_back(fp);
         }
     }
-    qInfo() << "get rootfileinfo over !";
+
+    // get the not connected, storaged remote connection
+    if (DFMApplication::genericAttribute(DFMApplication::GA_AlwaysShowOfflineRemoteConnections).toBool()) {
+        const QList<QVariantMap> &&stashedMounts = RemoteMountsStashManager::remoteMounts();
+        qDebug() << stashedMounts;
+        for (const auto &mount: stashedMounts) {
+            if (!mount.contains(REMOTE_KEY))
+                continue;
+            auto key = mount.value(REMOTE_KEY).toString() + "." + SUFFIX_GVFSMP;
+            auto encodedKey = QUrl::toPercentEncoding(key);
+            encodedKey.prepend("/");
+            qDebug() << encodedKey;
+            if (urllist.contains(encodedKey)) {
+                qDebug() << "stashed mount is mounted" << mount;
+                continue;
+            }
+
+            // ftp sometimes do not have share field
+            if (!(mount.contains(REMOTE_PROTOCOL) && mount.contains(REMOTE_HOST))) {
+                qWarning() << "invalid stashed remote connection: " << mount;
+                continue;
+            }
+            auto protocol = mount.value(REMOTE_PROTOCOL).toString();
+            auto host = mount.value(REMOTE_HOST).toString();
+            auto share = mount.value(REMOTE_SHARE).toString();
+            if (protocol.isEmpty() || host.isEmpty()) {
+                qWarning() << "protocol or host is empty: " << mount;
+                continue;
+            }
+
+            QString path = QString("%1://%2/%3").arg(protocol).arg(host).arg(share);
+            path.append(QString(".%1").arg(SUFFIX_STASHED_REMOTE));
+            path.prepend(DFMROOT_ROOT);
+            qDebug() << "get stashed remote connection: " << path;
+
+            auto stashedMountInfo = new DFMRootFileInfo(DUrl::fromPercentEncoding(path.toUtf8()));
+            DAbstractFileInfoPointer fp(stashedMountInfo);
+            ret.push_back(fp);
+        }
+    }
+
+    qInfo() << "get rootfileinfo over !" << ret;
+    for(auto item: ret) {
+        qInfo() << item->fileUrl();
+    }
+
     return ret;
 }
 
@@ -410,13 +514,28 @@ bool DFMRootFileWatcherPrivate::start()
         // 在这里的 gvfs 里又显示一次，且数据内容不一致。
         // 因此，在这里通过过滤 /meida/ 目录挂载点的方式，来过滤 udisks2 设备（udisks2 在默认情况下都是挂载磁盘到 /media/$USER/ 目录下）
         // 手动 sudo mount 挂载的设备不会被 Gio 捕获，因此不用考虑手动使用 mount 挂载到 /media 目录下的磁盘被过滤
-        if (mnt->getRootFile()->uri().startsWith("file:///media/"))
-            return;
+        if (mnt->getRootFile()->uri().startsWith("file:///media/")) {
+            // fix bug 97468
+            // 仅在特殊场景下会触发此代码，因此不影响启动性能
+            // 原 bug 60719 修复会将块设备和协议设备全部跳过，因此造成了协议设备
+            // 挂载到 /media 下后无法在计算机页面显示的问题
+            if (deviceListener->isFromNativeBlockDev(mnt->getRootFile()->path()))
+                return;
+        }
 
         DUrl url;
         url.setScheme(DFMROOT_SCHEME);
+        QString mountPointPath = mnt->getRootFile()->path();
         url.setPath("/" + QUrl::toPercentEncoding(mnt->getRootFile()->path()) + "." SUFFIX_GVFSMP);
         Q_EMIT wpar->subfileCreated(url);
+        if (FileUtils::isSmbPath(mountPointPath)) {
+            //refresh all dde-file-manager window
+            emit fileSignalManager->requestFreshAllFileView();
+            //refresh dde-desktop
+            emit fileSignalManager->requestFreshAllDesktop();
+
+            emit fileSignalManager->requestShowNewWindows();
+        }
     }));
     connections.push_back(QObject::connect(vfsmgr.data(), &DGioVolumeManager::mountRemoved, [wpar](QExplicitlySharedDataPointer<DGioMount> mnt) {
         if (mnt->getVolume() && mnt->getVolume()->volumeMonitorName().endsWith("UDisks2")) {
@@ -452,13 +571,24 @@ bool DFMRootFileWatcherPrivate::start()
         QString uri = mnt->getRootFile()->uri();
         fileSignalManager->requestRemoveRecentFile(path);
         qDebug() << uri << "mount removed";
+        if (FileUtils::isSmbPath(path)) {
+            emit fileSignalManager->requestFreshAllFileView();
+            emit fileSignalManager->requestFreshAllDesktop();
+        }
         if (uri.contains("smb-share://") || uri.contains("smb://") || uri.contains("ftp://") || uri.contains("sftp://")) {
             // remove NetworkNodes cache, so next time cd uri will fetchNetworks
-            QString smbUri = uri;
+            std::string stdStr = uri.toStdString();
+            QString smbUri = QUrl::fromPercentEncoding(QByteArray(stdStr.data()));
+            qDebug() << smbUri << "mount removed";
             if (smbUri.endsWith("/")) {
                 smbUri = smbUri.left(smbUri.length() - 1);
             }
             DUrl smbUrl(smbUri);
+            DUrlList networkNodesKeys = NetworkManager::NetworkNodes.keys();
+            for (auto networkNodesKey : networkNodesKeys) {
+               if (networkNodesKey.toString().toLower().startsWith(smbUrl.toString().toLower()))
+                    NetworkManager::NetworkNodes.remove(networkNodesKey);
+            }
             NetworkManager::NetworkNodes.remove(smbUrl);
             smbUrl.setPath("");
             NetworkManager::NetworkNodes.remove(smbUrl);
@@ -473,24 +603,10 @@ bool DFMRootFileWatcherPrivate::start()
     }));
     connections.push_back(QObject::connect(udisksmgr.data(), &DDiskManager::blockDeviceAdded, [wpar, this](const QString & blks) {
         QSharedPointer<DBlockDevice> blk(DDiskManager::createBlockDevice(blks));
-        QScopedPointer<DDiskDevice> drv(DDiskManager::createDiskDevice(blk->drive()));
+        QSharedPointer<DDiskDevice> drv(DDiskManager::createDiskDevice(blk->drive()));
 
-        if (!blk->hasFileSystem() && !drv->mediaCompatibility().join(" ").contains("optical") && !blk->isEncrypted()) {
-            if (!drv->removable()) // 对于本地磁盘，直接按照以前的方式，满足外围条件直接 return
-                return;
-
-            if (FileUtils::deviceShouldBeIgnore(blk->device())) // 设备需要被滤去，比如 /dev/sda 下还包含 /dev/sda1 时，需要滤去 sda
-                return;
-
-//            dialogManager->showFormatDialog(blk->device()); // 暂时取消监听设备接入时的格式化提示，只在用户进入不可读取的磁盘时提示格式化
-        }
-
-        if ((blk->hintIgnore() && !blk->isEncrypted()) || blk->cryptoBackingDevice().length() > 1) {
-            return;
-        }
-        using namespace DFM_NAMESPACE;
-        if (DFMApplication::genericAttribute(DFMApplication::GA_HiddenSystemPartition).toBool() && blk->hintSystem()) {
-            return;
+        if(ignoreBlkDevice(blks, blk, drv)) {
+            return ;
         }
 
         initBlockDevConnections(blk, blks);
@@ -503,7 +619,7 @@ bool DFMRootFileWatcherPrivate::start()
 
     for (auto devs : udisksmgr->blockDevices({})) {
         QSharedPointer<DBlockDevice> blk(DDiskManager::createBlockDevice(devs));
-        QScopedPointer<DDiskDevice> drv(DDiskManager::createDiskDevice(blk->drive()));
+        QSharedPointer<DDiskDevice> drv(DDiskManager::createDiskDevice(blk->drive()));
 
         auto mountPoints = blk->mountPoints();
         if (!drv->removable() && !mountPoints.isEmpty()) { // feature: hide the specified dir of unremovable devices
@@ -515,10 +631,7 @@ bool DFMRootFileWatcherPrivate::start()
             deviceListener->appendHiddenDirs(mountPoint + "lost+found");
         }
 
-        if (!blk->hasFileSystem() && !drv->mediaCompatibility().join(" ").contains("optical") && !blk->isEncrypted()) {
-            continue;
-        }
-        if ((blk->hintIgnore() && !blk->isEncrypted()) || blk->cryptoBackingDevice().length() > 1) {
+        if(ignoreBlkDevice(devs, blk, drv)){
             continue;
         }
 
