@@ -20,7 +20,6 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-
 #include "vaultcontroller.h"
 #include "models/vaultfileinfo.h"
 #include "dfileservices.h"
@@ -32,6 +31,10 @@
 #include "dfilestatisticsjob.h"
 #include "log/dfmLogManager.h"
 #include "log/filterAppender.h"
+#include "vaultconfig.h"
+#include "../vault/operatorcenter.h"
+#include "../vault/vaulthelper.h"
+#include "dfmapplication.h"
 
 #include "appcontroller.h"
 #include "singleton.h"
@@ -50,6 +53,7 @@
 
 #include "dfmevent.h"
 #include "../vault/vaultglobaldefine.h"
+#include "dbusinterface/vaultbruteforceprevention_interface.h"
 
 #include <QProcess>
 #include <QStandardPaths>
@@ -60,14 +64,13 @@
 
 #include <unistd.h>
 
-
 VaultController *VaultController::cryfs = nullptr;
 bool VaultController::m_isBigFileDeleting = false;
 
 class VaultControllerPrivate
 {
 public:
-    explicit VaultControllerPrivate(VaultController *CryFs);
+    explicit VaultControllerPrivate(VaultController *cryFs);
     ~VaultControllerPrivate();
 
     CryFsHandle *m_cryFsHandle = nullptr;
@@ -77,9 +80,9 @@ private:
     Q_DECLARE_PUBLIC(VaultController)
 };
 
-VaultControllerPrivate::VaultControllerPrivate(VaultController *CryFs): q_ptr(CryFs)
+VaultControllerPrivate::VaultControllerPrivate(VaultController *cryFs)
+    : q_ptr(cryFs)
 {
-
 }
 
 VaultControllerPrivate::~VaultControllerPrivate()
@@ -116,8 +119,7 @@ private:
 
 VaultDirIterator::VaultDirIterator(const DUrl &url, const QStringList &nameFilters,
                                    QDir::Filters filter, QDirIterator::IteratorFlags flags)
-    : DDirIterator()
-    , filters(filter)
+    : DDirIterator(), filters(filter)
 {
     QString path = VaultController::vaultToLocal(url);
     iterator = new QDirIterator(path, nameFilters, filter, flags);
@@ -211,7 +213,10 @@ DUrl VaultDirIterator::url() const
 }
 
 VaultController::VaultController(QObject *parent)
-    : DAbstractFileController(parent), d_ptr(new VaultControllerPrivate(this))
+    : DAbstractFileController(parent),
+      d_ptr(new VaultControllerPrivate(this)),
+      m_recordVaultPageMark(VaultPageMark::UNKNOWN),
+      m_vaultVisiable(true)
 {
     Q_D(VaultController);
 
@@ -230,12 +235,13 @@ VaultController::VaultController(QObject *parent)
     connect(d->m_cryFsHandle, &CryFsHandle::signalLockVault, this, &VaultController::slotLockVault);
     connect(d->m_cryFsHandle, &CryFsHandle::signalReadError, this, &VaultController::signalReadError);
     connect(d->m_cryFsHandle, &CryFsHandle::signalReadOutput, this, &VaultController::signalReadOutput);
+    connect(this, &VaultController::sigFinishedCopyFile, this, &VaultController::slotFinishedCopyFileTotalSize);
 
     // Get root dir size.
     m_sizeWorker = new DFileStatisticsJob(this);
 
-    DUrl rootUrl = vaultToLocalUrl(makeVaultUrl());
-    m_sizeWorker->start({rootUrl});
+    slotFinishedCopyFileTotalSize();
+
     connect(m_sizeWorker, &DFileStatisticsJob::dataNotify, this, &VaultController::updateFolderSizeLabel);
 
     // Refresh size when lock state changed.
@@ -252,6 +258,20 @@ VaultController::VaultController(QObject *parent)
     if (pTaskDlg) {
         connect(pTaskDlg, &DTaskDialog::paused, this, &VaultController::taskPaused);
     }
+
+    m_vaultInterface = new VaultBruteForcePreventionInterface("com.deepin.filemanager.daemon",
+                                                              "/com/deepin/filemanager/daemon/VaultManager2",
+                                                              QDBusConnection::systemBus(),
+                                                              this);
+
+    slotVaultPolicy();
+
+    QDBusConnection::systemBus().connect("com.deepin.filemanager.daemon",
+                                         "/com/deepin/filemanager/daemon/AccessControlManager",
+                                         "com.deepin.filemanager.daemon.AccessControlManager",
+                                         "AccessVaultPolicyNotify",
+                                         this,
+                                         SLOT(slotVaultPolicy()));
 }
 
 VaultController *VaultController::ins()
@@ -375,7 +395,7 @@ bool VaultController::openFiles(const QSharedPointer<DFMOpenFilesEvent> &event)
         }
         if (!result) {
             for (const DUrl &fileUrl : packUrl) {
-                AppController::instance()->actionOpenWithCustom(dMakeEventPointer<DFMOpenFileEvent>(event->sender(), fileUrl)); // requestShowOpenWithDialog
+                AppController::instance()->actionOpenWithCustom(dMakeEventPointer<DFMOpenFileEvent>(event->sender(), fileUrl));   // requestShowOpenWithDialog
             }
         }
     }
@@ -431,33 +451,49 @@ bool VaultController::openFilesByApp(const QSharedPointer<DFMOpenFilesByAppEvent
     }
 
     return FileUtils::openFilesByApp(event->appName(), pathList);
-
 }
 
 bool VaultController::deleteFiles(const QSharedPointer<DFMDeleteEvent> &event) const
 {
+    const_cast<VaultController *>(this)->slotFinishedCopyFileTotalSize();
+
+    const_cast<VaultController *>(this)->setVauleCurrentPageMark(VaultPageMark::DELETEFILEPAGE);
     DUrlList urlList = vaultToLocalUrls(event->urlList());
-    bool bDeletedSuccess = DFileService::instance()->deleteFiles(event->sender(), urlList);
+    bool bDeletedSuccess = DFileService::instance()->deleteFiles(event->sender(), urlList, true, event->silent());
     if (bDeletedSuccess) {
         const_cast<VaultController *>(this)->updateFileInfo(urlList);
     }
+    // 修复bug-89733 保险箱删除2个及以上的大文件时，删除完成后，界面不刷新
+    // 删除两个及以上的大文件时，刷新操作非常卡顿，所以不在刷新，并且模态弹框（与产品沟通后的做法）
+    // 这就导致了上述bug的产生，此处修改，增加判断，如果是此种情况，删除完成后，刷新一次界面
+    if (m_isBigFileDeleting)
+        emit fileSignalManager->requestFreshAllFileView();
     m_isBigFileDeleting = false;
     return true;
 }
 
 DUrlList VaultController::moveToTrash(const QSharedPointer<DFMMoveToTrashEvent> &event) const
 {
+    const_cast<VaultController *>(this)->slotFinishedCopyFileTotalSize();
+    const_cast<VaultController *>(this)->setVauleCurrentPageMark(VaultPageMark::DELETEFILEPAGE);
     DUrlList urlList = vaultToLocalUrls(event->urlList());
     bool bDeletedSuccess = DFileService::instance()->deleteFiles(event->sender(), urlList);
     if (bDeletedSuccess) {
         const_cast<VaultController *>(this)->updateFileInfo(urlList);
     }
+    // 修复bug-89733 保险箱删除2个及以上的大文件时，删除完成后，界面不刷新
+    // 删除两个及以上的大文件时，刷新操作非常卡顿，所以不在刷新，并且模态弹框（与产品沟通后的做法）
+    // 这就导致了上述bug的产生，此处修改，增加判断，如果是此种情况，删除完成后，刷新一次界面
+    if (m_isBigFileDeleting)
+        emit fileSignalManager->requestFreshAllFileView();
     m_isBigFileDeleting = false;
     return urlList;
 }
 
 DUrlList VaultController::pasteFile(const QSharedPointer<DFMPasteEvent> &event) const
 {
+    const_cast<VaultController *>(this)->slotFinishedCopyFileTotalSize();
+    const_cast<VaultController *>(this)->setVauleCurrentPageMark(VaultPageMark::COPYFILEPAGE);
     DUrlList urlList = vaultToLocalUrls(event->urlList());
     DUrl url = vaultToLocalUrl(event->targetUrl());
     DUrlList ulist = DFileService::instance()->pasteFile(event->sender(), event->action(), url, urlList);
@@ -466,6 +502,8 @@ DUrlList VaultController::pasteFile(const QSharedPointer<DFMPasteEvent> &event)
 
 bool VaultController::writeFilesToClipboard(const QSharedPointer<DFMWriteUrlsToClipboardEvent> &event) const
 {
+    const_cast<VaultController *>(this)->slotFinishedCopyFileTotalSize();
+    const_cast<VaultController *>(this)->setVauleCurrentPageMark(VaultPageMark::CLIPBOARDPAGE);
     DUrlList urlList = vaultToLocalUrls(event->urlList());
     return DFileService::instance()->writeFilesToClipboard(event->sender(), event->action(), urlList);
 }
@@ -481,28 +519,6 @@ bool VaultController::renameFile(const QSharedPointer<DFMRenameEvent> &event) co
     return flg;
 }
 
-bool VaultController::shareFolder(const QSharedPointer<DFMFileShareEvent> &event) const
-{
-    ShareInfo info;
-    info.setPath(makeVaultLocalPath(event->name()));
-
-    info.setShareName(event->name());
-    info.setIsGuestOk(event->allowGuest());
-    info.setIsWritable(event->isWritable());
-
-    bool ret = userShareManager->addUserShare(info);
-
-    return ret;
-}
-
-bool VaultController::unShareFolder(const QSharedPointer<DFMCancelFileShareEvent> &event) const
-{
-    QString path = vaultToLocalUrl(event->fileUrl()).path();
-    userShareManager->deleteUserShareByPath(path);
-
-    return true;
-}
-
 bool VaultController::openInTerminal(const QSharedPointer<DFMOpenInTerminalEvent> &event) const
 {
     const QString &current_dir = QDir::currentPath();
@@ -548,7 +564,7 @@ bool VaultController::addToBookmark(const QSharedPointer<DFMAddToBookmarkEvent>
 
 bool VaultController::removeBookmark(const QSharedPointer<DFMRemoveBookmarkEvent> &event) const
 {
-    return DFileService::instance()->deleteFiles(nullptr, {DUrl::fromBookMarkFile(event->url(), QString())}, false);
+    return DFileService::instance()->deleteFiles(nullptr, { DUrl::fromBookMarkFile(event->url(), QString()) }, false);
 }
 
 bool VaultController::createSymlink(const QSharedPointer<DFMCreateSymlinkEvent> &event) const
@@ -591,12 +607,12 @@ bool VaultController::setFileTags(const QSharedPointer<DFMSetFileTagsEvent> &eve
     DUrl durl = vaultToLocalUrl(url);
     QList<QString> taglist = event->tags();
     if (taglist.isEmpty()) {
-        const QStringList &tags = TagManager::instance()->getTagsThroughFiles({durl});
+        const QStringList &tags = TagManager::instance()->getTagsThroughFiles({ durl });
 
-        return tags.isEmpty() || TagManager::instance()->removeTagsOfFiles(tags, {durl});
+        return tags.isEmpty() || TagManager::instance()->removeTagsOfFiles(tags, { durl });
     }
 
-    return TagManager::instance()->makeFilesTags(taglist, {durl});
+    return TagManager::instance()->makeFilesTags(taglist, { durl });
 }
 
 bool VaultController::removeTagsOfFile(const QSharedPointer<DFMRemoveTagsOfFileEvent> &event) const
@@ -604,7 +620,7 @@ bool VaultController::removeTagsOfFile(const QSharedPointer<DFMRemoveTagsOfFileE
     DUrl url = event->url();
     DUrl durl = vaultToLocalUrl(url);
     QList<QString> taglist = event->tags();
-    return TagManager::instance()->removeTagsOfFiles(taglist, {durl});
+    return TagManager::instance()->removeTagsOfFiles(taglist, { durl });
 }
 
 QList<QString> VaultController::getTagsThroughFiles(const QSharedPointer<DFMGetTagsThroughFilesEvent> &event) const
@@ -720,7 +736,7 @@ DUrl VaultController::vaultToLocalUrl(const DUrl &vaultUrl)
 
 DUrlList VaultController::vaultToLocalUrls(DUrlList vaultUrls)
 {
-    std::transform(vaultUrls.begin(), vaultUrls.end(), vaultUrls.begin(), [](const DUrl & url) {
+    std::transform(vaultUrls.begin(), vaultUrls.end(), vaultUrls.begin(), [](const DUrl &url) {
         return vaultToLocalUrl(url);
     });
 
@@ -731,6 +747,8 @@ VaultController::VaultState VaultController::state(QString lockBaseDir)
 {
     QString cryfsBinary = QStandardPaths::findExecutable("cryfs");
     if (cryfsBinary.isEmpty()) {
+        // 记录保险箱状态
+        m_enVaultState = NotAvailable;
         return NotAvailable;
     }
 
@@ -746,11 +764,13 @@ VaultController::VaultState VaultController::state(QString lockBaseDir)
         QStorageInfo info(makeVaultLocalPath(""));
         QString temp = info.fileSystemType();
         if (info.isValid() && temp == "fuse.cryfs") {
+            m_enVaultState = Unlocked;
             return Unlocked;
         }
-
+        m_enVaultState = Encrypted;
         return Encrypted;
     } else {
+        m_enVaultState = NotExisted;
         return NotExisted;
     }
 }
@@ -762,7 +782,7 @@ bool VaultController::isRootDirectory(QString path)
     QString pathNoSplash = localFilePath;
     pathNoSplash.chop(1);
     if (localFilePath == path || makeVaultUrl().toString() == path
-            || pathNoSplash == path) {
+        || pathNoSplash == path) {
         bRootDir = true;
     }
     return bRootDir;
@@ -902,6 +922,81 @@ void VaultController::setBigFileIsDeleting(const bool isDeleting)
     m_isBigFileDeleting = isDeleting;
 }
 
+int VaultController::getLeftoverErrorInputTimes()
+{
+    createVaultBruteForcePreventionInterface();
+    int leftChance = -1;
+    if (m_vaultInterface->isValid()) {
+        QDBusPendingReply<int> reply = m_vaultInterface->getLeftoverErrorInputTimes(int(getuid()));
+        reply.waitForFinished();
+        if (reply.isError()) {
+            qInfo() << "Warning: Obtaining the remaining number of password input errors!" << reply.error().message();
+        } else {
+            leftChance = reply.value();
+        }
+    }
+    return leftChance;
+}
+
+void VaultController::leftoverErrorInputTimesMinusOne()
+{
+    createVaultBruteForcePreventionInterface();
+    if (m_vaultInterface->isValid()) {
+        QDBusPendingReply<> reply = m_vaultInterface->leftoverErrorInputTimesMinusOne(int(getuid()));
+        reply.waitForFinished();
+        if (reply.isError())
+            qInfo() << "Warning: The remaining password input times minus 1 is wrong!" << reply.error().message();
+    }
+}
+
+void VaultController::restoreLeftoverErrorInputTimes()
+{
+    createVaultBruteForcePreventionInterface();
+    if (m_vaultInterface->isValid()) {
+        QDBusPendingReply<> reply = m_vaultInterface->restoreLeftoverErrorInputTimes(int(getuid()));
+        reply.waitForFinished();
+        if (reply.isError())
+            qInfo() << "Warning: Error in restoring the remaining number of incorrect entries!" << reply.error().message();
+    }
+}
+
+void VaultController::startTimerOfRestorePasswordInput()
+{
+    createVaultBruteForcePreventionInterface();
+    if (m_vaultInterface->isValid()) {
+        QDBusPendingReply<> reply = m_vaultInterface->startTimerOfRestorePasswordInput(int(getuid()));
+        reply.waitForFinished();
+        if (reply.isError())
+            qInfo() << "Warning: Error when opening the password input timer!" << reply.error().message();
+    }
+}
+
+int VaultController::getNeedWaitMinutes()
+{
+    createVaultBruteForcePreventionInterface();
+    int result = 100;
+    if (m_vaultInterface->isValid()) {
+        QDBusPendingReply<int> reply = m_vaultInterface->getNeedWaitMinutes(int(getuid()));
+        reply.waitForFinished();
+        if (reply.isError())
+            qInfo() << "Warning: Failed to get the number of minutes to wait!" << reply.error().message();
+        else
+            result = reply.value();
+    }
+    return result;
+}
+
+void VaultController::restoreNeedWaitMinutes()
+{
+    createVaultBruteForcePreventionInterface();
+    if (m_vaultInterface->isValid()) {
+        QDBusPendingReply<> reply = m_vaultInterface->restoreNeedWaitMinutes(int(getuid()));
+        reply.waitForFinished();
+        if (reply.isError())
+            qInfo() << "Warnning: The restore needs to wait for a few minutes to fail!" << reply.error().message();
+    }
+}
+
 void VaultController::updateFolderSizeLabel(const qint64 size) noexcept
 {
     m_totalSize = size;
@@ -996,9 +1091,19 @@ bool VaultController::isBigFileDeleting()
 
 void VaultController::createVault(const DSecureString &password, QString lockBaseDir, QString unlockFileDir)
 {
-    auto createIfNotExist = [](const QString & path) {
+    auto createIfNotExist = [](const QString &path) {
         if (!QFile::exists(path)) {
             QDir().mkpath(path);
+        } else {   // 修复bug-52351 创建保险箱前，如果文件夹存在，则清空
+            QDir dir(path);
+            if (!dir.isEmpty()) {
+                QDirIterator dirsIterator(path, QDir::AllEntries | QDir::NoDotAndDotDot);
+                while (dirsIterator.hasNext()) {
+                    if (!dir.remove(dirsIterator.next())) {
+                        QDir(dirsIterator.filePath()).removeRecursively();
+                    }
+                }
+            }
         }
     };
 
@@ -1046,7 +1151,7 @@ void VaultController::unlockVault(const DSecureString &password, QString lockBas
                 }
             }
         }
-    } else {    // 如果不存在,则创建目录
+    } else {   // 如果不存在,则创建目录
         QDir().mkpath(strPath);
     }
 
@@ -1113,7 +1218,7 @@ void VaultController::refreshTotalSize()
     }
 
     DUrl url = vaultToLocalUrl(makeVaultUrl());
-    m_sizeWorker->start({url});
+    m_sizeWorker->start({ url });
 }
 
 void VaultController::onFinishCalcSize()
@@ -1122,7 +1227,7 @@ void VaultController::onFinishCalcSize()
     if (m_bNeedRefreshSize && !m_sizeWorker->isRunning()) {
         DUrl url = vaultToLocalUrl(makeVaultUrl());
         // 修复BUG-47507 增加判断，如果该线程正在启动，不要再次进入该线程
-        m_sizeWorker->start({url});
+        m_sizeWorker->start({ url });
         m_bNeedRefreshSize = false;
     }
 }
@@ -1157,10 +1262,168 @@ void VaultController::slotLockVault(int state)
         m_enVaultState = Encrypted;
         // 刷新下界面
         emit fileSignalManager->requestFreshAllFileView();
+        VaultController::ins()->setVauleCurrentPageMark(VaultPageMark::UNKNOWN);
     }
     emit signalLockVault(state);
 }
 
+void VaultController::slotFinishedCopyFileTotalSize()
+{
+    if (!m_sizeWorker->isRunning()) {
+        DUrl rootUrl = vaultToLocalUrl(makeVaultUrl());
+        m_sizeWorker->start({ rootUrl });
+    }
+}
+
+void VaultController::slotVaultPolicy()
+{
+    switch (getVaultPolicy()) {
+    case INVISIBLE: {
+        switch (getVaultCurrentPageMark()) {
+        case VaultPageMark::UNKNOWN:
+            break;
+        case VaultPageMark::CREATEVAULTPAGE:
+            emit sigCloseWindow();
+            break;
+        case VaultPageMark::RETRIEVEPASSWORDPAGE:
+            emit sigCloseWindow();
+            break;
+        case VaultPageMark::VAULTPAGE:
+            emit sigCloseWindow();
+            break;
+        case VaultPageMark::CLIPBOARDPAGE:
+            if (m_vaultVisiable) {
+                lockVault();
+                m_vaultVisiable = false;
+                emit DFMApplication::instance()->reloadComputerModel();
+                VaultHelper::killVaultTasks();
+                return;
+            }
+            break;
+        case VaultPageMark::COPYFILEPAGE:
+            if (m_vaultVisiable) {
+                lockVault();
+                m_vaultVisiable = false;
+                emit DFMApplication::instance()->reloadComputerModel();
+                VaultHelper::killVaultTasks();
+                return;
+            }
+            break;
+        case VaultPageMark::CREATEVAULTPAGE1:
+        case VaultPageMark::UNLOCKVAULTPAGE:
+        case VaultPageMark::DELETEFILEPAGE:
+        case VaultPageMark::DELETEVAULTPAGE:
+            setVaultPolicyState(2);
+            return;
+        }
+
+        lockVault();
+        m_vaultVisiable = false;
+        emit DFMApplication::instance()->reloadComputerModel();
+    } break;
+    case VISIBLE:
+        if (!m_vaultVisiable) {
+            m_vaultVisiable = true;
+            emit DFMApplication::instance()->reloadComputerModel();
+        }
+        break;
+    }
+}
+
+bool VaultController::getVaultVersion()
+{
+    VaultConfig config;
+    QString strVersion = config.get(CONFIG_NODE_NAME, CONFIG_KEY_VERSION).toString();
+    if (!strVersion.isEmpty() && strVersion != CONFIG_VAULT_VERSION)
+        return true;
+
+    return false;
+}
+
+void VaultController::createVaultBruteForcePreventionInterface()
+{
+    // 防暴力破解功能的dbus对象
+    if (!m_vaultInterface->isValid())
+        m_vaultInterface = new VaultBruteForcePreventionInterface("com.deepin.filemanager.daemon",
+                                                                  "/com/deepin/filemanager/daemon/VaultManager2",
+                                                                  QDBusConnection::systemBus(),
+                                                                  this);
+}
+
+int VaultController::getVaultPolicy()
+{
+    QDBusInterface deepin_systemInfo("com.deepin.filemanager.daemon",
+                                     "/com/deepin/filemanager/daemon/AccessControlManager",
+                                     "com.deepin.filemanager.daemon.AccessControlManager",
+                                     QDBusConnection::systemBus(), this);
+
+    int vaulthidestate = -1;
+
+    //调用
+    auto response = deepin_systemInfo.call("QueryVaultAccessPolicyVisible");
+    //判断method是否被正确返回
+    if (response.type() == QDBusMessage::ReplyMessage) {
+        //从返回参数获取返回值
+        QVariantList value = response.arguments();
+        if (!value.isEmpty()) {
+            QVariant varVaule = value.first();
+            vaulthidestate = varVaule.toInt();
+        } else {
+            vaulthidestate = -1;
+        }
+
+    } else {
+        qDebug() << "value method called failed!";
+        vaulthidestate = -1;
+    }
+
+    return vaulthidestate;
+}
+
+bool VaultController::setVaultPolicyState(int policyState)
+{
+    QDBusInterface deepin_systemInfo("com.deepin.filemanager.daemon",
+                                     "/com/deepin/filemanager/daemon/AccessControlManager",
+                                     "com.deepin.filemanager.daemon.AccessControlManager",
+                                     QDBusConnection::systemBus(), this);
+
+    auto response = deepin_systemInfo.call("FileManagerReply", QVariant::fromValue(policyState));
+    //判断method是否被正确返回
+    if (response.type() == QDBusMessage::ReplyMessage) {
+        //从返回参数获取返回值
+        QVariantList value = response.arguments();
+        if (!value.isEmpty()) {
+            QVariant varVaule = value.first();
+            if (!varVaule.toString().isEmpty()) {
+                return true;
+            }
+        } else {
+            return false;
+        }
+
+    } else {
+        qDebug() << "value method called failed!";
+        return false;
+    }
+
+    return false;
+}
+
+void VaultController::setVauleCurrentPageMark(VaultPageMark mark)
+{
+    m_recordVaultPageMark = mark;
+}
+
+VaultPageMark VaultController::getVaultCurrentPageMark()
+{
+    return m_recordVaultPageMark;
+}
+
+bool VaultController::isVaultVisiable()
+{
+    return m_vaultVisiable;
+}
+
 VaultController::~VaultController()
 {
     if (d_ptr) {
