@@ -106,7 +106,6 @@ DialogManager::DialogManager(QObject *parent) : QObject(parent)
 
 DialogManager::~DialogManager()
 {
-
 }
 
 void DialogManager::initData()
@@ -174,12 +173,6 @@ void DialogManager::initConnect()
     connect(fileSignalManager, &FileSignalManager::requestShowFilePreviewDialog, this, &DialogManager::showFilePreviewDialog);
     connect(fileSignalManager, &FileSignalManager::requestShowErrorDialog, this, &DialogManager::showErrorDialog);
     connect(fileSignalManager, &FileSignalManager::activeTaskDlg, this, &DialogManager::showTaskProgressDlgOnActive);
-
-    if (getGvfsMountManager(false)) {
-        connect(gvfsMountManager, &GvfsMountManager::mount_added, this, &DialogManager::showNtfsWarningDialog);
-    }
-
-
 #ifdef SW_LABEL
     connect(fileSignalManager, &FileSignalManager::jobFailed, this, &DialogManager::onJobFailed_SW);
 #endif
@@ -406,7 +399,7 @@ void DialogManager::showCopyMoveToSelfDialog(const QMap<QString, QString> &jobDe
     d.setTitle(tr("Operation failed!"));
     d.setMessage(tr("Target folder is inside the source folder!"));
     QStringList buttonTexts;
-    buttonTexts.append(tr("OK"));
+    buttonTexts.append(tr("OK","button"));
     d.addButton(buttonTexts[0], true, DDialog::ButtonRecommend);
     d.setDefaultButton(0);
     d.setIcon(m_dialogWarningIcon);
@@ -436,10 +429,10 @@ int DialogManager::showRunExcutableScriptDialog(const DUrl &url, quint64 winId)
     buttonKeys.append("OptionRun");
     buttonKeys.append("OptionRunInTerminal");
     buttonKeys.append("OptionDisplay");
-    buttonTexts.append(tr("Cancel"));
-    buttonTexts.append(tr("Run"));
-    buttonTexts.append(tr("Run in terminal"));
-    buttonTexts.append(tr("Display"));
+    buttonTexts.append(tr("Cancel","button"));
+    buttonTexts.append(tr("Run","button"));
+    buttonTexts.append(tr("Run in terminal","button"));
+    buttonTexts.append(tr("Display","button"));
     d.setIcon(QIcon::fromTheme("application-x-shellscript"));
     d.setTitle(message);
     d.setMessage(tipMessage);
@@ -462,9 +455,9 @@ int DialogManager::showRunExcutableFileDialog(const DUrl &url, quint64 winId)
     QString fileDisplayName = d.fontMetrics().elidedText(_fileDisplayName, Qt::ElideRight, maxDisplayNameLength);
     QString message = tr("Do you want to run %1?").arg(fileDisplayName);
     QString tipMessage = tr("It is an executable file.");
-    d.addButton(tr("Cancel"));
-    d.addButton(tr("Run in terminal"));
-    d.addButton(tr("Run"), true, DDialog::ButtonRecommend);
+    d.addButton(tr("Cancel","button"));
+    d.addButton(tr("Run in terminal","button"));
+    d.addButton(tr("Run","button"), true, DDialog::ButtonRecommend);
     d.setTitle(message);
     d.setMessage(tipMessage);
     d.setIcon(pfileInfo->fileIcon());
@@ -478,8 +471,8 @@ int DialogManager::showAskIfAddExcutableFlagAndRunDialog(const DUrl &url, quint6
     const DAbstractFileInfoPointer &pfileInfo = fileService->createFileInfo(this, url);
     // i18n text from: https://github.com/linuxdeepin/internal-discussion/issues/456 , seems a little weird..
     QString message = tr("This file is not executable, do you want to add the execute permission and run?");
-    d.addButton(tr("Cancel"));
-    d.addButton(tr("Run"), true, DDialog::ButtonRecommend);
+    d.addButton(tr("Cancel","button"));
+    d.addButton(tr("Run","button"), true, DDialog::ButtonRecommend);
     d.setTitle(message);
     d.setIcon(pfileInfo->fileIcon());
     int code = d.exec();
@@ -493,7 +486,7 @@ int DialogManager::showRenameNameSameErrorDialog(const QString &name, const DFME
     QFontMetrics fm(d.font());
     d.setTitle(tr("\"%1\" already exists, please use another name.").arg(fm.elidedText(name, Qt::ElideMiddle, 150)));
     QStringList buttonTexts;
-    buttonTexts.append(tr("Confirm"));
+    buttonTexts.append(tr("Confirm","button"));
     d.addButton(buttonTexts[0], true, DDialog::ButtonRecommend);
     d.setDefaultButton(0);
     d.setIcon(m_dialogWarningIcon);
@@ -508,7 +501,7 @@ int DialogManager::showRenameNameDotDotErrorDialog(const DFMEvent &event)
     QFontMetrics fm(d.font());
     d.setTitle(tr("The file name must not contain two dots (..)"));
     QStringList buttonTexts;
-    buttonTexts.append(tr("Confirm"));
+    buttonTexts.append(tr("Confirm","button"));
     d.addButton(buttonTexts[0], true, DDialog::ButtonRecommend);
     d.setDefaultButton(0);
     // 设置对话框icon
@@ -517,6 +510,21 @@ int DialogManager::showRenameNameDotDotErrorDialog(const DFMEvent &event)
     return code;
 }
 
+void DialogManager::showRenameBusyErrDialog(const DFMEvent &event)
+{
+    // 获取父对话框字体特性
+    DDialog d(WindowManager::getWindowById(event.windowId()));
+    QFontMetrics fm(d.font());
+    d.setTitle(tr("Device or resource busy"));
+    QStringList buttonTexts;
+    buttonTexts.append(tr("Confirm","button"));
+    d.addButton(buttonTexts[0], true, DDialog::ButtonRecommend);
+    d.setDefaultButton(0);
+    // 设置对话框icon
+    d.setIcon(m_dialogWarningIcon);
+    d.exec();
+}
+
 int DialogManager::showOpticalBlankConfirmationDialog(const DFMUrlBaseEvent &event)
 {
     QString EraseDisk = tr("Are you sure you want to erase all data on the disc?");
@@ -524,8 +532,8 @@ int DialogManager::showOpticalBlankConfirmationDialog(const DFMUrlBaseEvent &eve
     DUrl url = event.url();
     qDebug() << url;
     QStringList buttonTexts;
-    buttonTexts.append(tr("Cancel"));
-    buttonTexts.append(tr("Erase"));
+    buttonTexts.append(tr("Cancel","button"));
+    buttonTexts.append(tr("Erase","button"));
 
     DDialog d;
 
@@ -551,9 +559,9 @@ int DialogManager::showOpticalImageOpSelectionDialog(const DFMUrlBaseEvent &even
 
     DUrl url = event.url();
     QStringList buttonTexts;
-    buttonTexts.append(tr("Cancel"));
-    buttonTexts.append(tr("Burn image"));
-    buttonTexts.append(tr("Burn files"));
+    buttonTexts.append(tr("Cancel","button"));
+    buttonTexts.append(tr("Burn image","button"));
+    buttonTexts.append(tr("Burn files","button"));
 
     DDialog d;
 
@@ -575,7 +583,6 @@ int DialogManager::showOpticalImageOpSelectionDialog(const DFMUrlBaseEvent &even
 
 void DialogManager::showOpticalJobFailureDialog(int type, const QString &err, const QStringList &details)
 {
-    Q_UNUSED(details)
     DDialog d;
     d.setIcon(QIcon::fromTheme("dialog-error"));
     QString failure_type;
@@ -596,8 +603,7 @@ void DialogManager::showOpticalJobFailureDialog(int type, const QString &err, co
     QWidget *detailsw = new QWidget(&d);
     detailsw->setLayout(new QVBoxLayout());
     QTextEdit *te = new QTextEdit();
-    // tmp: 暂时不要详细信息
-    // te->setPlainText(details.join('\n'));
+    te->setPlainText(details.join('\n'));
     te->setReadOnly(true);
     te->hide();
     detailsw->layout()->addWidget(te);
@@ -616,10 +622,14 @@ void DialogManager::showOpticalJobFailureDialog(int type, const QString &err, co
             d.setTitle(tr("Error"));
         }
     });
+
+    detailsw->setFixedWidth(360);
+    d.layout()->setSizeConstraint(QLayout::SetFixedSize); // make sure dialog can shrank after expanded for more info.
+
     d.addContent(detailsw);
     d.setOnButtonClickedClose(false);
-    d.addButton(tr("Show details"));
-    d.addButton(tr("Confirm"), true, DDialog::ButtonRecommend);
+    d.addButton(tr("Show details","button"));
+    d.addButton(tr("Confirm","button"), true, DDialog::ButtonRecommend);
     d.setDefaultButton(1);
     d.getButton(1)->setFocus();
     d.exec();
@@ -630,7 +640,7 @@ void DialogManager::showOpticalJobCompletionDialog(const QString &msg, const QSt
     DDialog d;
     d.setIcon(QIcon::fromTheme(icon));
     d.setTitle(msg);
-    d.addButton(tr("OK"), true, DDialog::ButtonRecommend);
+    d.addButton(tr("OK","button"), true, DDialog::ButtonRecommend);
     d.setDefaultButton(0);
     d.getButton(0)->setFocus();
     d.exec();
@@ -647,8 +657,8 @@ int DialogManager::showDeleteFilesClearTrashDialog(const DFMUrlListBaseEvent &ev
 
     DUrlList urlList = event.urlList();
     QStringList buttonTexts;
-    buttonTexts.append(tr("Cancel"));
-    buttonTexts.append(tr("Delete"));
+    buttonTexts.append(tr("Cancel","button"));
+    buttonTexts.append(tr("Delete","button"));
 
     DDialog d;
 
@@ -721,8 +731,8 @@ int DialogManager::showNormalDeleteConfirmDialog(const DFMUrlListBaseEvent &even
     }
 
     QStringList buttonTexts;
-    buttonTexts.append(tr("Cancel"));
-    buttonTexts.append(tr("Delete"));
+    buttonTexts.append(tr("Cancel","button"));
+    buttonTexts.append(tr("Delete","button"));
     d.addButton(buttonTexts[0], true, DDialog::ButtonNormal);
     d.addButton(buttonTexts[1], false, DDialog::ButtonWarning);
     d.setDefaultButton(1);
@@ -738,8 +748,8 @@ int DialogManager::showRemoveBookMarkDialog(const DFMEvent &event)
     d.setTitle(tr("Sorry, unable to locate your bookmark directory, remove it?"));
     d.setMessage(" ");
     QStringList buttonTexts;
-    buttonTexts.append(tr("Cancel"));
-    buttonTexts.append(tr("Remove"));
+    buttonTexts.append(tr("Cancel","button"));
+    buttonTexts.append(tr("Remove","button"));
     d.addButton(buttonTexts[0], true);
     d.addButton(buttonTexts[1], false, DDialog::ButtonRecommend);
     d.setDefaultButton(1);
@@ -860,6 +870,7 @@ void DialogManager::showTrashPropertyDialog(const DFMEvent &event)
 void DialogManager::showComputerPropertyDialog()
 {
     if (m_computerDialog) {
+        m_computerDialog->updateComputerInfo();
         m_computerDialog->show();
         m_computerDialog->raise();
         return;
@@ -901,8 +912,8 @@ void DialogManager::showDiskErrorDialog(const QString &id, const QString &errorT
         d.setTitle(tr("Disk is busy, cannot unmount now"));
         d.setMessage(tr("Name: ") + info->fileDisplayName()/* + ", " + tr("Path: ") + info->getPath()*/);
         QStringList buttonTexts;
-        buttonTexts.append(tr("Cancel"));
-        buttonTexts.append(tr("Force unmount"));
+        buttonTexts.append(tr("Cancel","button"));
+        buttonTexts.append(tr("Force unmount","button"));
         d.addButton(buttonTexts[0], true);
         d.addButton(buttonTexts[1], false, DDialog::ButtonWarning);
         d.setDefaultButton(0);
@@ -931,8 +942,8 @@ void DialogManager::showBreakSymlinkDialog(const QString &targetName, const DUrl
     d.setTitle(warnText.arg(_targetName));
     d.setMessage(tr("Do you want to delete this shortcut？"));
     QStringList buttonTexts;
-    buttonTexts.append(tr("Cancel"));
-    buttonTexts.append(tr("Confirm"));
+    buttonTexts.append(tr("Cancel","button"));
+    buttonTexts.append(tr("Confirm","button"));
     d.addButton(buttonTexts[0], true);
     d.addButton(buttonTexts[1], false, DDialog::ButtonRecommend);
     d.setDefaultButton(1);
@@ -1016,7 +1027,7 @@ void DialogManager::showDiskSpaceOutOfUsedDialog()
     DDialog d;
     d.setIcon(m_dialogWarningIcon);
     d.setTitle(tr("Unable to copy. Not enough free space on the target disk."));
-    d.addButton(tr("OK"));
+    d.addButton(tr("OK","button"));
 
     QRect rect = d.geometry();
     rect.moveCenter(qApp->desktop()->geometry().center());
@@ -1029,7 +1040,7 @@ void DialogManager::show4gFat32Dialog()
     DDialog d;
     d.setTitle(tr("Failed, file size must be less than 4GB."));
     d.setIcon(m_dialogWarningIcon);
-    d.addButton(tr("OK"), true, DDialog::ButtonRecommend);
+    d.addButton(tr("OK","button"), true, DDialog::ButtonRecommend);
     d.exec();
 }
 
@@ -1038,7 +1049,7 @@ void DialogManager::showFailToCreateSymlinkDialog(const QString &errorString)
     DDialog d;
     d.setTitle(tr("Fail to create symlink, cause:") + errorString);
     d.setIcon(m_dialogWarningIcon);
-    d.addButton(tr("OK"), true, DDialog::ButtonRecommend);
+    d.addButton(tr("OK","button"), true, DDialog::ButtonRecommend);
     d.exec();
 }
 
@@ -1056,7 +1067,7 @@ void DialogManager::showDeleteSystemPathWarnDialog(quint64 winId)
     DDialog d(WindowManager::getWindowById(winId));
     d.setTitle(tr("The selected files contain system file/directory, and it cannot be deleted"));
     d.setIcon(m_dialogWarningIcon);
-    d.addButton(tr("OK"), true, DDialog::ButtonRecommend);
+    d.addButton(tr("OK","button"), true, DDialog::ButtonRecommend);
     d.exec();
 }
 
@@ -1153,7 +1164,7 @@ void DialogManager::showRestoreFailedDialog(const DUrlList &urlList)
         d.setMessage(tr("Failed to restore %1 files, the target folder is read-only").arg(QString::number(urlList.count())));
     }
     d.setIcon(m_dialogWarningIcon);
-    d.addButton(tr("OK"), true, DDialog::ButtonRecommend);
+    d.addButton(tr("OK","button"), true, DDialog::ButtonRecommend);
     d.exec();
 }
 
@@ -1164,7 +1175,7 @@ void DialogManager::showRestoreFailedPerssionDialog(const QString &srcPath, cons
     d.setTitle(tr("Operation failed!"));
     d.setMessage(tr("You do not have permission to operate file/folder!"));
     d.setIcon(m_dialogWarningIcon);
-    d.addButton(tr("OK"), true, DDialog::ButtonRecommend);
+    d.addButton(tr("OK","button"), true, DDialog::ButtonRecommend);
     d.exec();
 }
 
@@ -1178,7 +1189,7 @@ void DialogManager::showRestoreFailedSourceNotExists(const DUrlList &urlList)
         d.setMessage(tr("Failed to restore %1 files, the source files do not exist").arg(QString::number(urlList.count())));
     }
     d.setIcon(m_dialogWarningIcon);
-    d.addButton(tr("OK"), true, DDialog::ButtonRecommend);
+    d.addButton(tr("OK","button"), true, DDialog::ButtonRecommend);
     d.exec();
 }
 
@@ -1244,93 +1255,10 @@ void DialogManager::showNoPermissionDialog(const DFMUrlListBaseEvent &event)
         d.addContent(contentFrame, Qt::AlignCenter);
     }
 
-    d.addButton(tr("OK"), true, DDialog::ButtonRecommend);
+    d.addButton(tr("OK","button"), true, DDialog::ButtonRecommend);
     d.exec();
 }
 
-void DialogManager::showNtfsWarningDialog(const QDiskInfo &diskInfo)
-{
-    QTimer::singleShot(1000, [ = ] {
-        if (qApp->applicationName() == QMAKE_TARGET && !DFMGlobal::IsFileManagerDiloagProcess)
-        {
-            QStringList &&udiskspaths = DDiskManager::resolveDeviceNode(diskInfo.unix_device(), {});
-            if (udiskspaths.isEmpty())
-                return;
-            QScopedPointer<DBlockDevice> blk(DDiskManager::createBlockDevice(udiskspaths.first()));
-            QString fstype = blk->idType();
-            if (fstype == "ntfs") {
-                // blumia: the ntfs partition will be read-only if user mount the ntfs device by the kernel driver.
-                //         the fstype (from `df -T` or `mount`) will be "ntfs" rather than "fuseblk" if user use the kernel driver
-                //         to mount the block device, so we use `df -t ntfs /dev/xxxxx` to check if the fstype is "ntfs".
-                QProcess checkFsDrv;
-                checkFsDrv.start("df", {"--output=fstype", diskInfo.unix_device()});
-                checkFsDrv.waitForFinished(-1);
-                QString dfStdOut = checkFsDrv.readAllStandardOutput().split('\n').value(1);
-                if (dfStdOut == QStringLiteral("ntfs"))
-                    return;
-
-                bool isReadOnly = false;
-                DUrl mountUrl = DUrl(diskInfo.mounted_root_uri());
-                QFileInfo mountFileInfo(mountUrl.toLocalFile());
-                isReadOnly = mountFileInfo.isReadable() && !QFileInfo(DUrl(diskInfo.mounted_root_uri()).toLocalFile()).isWritable();
-                qDebug() << DUrl(diskInfo.mounted_root_uri()).toLocalFile() << fstype << "isReadOnly:" << isReadOnly;
-                if (isReadOnly) {
-                    DDialog d;
-                    QFrame *contentFrame = new QFrame;
-
-                    QLabel *iconLabel = new QLabel;
-                    iconLabel->setPixmap(m_dialogWarningIcon.pixmap(64, 64));
-
-                    QLabel *titleLabel = new QLabel;
-                    titleLabel->setText(tr("Mount partition%1 to be read only").arg(diskInfo.unix_device()));
-
-                    QLabel *discriptionLabel = new QLabel;
-                    discriptionLabel->setScaledContents(true);
-                    discriptionLabel->setText(tr("Disks in Windows will be unable to read and write normally if check \"Turn on fast startup (recommended)\" in Shutdown settings"));
-
-                    QLabel *messageTitleLabel = new QLabel;
-                    messageTitleLabel->setScaledContents(true);
-                    QString messageTitleMessage = tr("Please restore by the following steps to normally access Windows disk");
-                    messageTitleLabel->setText(messageTitleMessage);
-
-                    QLabel *messageLabel = new QLabel;
-                    messageLabel->setScaledContents(true);
-
-                    QString message1 = tr("1. Reboot to enter Windows");
-                    QString message2 = tr("2. Uncheck \"Turn on fast startup\" and \"Hibernate\" in shutdown settings and reboot");
-                    QString message3 = tr("3. Reboot and enter %1").arg(DSysInfo::distributionOrgName());
-
-                    messageLabel->setText(QString("%1\n%2\n%3").arg(message1, message2, message3));
-
-                    QVBoxLayout *contentLayout = new QVBoxLayout;
-                    contentLayout->addWidget(iconLabel, 0, Qt::AlignCenter);
-                    contentLayout->addWidget(titleLabel, 0, Qt::AlignCenter);
-                    contentLayout->addWidget(discriptionLabel, 0, Qt::AlignLeft);
-                    contentLayout->addSpacing(10);
-                    contentLayout->addWidget(messageTitleLabel, 0, Qt::AlignLeft);
-                    contentLayout->addWidget(messageLabel, 0, Qt::AlignLeft);
-                    contentLayout->setContentsMargins(100, 0, 100, 0);
-                    contentLayout->setSpacing(10);
-                    contentFrame->setLayout(contentLayout);
-
-                    d.addContent(contentFrame, Qt::AlignCenter);
-                    d.addButton(tr("Cancel"), false, DDialog::ButtonNormal);
-                    d.addButton(tr("Reboot"), true, DDialog::ButtonRecommend);
-                    int ret = d.exec();
-                    if (ret == 1) {
-                        qDebug() << "===================Reboot system=====================";
-                        QDBusInterface sessionManagerIface("com.deepin.SessionManager",
-                                                           "/com/deepin/SessionManager",
-                                                           "com.deepin.SessionManager",
-                                                           QDBusConnection::sessionBus());
-                        sessionManagerIface.asyncCall("Reboot");
-                    }
-                }
-            }
-        }
-    });
-}
-
 void DialogManager::showErrorDialog(const QString &title, const QString &message)
 {
     DDialog d(title, message);
@@ -1338,7 +1266,7 @@ void DialogManager::showErrorDialog(const QString &title, const QString &message
     // dialog show top
     d.setWindowFlags(flags | Qt::CustomizeWindowHint | Qt::WindowStaysOnTopHint);
     d.setIcon(QIcon::fromTheme("dialog-error"));
-    d.addButton(tr("Confirm"), true, DDialog::ButtonRecommend);
+    d.addButton(tr("Confirm","button"), true, DDialog::ButtonRecommend);
     d.setMaximumWidth(640);
     d.exec();
 }
@@ -1442,7 +1370,7 @@ int DialogManager::showUnableToLocateDir(const QString &dir)
         d.setTitle(tr("Unable to access %1").arg(dir));
         d.setMessage(" ");
         QStringList buttonTexts;
-        buttonTexts.append(tr("Confirm"));
+        buttonTexts.append(tr("Confirm","button"));
         d.addButton(buttonTexts[0], true);
         d.setDefaultButton(0);
         d.setIcon(QIcon::fromTheme("folder").pixmap(64, 64));
@@ -1569,8 +1497,8 @@ void DialogManager::showFormatDialog(const QString &devId)
     qDebug() << "device formatter has shown: " << devId;
     DDialog dlg;
     dlg.setIcon(m_dialogWarningIcon);
-    dlg.addButton(tr("Cancel"));
-    dlg.addButton(tr("Format"), true, DDialog::ButtonRecommend);
+    dlg.addButton(tr("Cancel","button"));
+    dlg.addButton(tr("Format","button"), true, DDialog::ButtonRecommend);
     dlg.setTitle(tr("To access the device, you must format the disk first. Are you sure you want to format it now?"));
     int code = dlg.exec();
     if (code == 1) {
@@ -1584,8 +1512,8 @@ int DialogManager::showStopScanningDialog()
 {
     DDialog dlg;
     dlg.setIcon(m_dialogWarningIcon);
-    dlg.addButton(tr("Cancel"));
-    dlg.addButton(tr("Stop"), true, DDialog::ButtonWarning); // 终止
+    dlg.addButton(tr("Cancel","button"));
+    dlg.addButton(tr("Stop","button"), true, DDialog::ButtonWarning); // 终止
     dlg.setTitle(tr("Scanning the device, stop it?")); // 正在扫描当前设备，是否终止扫描？
     return dlg.exec();
 }
@@ -1645,7 +1573,7 @@ void DialogManager::showAddUserShareFailedDialog(const QString &sharePath)
     DDialog d;
     d.setTitle(tr("Share folder can't be named after the current username"));
     d.setIcon(m_dialogWarningIcon);
-    d.addButton(tr("OK"), true, DDialog::ButtonRecommend);
+    d.addButton(tr("OK","button"), true, DDialog::ButtonRecommend);
     d.exec();
 }
 
