@@ -94,7 +94,7 @@ FilePreviewDialogStatusBar::FilePreviewDialogStatusBar(QWidget *parent)
     m_title->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     m_title->hide();
 
-    m_openButton = new QPushButton(QObject::tr("Open"), this);
+    m_openButton = new QPushButton(QObject::tr("Open","button"), this);
     m_openButton->setObjectName("OpenButton");
     QFont font = m_openButton->font();
     font.setPixelSize(12);
@@ -537,10 +537,10 @@ void FilePreviewDialog::switchToPage(int index)
 
     connect(preview, &DFMFilePreview::titleChanged, this, &FilePreviewDialog::updateTitle);
 
-    if (m_preview)
-        m_preview->deleteLater();
 
     if (m_preview) {
+        m_preview->contentWidget()->setVisible(false);
+        m_preview->deleteLater();
         static_cast<QVBoxLayout *>(layout())->removeWidget(m_preview->contentWidget());
     }
 
@@ -555,34 +555,21 @@ void FilePreviewDialog::switchToPage(int index)
     m_separator->setVisible(preview->showStatusBarSeparator());
     m_preview = preview;
 
-    QTimer::singleShot(0, this, [this] {
+     QTimer::singleShot(0, this, [this] {
         updateTitle();
         m_statusBar->openButton()->setFocus();
-        if (m_firstEnterSwitchToPage)
-        {
-            adjustSize();
-        } else
-        {
-            /*fix bug 48357 预览图片快速切换导致预览析构了定时器还在工作，使用智能指针对其进行判断*/
-            if (!m_preview) {
-                qDebug() << "switchToPage m_preview is null,so exit";
-                return;
-            }
-            if (m_preview->metaObject()->className() == QStringLiteral("dde_file_manager::VideoPreview")) {
-                adjustSize();
-            } else {
-                /*fix bug 45465 对视频和图片的切换进行size整理，adjustSize有不成功的可能，所以需要二次resize*/
-                this->resize(m_preview->contentWidget()->size().width(), m_preview->contentWidget()->size().height());
-                QSize end_zoompin = size();
-                adjustSize();
-                if (end_zoompin.width() > size().width()) {
-                    /*m_preview->contentWidget()->size().width() * 2 2和1.5是adjustSize的自适应值*/
-                    resize((double)m_preview->contentWidget()->size().width() * 2, (double)m_preview->contentWidget()->size().height() * 1.5);
-                } else if (end_zoompin.width() == size().width()) {
-                    resize(m_preview->contentWidget()->size().width(), m_preview->contentWidget()->size().height());
-                }
-            }
+        int perviewwidth = m_preview->contentWidget()->size().width();
+        int perviewheight = m_preview->contentWidget()->size().height();
+        this->resize(perviewwidth, perviewheight);
+        adjustSize();
+        m_preview->contentWidget()->adjustSize();
+        int newPerviewWidth = m_preview->contentWidget()->size().width();
+        int newPerviewHeight = m_preview->contentWidget()->size().height();
+
+        if(perviewwidth != newPerviewWidth || perviewheight != newPerviewHeight){
+            resize(newPerviewWidth, newPerviewHeight);
         }
+
         playCurrentPreviewFile();
         moveToCenter();
     });
