@@ -38,6 +38,7 @@
 #include "mountsecretdiskaskpassworddialog.h"
 #include "app/filesignalmanager.h"
 #include "shutil/fileutils.h"
+#include "utils.h"
 
 #include "networkmanager.h"
 #include "dfmapplication.h"
@@ -54,7 +55,11 @@
 #include <QJsonArray>
 #include <QProcess>
 #include <QStandardPaths>
+#include <QStorageInfo>
 #include <QRegularExpression>
+#include <dgiofile.h>
+
+#include <disomaster.h>
 
 #include <views/windowmanager.h>
 
@@ -76,13 +81,13 @@ MountSecretDiskAskPasswordDialog *GvfsMountManager::mountSecretDiskAskPasswordDi
 
 bool GvfsMountManager::AskedPasswordWhileMountDisk = false;
 
-QHash<GMountOperation *,DFMUrlBaseEvent*> GvfsMountManager::MountEventHash;
-QHash<GMountOperation *,QSharedPointer<QTimer>> GvfsMountManager::MountTimerHash;
-QHash<GMountOperation *,GCancellable *> GvfsMountManager::CancellHash;
-QHash<GMountOperation *,QSharedPointer<QEventLoop>> GvfsMountManager::eventLoopHash;
-QHash<GMountOperation *,bool> GvfsMountManager::AskingPasswordHash;
-QHash<GMountOperation *,MountAskPasswordDialog *> GvfsMountManager::askPasswordDialogHash;
-QHash<GMountOperation *,QJsonObject *> GvfsMountManager::SMBLoginObjHash;
+QHash<GMountOperation *, QSharedPointer<DFMUrlBaseEvent>> GvfsMountManager::MountEventHash;
+QHash<GMountOperation *, QSharedPointer<QTimer>> GvfsMountManager::MountTimerHash;
+QHash<GMountOperation *, GCancellable *> GvfsMountManager::CancellHash;
+QHash<GMountOperation *, QSharedPointer<QEventLoop>> GvfsMountManager::eventLoopHash;
+QHash<GMountOperation *, bool> GvfsMountManager::AskingPasswordHash;
+QHash<GMountOperation *, MountAskPasswordDialog *> GvfsMountManager::askPasswordDialogHash;
+QHash<GMountOperation *, QJsonObject *> GvfsMountManager::SMBLoginObjHash;
 
 //fix: 每次弹出光驱时需要删除临时缓存数据文件
 QString GvfsMountManager::g_qVolumeId = "sr0";
@@ -95,10 +100,6 @@ Q_LOGGING_CATEGORY(mountManager, "gvfs.mountMgr", QtInfoMsg)
 
 GvfsMountManager::GvfsMountManager(QObject *parent) : QObject(parent)
 {
-    if (getDialogManager(false)) {
-        connect(this, &GvfsMountManager::mount_added, dialogManager, &DialogManager::showNtfsWarningDialog);
-    }
-
     m_gVolumeMonitor = g_volume_monitor_get();
     qRegisterMetaType<QDrive>("QDrive");
 }
@@ -201,22 +202,25 @@ QDrive GvfsMountManager::gDriveToqDrive(GDrive *drive)
     return qDrive;
 }
 
-QVolume GvfsMountManager::gVolumeToqVolume(GVolume *volume)
+QVolume GvfsMountManager::gVolumeToqVolume(GVolume *gvolume)
 {
+    if (!gvolume)
+        return QVolume();
+
     QVolume qVolume;
     char *name;
     char **ids;
     GIcon *icon;
     GFile *activation_root;
 
-    name = g_volume_get_name(volume);
+    name = g_volume_get_name(gvolume);
     qVolume.setName(QString(name));
     g_free(name);
 
-    ids = g_volume_enumerate_identifiers(volume);
+    ids = g_volume_enumerate_identifiers(gvolume);
     if (ids && ids[0] != nullptr) {
         for (int i = 0; ids[i] != nullptr; i++) {
-            char *id = g_volume_get_identifier(volume, ids[i]);
+            char *id = g_volume_get_identifier(gvolume, ids[i]);
             if (QString(ids[i]) == G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE) {
                 qVolume.setUnix_device(QString(id));
             } else if (QString(ids[i]) == G_VOLUME_IDENTIFIER_KIND_LABEL) {
@@ -236,12 +240,12 @@ QVolume GvfsMountManager::gVolumeToqVolume(GVolume *volume)
     }
     g_strfreev(ids);
 
-    qVolume.setCan_mount(g_volume_can_mount(volume));
-    qVolume.setCan_eject(g_volume_can_eject(volume));
-    qVolume.setShould_automount(g_volume_should_automount(volume));
+    qVolume.setCan_mount(g_volume_can_mount(gvolume));
+    qVolume.setCan_eject(g_volume_can_eject(gvolume));
+    qVolume.setShould_automount(g_volume_should_automount(gvolume));
 
 
-    icon = g_volume_get_icon(volume);
+    icon = g_volume_get_icon(gvolume);
     if (icon) {
         if (G_IS_THEMED_ICON(icon)) {
             qVolume.setIcons(getIconNames(G_THEMED_ICON(icon)));
@@ -249,7 +253,7 @@ QVolume GvfsMountManager::gVolumeToqVolume(GVolume *volume)
         g_object_unref(icon);
     }
 
-    icon = g_volume_get_symbolic_icon(volume);
+    icon = g_volume_get_symbolic_icon(gvolume);
     if (icon) {
         if (G_IS_THEMED_ICON(icon)) {
             qVolume.setSymbolic_icons(getIconNames(G_THEMED_ICON(icon)));
@@ -257,7 +261,7 @@ QVolume GvfsMountManager::gVolumeToqVolume(GVolume *volume)
         g_object_unref(icon);
     }
 
-    GMount *mount = g_volume_get_mount(volume);
+    GMount *mount = g_volume_get_mount(gvolume);
     if (mount) {
         qVolume.setIsMounted(true);
         GFile *root = g_mount_get_root(mount);
@@ -268,7 +272,7 @@ QVolume GvfsMountManager::gVolumeToqVolume(GVolume *volume)
         g_free(uri);
     }
 
-    activation_root = g_volume_get_activation_root(volume);
+    activation_root = g_volume_get_activation_root(gvolume);
     if (activation_root != nullptr) {
         char *action_root_uri = g_file_get_uri(activation_root);
         qVolume.setActivation_root_uri(QString(action_root_uri));
@@ -276,7 +280,7 @@ QVolume GvfsMountManager::gVolumeToqVolume(GVolume *volume)
         g_free(action_root_uri);
     }
 
-    GDrive *gDrive = g_volume_get_drive(volume);
+    GDrive *gDrive = g_volume_get_drive(gvolume);
     if (gDrive) {
         QDrive qDrive = gDriveToqDrive(gDrive);
         qVolume.setDrive_unix_device(QString(g_drive_get_identifier(gDrive, "unix-device")));
@@ -286,24 +290,27 @@ QVolume GvfsMountManager::gVolumeToqVolume(GVolume *volume)
     return qVolume;
 }
 
-QMount GvfsMountManager::gMountToqMount(GMount *mount)
+QMount GvfsMountManager::gMountToqMount(GMount *gmount)
 {
+    if(!gmount)
+        return QMount();
+
     QMount qMount;
     char *name, *uri;
     GFile *root, *default_location;
     GIcon *icon;
 
-    name = g_mount_get_name(mount);
+    name = g_mount_get_name(gmount);
     qMount.setName(QString(name));
     g_free(name);
 
-    root = g_mount_get_root(mount);
+    root = g_mount_get_root(gmount);
     uri = g_file_get_uri(root);
     qMount.setMounted_root_uri(QString(uri));
     g_object_unref(root);
     g_free(uri);
 
-    default_location = g_mount_get_default_location(mount);
+    default_location = g_mount_get_default_location(gmount);
     if (default_location) {
         char *loc_uri = g_file_get_uri(default_location);
         qMount.setDefault_location(QString(loc_uri));
@@ -311,7 +318,7 @@ QMount GvfsMountManager::gMountToqMount(GMount *mount)
         g_object_unref(default_location);
     }
 
-    icon = g_mount_get_icon(mount);
+    icon = g_mount_get_icon(gmount);
     if (icon) {
         if (G_IS_THEMED_ICON(icon)) {
             qMount.setIcons(getIconNames(G_THEMED_ICON(icon)));
@@ -319,7 +326,7 @@ QMount GvfsMountManager::gMountToqMount(GMount *mount)
         g_object_unref(icon);
     }
 
-    icon = g_mount_get_symbolic_icon(mount);
+    icon = g_mount_get_symbolic_icon(gmount);
     if (icon) {
         if (G_IS_THEMED_ICON(icon)) {
             qMount.setSymbolic_icons(getIconNames(G_THEMED_ICON(icon)));
@@ -327,9 +334,9 @@ QMount GvfsMountManager::gMountToqMount(GMount *mount)
         g_object_unref(icon);
     }
 
-    qMount.setCan_unmount(g_mount_can_unmount(mount));
-    qMount.setCan_eject(g_mount_can_eject(mount));
-    qMount.setIs_shadowed(g_mount_is_shadowed(mount));
+    qMount.setCan_unmount(g_mount_can_unmount(gmount));
+    qMount.setCan_eject(g_mount_can_eject(gmount));
+    qMount.setIs_shadowed(g_mount_is_shadowed(gmount));
 
     return qMount;
 }
@@ -467,26 +474,42 @@ void GvfsMountManager::monitor_mount_removed_root(GVolumeMonitor *volume_monitor
     emit gvfsMountManager->volume_removed(diskInfo);
 }
 
-
-void GvfsMountManager::monitor_mount_added(GVolumeMonitor *volume_monitor, GMount *mount)
+void GvfsMountManager::monitor_mount_added(GVolumeMonitor *volume_monitor, GMount *gmount)
 {
     Q_UNUSED(volume_monitor)
     qCDebug(mountManager()) << "==============================monitor_mount_added==============================";
-    QMount qMount = gMountToqMount(mount);
-    GVolume *volume = g_mount_get_volume(mount);
+    QMount qMount = gMountToqMount(gmount);
+    GVolume *gvolume = g_mount_get_volume(gmount);
+    QVolume qVolume = gVolumeToqVolume(gvolume);
 
     //fix: 探测光盘推进,弹出和挂载状态机标识
     if (qMount.icons().contains("media-optical")) { //CD/DVD
-        DFMOpticalMediaWidget::g_mapCdStatusInfo[getVolTag(volume)].bMntFlag = true;
-        DFMOpticalMediaWidget::g_mapCdStatusInfo[getVolTag(volume)].bVolFlag = true;
-        //fix: 设置光盘容量属性
-        //DFMOpticalMediaWidget::setBurnCapacity(DFMOpticalMediaWidget::BCSA_BurnCapacityStatusAddMount);
+        QString volTag = getVolTag(gvolume);
+        DFMOpticalMediaWidget::g_mapCdStatusInfo[volTag].bMntFlag = true;
+        DFMOpticalMediaWidget::g_mapCdStatusInfo[volTag].bVolFlag = true;
+
+        // 对于光盘来说，执行挂载之后，一定是能够获取到 dp 对象的，在 actionMount 函数以及 setRootUrl 函数中，均请求了光盘的 dp 属性
+        DISOMasterNS::DeviceProperty dp = ISOMaster->getDevicePropertyCached(qVolume.unix_device());
+        if (dp.avail == 0) {
+            QString mpt = qMount.mounted_root_uri();
+            mpt.remove(FILE_ROOT);
+            mpt = mpt.startsWith("/") ? mpt : ("/" + mpt);
+            QStorageInfo info(mpt);
+            if (info.isValid()) {
+                quint64 total = static_cast<quint64>(info.bytesTotal());
+                DFMOpticalMediaWidget::g_mapCdStatusInfo[volTag].nTotal = total;
+                DFMOpticalMediaWidget::g_mapCdStatusInfo[volTag].nUsage = total;
+            }
+        } else {
+            DFMOpticalMediaWidget::g_mapCdStatusInfo[volTag].nTotal = dp.avail + dp.data;
+            DFMOpticalMediaWidget::g_mapCdStatusInfo[volTag].nUsage = dp.data;
+        }
     }
 
-    qCDebug(mountManager()) << "===================" << qMount.mounted_root_uri() << volume << "=======================";
+    qCDebug(mountManager()) << "===================" << qMount.mounted_root_uri() << gvolume << "=======================";
     qCDebug(mountManager()) << "===================" << qMount << "=======================";
-    if (volume != nullptr) {
-        QVolume qVolume = gVolumeToqVolume(volume);
+    if (gvolume != nullptr) {
+        QVolume qVolume = gVolumeToqVolume(gvolume);
         Volumes.insert(qVolume.unix_device(), qVolume);
 
         QDiskInfo diskInfo = qVolumeToqDiskInfo(qVolume);
@@ -515,6 +538,12 @@ void GvfsMountManager::monitor_mount_added(GVolumeMonitor *volume_monitor, GMoun
         }
     }
 
+    // when remote connection is mounted, reload computer model.
+    if (qMount.mounted_root_uri().startsWith("smb://")) {
+        QScopedPointer<DGioFile> file(DGioFile::createFromUri(qMount.mounted_root_uri()));
+        RemoteMountsStashManager::stashRemoteMount(file->path(), qMount.name());
+    }
+
     Mounts.insert(qMount.mounted_root_uri(), qMount);
 }
 
@@ -565,6 +594,11 @@ void GvfsMountManager::monitor_mount_removed(GVolumeMonitor *volume_monitor, GMo
         g_free(path);
         g_object_unref(root);
         emit fileSignalManager->requestCloseTab(durl);
+
+        if (qMount.mounted_root_uri().startsWith("smb://")) {
+            if (DFMApplication::genericAttribute(DFMApplication::GA_AlwaysShowOfflineRemoteConnections).toBool())
+                emit DFMApplication::instance()->reloadComputerModel();
+        }
     }
 }
 
@@ -610,6 +644,7 @@ void GvfsMountManager::monitor_volume_added(GVolumeMonitor *volume_monitor, GVol
     if (qVolume.icons().contains("media-optical")) { //CD/DVD
         DFMOpticalMediaWidget::g_mapCdStatusInfo[getVolTag(volume)].bMntFlag = false;
         DFMOpticalMediaWidget::g_mapCdStatusInfo[getVolTag(volume)].bVolFlag = true;
+        DFMOpticalMediaWidget::g_mapCdStatusInfo[getVolTag(volume)].bBurningOrErasing = false;
         //fix: 设置光盘容量属性
         DFMOpticalMediaWidget::setBurnCapacity(DFMOpticalMediaWidget::BCSA_BurnCapacityStatusAdd, getVolTag(volume));
     }
@@ -657,7 +692,7 @@ void GvfsMountManager::monitor_volume_removed(GVolumeMonitor *volume_monitor, GV
     //fix: 探测光盘推进,弹出和挂载状态机标识
     if (qVolume.name().contains("CD/DVD") || qVolume.name().contains("CD") || qVolume.icons().contains("media-optical")) { //CD/DVD
         DFMOpticalMediaWidget::g_mapCdStatusInfo[getVolTag(volume)].bVolFlag = false;
-        DFMOpticalMediaWidget::g_mapCdStatusInfo[getVolTag(volume)].bBurningOrErasing = false;
+       // DFMOpticalMediaWidget::g_mapCdStatusInfo[getVolTag(volume)].bBurningOrErasing = false;
     }
 
     //fix: 每次弹出光驱时需要删除临时缓存数据文件
@@ -668,6 +703,10 @@ void GvfsMountManager::monitor_volume_removed(GVolumeMonitor *volume_monitor, GV
         DFMOpticalMediaWidget::g_mapCdStatusInfo[getVolTag(volume)].nUsage = 0;;
         DFMOpticalMediaWidget::setBurnCapacity(DFMOpticalMediaWidget::BCSA_BurnCapacityStatusEjct, getVolTag(volume));
         emit fileSignalManager->requestUpdateComputerView();
+
+        const static QString stagePrefix = QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + "/"
+                + qApp->organizationName() + "/" DISCBURN_STAGING "/";
+        clearStageDir(stagePrefix + qVolume.unix_device().replace("/", "_"));
     }
 
     GDrive *drive = g_volume_get_drive(volume);
@@ -783,7 +822,7 @@ void GvfsMountManager::ask_question_cb(GMountOperation *op, const char *message,
         qDebug() << newmsg;
     }
 
-    if (MountEventHash.contains(op)) {
+    if (MountEventHash.contains(op) && MountEventHash.value(op)) {
             choice = DThreadUtil::runInMainThread(requestAnswerDialog, MountEventHash.value(op)->windowId(), newmsg, choiceList);
         } else {
             choice = -1;
@@ -832,7 +871,7 @@ void GvfsMountManager::ask_password_cb(GMountOperation *op, const char *message,
             DThreadUtil::runInMainThread(dialogManager, &DialogManager::showErrorDialog,
                                         tr("Mounting device error"), tr("Wrong username or password"));
         //fix bug 63796,是sftp和ftp时，后面不会弹窗，所以这里要弹提示
-        if (!AskingPasswordHash.value(op) && MountEventHash.value(op)->fileUrl().scheme() != SMB_SCHEME)
+        if (!AskingPasswordHash.value(op) && MountEventHash.value(op) && MountEventHash.contains(op) && MountEventHash.value(op)->fileUrl().scheme() != SMB_SCHEME)
             DThreadUtil::runInMainThread(dialogManager, &DialogManager::showErrorDialog,
                                          tr("Mounting device error"), QString());
         return;
@@ -860,7 +899,7 @@ void GvfsMountManager::ask_password_cb(GMountOperation *op, const char *message,
     obj.insert("GAskPasswordFlags", flags);
     obj.insert("passwordSave", passwordSave);
     QJsonObject loginObj;
-    if (MountTimerHash.contains(op)) {
+    if (MountTimerHash.contains(op) && MountEventHash.value(op)) {
         loginObj = DThreadUtil::runInMainThread(requestPasswordDialog,
                                                 MountEventHash.value(op)->windowId(),
                                                 MountEventHash.value(op)->fileUrl().isSMBFile(), obj, op);
@@ -1297,7 +1336,7 @@ bool GvfsMountManager::errorCodeNeedSilent(int errorCode)
 
 /*
  * get real mount url from  mounted_root_uri of info
- * smb://10.0.12.150/share -> file:///run/user/1000/gvfs/smb-share:server=10.0.12.150,share=share
+ * smb://ttt;uos:1@xx.xx.xx.xx/io/path -> file:///run/user/1000/gvfs/smb-share:domain=ttt,server=xx.xx.xx.xx,share=io,user=uos/path
 */
 DUrl GvfsMountManager::getRealMountUrl(const QDiskInfo &info)
 {
@@ -1353,7 +1392,8 @@ void GvfsMountManager::cancellMountSync(GMountOperation *op)
         CancellHash.remove(op);
         if (cancell) {
             g_cancellable_cancel(cancell);
-            g_cancellable_release_fd(cancell);
+            //84859 g_cancellable_get_fd或g_cancellable_make_pollfd 后才能调用g_cancellable_release_fd
+            //g_cancellable_release_fd(cancell);
             g_object_unref(cancell);
         }
     }
@@ -1397,7 +1437,14 @@ void GvfsMountManager::mount(const QDiskInfo &diskInfo, bool silent)
 
 MountStatus GvfsMountManager::mount_sync(const DFMUrlBaseEvent &event)
 {
-    GFile *file = g_file_new_for_uri(event.fileUrl().toString().toUtf8().constData());
+    DUrl fileUrl = event.fileUrl();
+    // fix bug 100864 获取真实的网络挂载点
+    static const QRegExp rxPath(R"((^/[^/]+))");
+    if (rxPath.indexIn(fileUrl.path()) != -1) {
+        qInfo() << rxPath.cap(1);
+        fileUrl.setPath(rxPath.cap(1));
+    }
+    GFile *file = g_file_new_for_uri(fileUrl.toString().toUtf8().constData());
 
     if (file == nullptr)
         return MOUNT_FAILED;
@@ -1405,11 +1452,11 @@ MountStatus GvfsMountManager::mount_sync(const DFMUrlBaseEvent &event)
     GMountOperation *op = new_mount_op(false);
 
 
-    DFMUrlBaseEvent evettemp = event;
+    QSharedPointer<DFMUrlBaseEvent> evettemp(new DFMUrlBaseEvent(event));
 
-    MountEventHash.insert(op, &evettemp);
+    MountEventHash.insert(op, evettemp);
     QSharedPointer<QEventLoop> event_loop(new QEventLoop);
-    eventLoopHash.insert(op,event_loop);
+    eventLoopHash.insert(op, event_loop);
 
     QSharedPointer<QTimer> timer(new QTimer);
     MountTimerHash.insert(op,timer);
@@ -1434,7 +1481,6 @@ MountStatus GvfsMountManager::mount_sync(const DFMUrlBaseEvent &event)
     MountEventHash.remove(op);
     MountTimerHash.remove(op);
     if (CancellHash.value(op)) {
-        g_cancellable_release_fd(CancellHash.value(op));
         g_object_unref(CancellHash.value(op));
     }
     CancellHash.remove(op);
@@ -1472,9 +1518,11 @@ void GvfsMountManager::mount_done_cb(GObject *object, GAsyncResult *res, gpointe
 
     succeeded = g_file_mount_enclosing_volume_finish(G_FILE(object), res, &error);
 
+    DUrl rootUri = DUrl(g_file_get_uri(G_FILE (object)));
+
     if (!succeeded) {
         Q_ASSERT(error->domain == G_IO_ERROR);
-
+        emit fileSignalManager->requestRemoveSmbUrl(rootUri);
         bool showWarnDlg = false;
 
         switch (error->code) {
@@ -1519,7 +1567,7 @@ void GvfsMountManager::mount_done_cb(GObject *object, GAsyncResult *res, gpointe
     } else {
         qCDebug(mountManager()) << "g_file_mount_enclosing_volume_finish" << succeeded << AskingPasswordHash.value(op);
         if (AskingPasswordHash.value(op) && SMBLoginObjHash.value(op)) {
-            SMBLoginObjHash.value(op)->insert("id", MountEventHash.value(op)->url().toString());
+            SMBLoginObjHash.value(op)->insert("id", rootUri.toString());
             if (SMBLoginObjHash.value(op)->value("passwordSave").toInt() == 2) {
                 SMBLoginObjHash.value(op)->remove("password");
                 emit fileSignalManager->requsetCacheLoginData(*SMBLoginObjHash.value(op));
@@ -1735,7 +1783,7 @@ void GvfsMountManager::unmount_mounted(const QString &mounted_root_uri)
             DDialog error_dilaog(tr("The disk is mounted by user \"%1\", you cannot unmount it.").arg(user_name), QString(" "));
 
             error_dilaog.setIcon(QIcon::fromTheme("dialog-error"));
-            error_dilaog.addButton(tr("Confirm"), true, DDialog::ButtonRecommend);
+            error_dilaog.addButton(tr("Confirm","button"), true, DDialog::ButtonRecommend);
             error_dilaog.setModal(true);
             error_dilaog.exec();
             return;
@@ -1743,13 +1791,16 @@ void GvfsMountManager::unmount_mounted(const QString &mounted_root_uri)
 
         DDialog error_dilaog(tr("Cannot find the mounted device"), QString(error->message));
 
+        g_error_free(error);
+
         error_dilaog.setIcon(QIcon::fromTheme("dialog-error"));
-        error_dilaog.addButton(tr("Confirm"), true, DDialog::ButtonRecommend);
+        error_dilaog.addButton(tr("Confirm","button"), true, DDialog::ButtonRecommend);
         error_dilaog.setModal(true);
         error_dilaog.exec();
         return;
     }
 
+    g_error_free(error);
     char *local_mount_point = g_file_get_path(file);
 
     mount_op = new_mount_op();
@@ -1770,7 +1821,7 @@ void GvfsMountManager::unmount_done_cb(GObject *object, GAsyncResult *res, gpoin
         DDialog error_dilaog(tr("Cannot unmount the device"), QString(error->message));
 
         error_dilaog.setIcon(QIcon::fromTheme("dialog-error"));
-        error_dilaog.addButton(tr("Confirm"), true, DDialog::ButtonRecommend);
+        error_dilaog.addButton(tr("Confirm","button"), true, DDialog::ButtonRecommend);
         error_dilaog.setModal(true);
         error_dilaog.exec();
     } else {
@@ -1889,7 +1940,7 @@ void GvfsMountManager::eject_with_device_file_cb(GObject *object, GAsyncResult *
                              QString(error->message));
 
         error_dilaog.setIcon(QIcon::fromTheme("dialog-error"));
-        error_dilaog.addButton(tr("Confirm"), true, DDialog::ButtonRecommend);
+        error_dilaog.addButton(tr("Confirm","button"), true, DDialog::ButtonRecommend);
         error_dilaog.setModal(true);
         error_dilaog.exec();
     } else {
@@ -1911,14 +1962,14 @@ void GvfsMountManager::eject_mounted(const QString &mounted_root_uri)
     GMount *mount = g_file_find_enclosing_mount(file, nullptr, &error);
     if (mount == nullptr) {
         DDialog error_dilaog(tr("Cannot find the mounted device"), QString(error->message));
-
+        g_error_free(error);
         error_dilaog.setIcon(QIcon::fromTheme("dialog-error"));
-        error_dilaog.addButton(tr("Confirm"), true, DDialog::ButtonRecommend);
+        error_dilaog.addButton(tr("Confirm","button"), true, DDialog::ButtonRecommend);
         error_dilaog.setModal(true);
         error_dilaog.exec();
         return;
     }
-
+    g_error_free(error);
     GMountOperation *mount_op = new_mount_op();
     g_mount_eject_with_operation(mount, G_MOUNT_UNMOUNT_NONE, mount_op, nullptr, &GvfsMountManager::eject_with_mounted_file_cb, nullptr);
     g_object_unref(mount_op);
