@@ -846,6 +846,7 @@ QVector<MenuAction> DAbstractFileInfo::menuActionList(DAbstractFileInfo::MenuTyp
                    << MenuAction::SortBy
                    << MenuAction::OpenAsAdmin
                    << MenuAction::OpenInTerminal
+                   << MenuAction::RefreshView
                    << MenuAction::Separator
                    << MenuAction::Paste
                    << MenuAction::SelectAll
@@ -942,14 +943,14 @@ QVector<MenuAction> DAbstractFileInfo::menuActionList(DAbstractFileInfo::MenuTyp
                        << MenuAction::SendToDesktop;
 
             if (deviceListener->getCanSendDisksByUrl(absoluteFilePath()).count() > 0
-                    || bluetoothManager->model()->adapters().count() > 0) {
+                    || bluetoothManager->hasAdapter()) {
                 actionKeys << MenuAction::SendToRemovableDisk;
             }
 
             DDiskManager diskm;
             for (auto &devs : diskm.diskDevices()) {
                 QScopedPointer<DDiskDevice> dev(DDiskManager::createDiskDevice(devs));
-                if (dev->mediaCompatibility().join(' ').contains("_r")) {
+                if (dev->mediaCompatibility().join(' ').contains("_r") && dev->optical()) {
                     actionKeys << MenuAction::StageFileForBurning;
                     break;
                 }
@@ -1016,14 +1017,14 @@ QVector<MenuAction> DAbstractFileInfo::menuActionList(DAbstractFileInfo::MenuTyp
                    << MenuAction::SendToDesktop;
 
         if (deviceListener->getCanSendDisksByUrl(absoluteFilePath()).count() > 0
-                || bluetoothManager->model()->adapters().count() > 0) {
+                || bluetoothManager->hasAdapter()) {
             actionKeys << MenuAction::SendToRemovableDisk;
         }
 
         DDiskManager diskm;
         for (auto &devs : diskm.diskDevices()) {
             QScopedPointer<DDiskDevice> dev(DDiskManager::createDiskDevice(devs));
-            if (dev->mediaCompatibility().join(' ').contains("_r")) {
+            if (dev->mediaCompatibility().join(' ').contains("_r") && dev->optical()) {
                 actionKeys << MenuAction::StageFileForBurning;
                 break;
             }
@@ -1349,7 +1350,7 @@ QString DAbstractFileInfo::suffix() const
     QString strSuffix;
     while (strSuffix.isEmpty()) {
         nIdx = tmpName.lastIndexOf(".");
-        if (nIdx == -1)
+        if (nIdx == -1 || nIdx == 0)
             return QString();
         strSuffix = tmpName.mid(nIdx + 1);
         tmpName = tmpName.mid(0, nIdx);
@@ -1727,7 +1728,7 @@ QMap<MenuAction, QVector<MenuAction> > DAbstractFileInfo::subMenuActionList(Menu
     actions.insert(MenuAction::SortBy, sortByMenuActionKeys);
 
     if (deviceListener->isMountedRemovableDiskExits()
-            || bluetoothManager->model()->adapters().count() > 0) {
+            || bluetoothManager->hasAdapter()) {
         QVector<MenuAction> diskMenuActionKeys;
         actions.insert(MenuAction::SendToRemovableDisk, diskMenuActionKeys);
     }
@@ -1735,7 +1736,7 @@ QMap<MenuAction, QVector<MenuAction> > DAbstractFileInfo::subMenuActionList(Menu
     DDiskManager diskm;
     for (auto &drvs : diskm.diskDevices()) {
         QScopedPointer<DDiskDevice> drv(DDiskManager::createDiskDevice(drvs));
-        if (drv->mediaCompatibility().join(' ').contains("_r")) {
+        if (drv->mediaCompatibility().join(' ').contains("_r") && drv->optical()) {
             actions.insert(MenuAction::StageFileForBurning, {});
             break;
         }
@@ -1755,10 +1756,10 @@ QSet<MenuAction> DAbstractFileInfo::disableMenuActionList() const
     }
 
     if (!canRename()) {
-        list << MenuAction::Cut << MenuAction::Rename << MenuAction::Delete;
+        list << MenuAction::Cut << MenuAction::Rename << MenuAction::Delete << MenuAction::CompleteDeletion;
     }
 
-    if (isVirtualEntry()) {
+    if (isVirtualEntry() || (!isReadable() && !isSymLink())) {
         list << MenuAction::Copy;
     }
 
