@@ -62,6 +62,11 @@
 #include "customization/dcustomactionbuilder.h"
 #include "customization/dcustomactionparser.h"
 #include "gvfs/gvfsmountmanager.h"
+#include "extensionimpl/dfmextpluginmanager.h"
+#include "extensionimpl/dfmextmenuimplproxy.h"
+#include "extensionimpl/dfmextmenuimpl.h"
+#include "extensionimpl/dfmextmendefine.h"
+#include "extensionimpl/private/dfmextmenuimpl_p.h"
 
 #include <DSysInfo>
 
@@ -99,6 +104,7 @@ static DCustomActionParser *customMenuParser = nullptr;
 
 void initData();
 void initActions();
+void clearActions();
 
 MenuAction takeAvailableUserActionType()
 {
@@ -124,7 +130,15 @@ void recycleUserActionType(MenuAction type)
     if (action) {
         actionToMenuAction.remove(action);
     }
+    if (DFileMenuManager::needDeleteAction())
+        delete action;
 }
+
+DFMExtMenuImpl *createMenuImpl(QMenu *menu)
+{
+    return new DFMExtMenuImpl(menu);
+}
+
 }
 
 DFileMenu *DFileMenuManager::createDefaultBookMarkMenu(const QSet<MenuAction> &disableList)
@@ -183,23 +197,22 @@ DFileMenu *DFileMenuManager::createNormalMenu(const DUrl &currentUrl, const DUrl
         return menu;
     }
 
-    bool enableSendToBluetooth = true; // feat 蓝牙：当选中的列表中包含文件夹时不予启用蓝牙发送选项
     //! urlList中有保险箱的DUrl需要进行转换否则会出现报错或功能不可用
     DUrlList urls = urlList;
     for (int i = 0; i < urlList.size(); ++i) {
-        if (urlList[i].isVaultFile()) {
+        if (urlList[i].isVaultFile())
             urls[i] = VaultController::vaultToLocalUrl(urlList[i]);
-
-        }
-
-        // feat 蓝牙：当选中的列表中包含文件夹时不予启用蓝牙发送选项
-        if (bluetoothManager->model()->adapters().count() > 0 && enableSendToBluetooth) {
-            DAbstractFileInfoPointer file_info = fileService->createFileInfo(nullptr, urls[i]);
-            if (file_info && file_info->isDir())
-                enableSendToBluetooth = false;
-        }
     }
 
+    auto dirInUrls = [](const DUrlList &urls) {
+        for (const auto &url: urls) {
+            auto fileInfo = fileService->createFileInfo(nullptr, url);
+            if (fileInfo && fileInfo->isDir())
+                return true;
+        }
+        return false;
+    };
+
     DUrlList redirectedUrlList;
     if (urls.length() == 1) {
         QVector<MenuAction> actions = info->menuActionList(DAbstractFileInfo::SingleFile);
@@ -435,14 +448,14 @@ DFileMenu *DFileMenuManager::createNormalMenu(const DUrl &currentUrl, const DUrl
         }
 
         QAction *action = new QAction(fileMenuManger->getActionString(MenuAction::OpenWithCustom), openWithMenu);
-        action->setData((int)MenuAction::OpenWithCustom);
+        action->setData(static_cast<int>(MenuAction::OpenWithCustom));
         openWithMenu->addAction(action);
         DFileMenuData::actions[MenuAction::OpenWithCustom] = action;
         DFileMenuData::actionToMenuAction[action] = MenuAction::OpenWithCustom;
     }
 
     if (deviceListener->isMountedRemovableDiskExits()
-            || bluetoothManager->model()->adapters().count() > 0) {
+            || bluetoothManager->hasAdapter()) {
         QAction *sendToMountedRemovableDiskAction = menu->actionAt(DFileMenuManager::getActionString(DFMGlobal::SendToRemovableDisk));
         if (currentUrl.path().contains("/dev/sr")
                 || (currentUrl.scheme() == SEARCH_SCHEME && currentUrl.query().contains("/dev/sr"))) // 禁用光盘搜索列表中的发送到选项
@@ -451,13 +464,15 @@ DFileMenu *DFileMenuManager::createNormalMenu(const DUrl &currentUrl, const DUrl
             DFileMenu *sendToMountedRemovableDiskMenu = sendToMountedRemovableDiskAction ? qobject_cast<DFileMenu *>(sendToMountedRemovableDiskAction->menu()) : Q_NULLPTR;
             if (sendToMountedRemovableDiskMenu) {
                 // 如果有蓝牙设备并且当前文件不在保险箱内
-                if ((bluetoothManager->model()->adapters().count() > 0) && !VaultController::isVaultFile(currentUrl.toLocalFile())) {
-                        QAction *sendToBluetooth = new QAction(DFileMenuManager::getActionString(DFMGlobal::SendToBluetooth), sendToMountedRemovableDiskMenu);
-                        sendToBluetooth->setProperty("urlList", DUrl::toStringList(urls));
-                        sendToMountedRemovableDiskMenu->addAction(sendToBluetooth);
-                        connect(sendToBluetooth, &QAction::triggered, appController, &AppController::actionSendToBluetooth);
-                        if (!enableSendToBluetooth)
-                            sendToBluetooth->setEnabled(false);
+                if (BluetoothManager::bluetoothSendEnable() // is system disabled "sending via bluetooth"
+                        && bluetoothManager->hasAdapter()
+                        && !VaultController::isVaultFile(currentUrl.toLocalFile())) {
+                    QAction *sendToBluetooth = new QAction(DFileMenuManager::getActionString(DFMGlobal::SendToBluetooth), sendToMountedRemovableDiskMenu);
+                    sendToBluetooth->setProperty("urlList", DUrl::toStringList(urls));
+                    sendToMountedRemovableDiskMenu->addAction(sendToBluetooth);
+                    connect(sendToBluetooth, &QAction::triggered, appController, &AppController::actionSendToBluetooth);
+                    if (dirInUrls(urls))
+                        sendToBluetooth->setEnabled(false);
                 }
 
                 foreach (UDiskDeviceInfoPointer pDeviceinfo, deviceListener->getCanSendDisksByUrl(currentUrl.toLocalFile()).values()) {
@@ -809,7 +824,7 @@ void DFileMenuData::initData()
     actionKeys[MenuAction::CreateSymlink] = QObject::tr("Create link");
     actionKeys[MenuAction::SendToDesktop] = QObject::tr("Send to desktop");
     actionKeys[MenuAction::SendToRemovableDisk] = QObject::tr("Send to");
-    actionKeys[MenuAction::SendToBluetooth] = QObject::tr("Send to Bluetooth");
+    actionKeys[MenuAction::SendToBluetooth] = QObject::tr("Bluetooth");
     actionKeys[MenuAction::AddToBookMark] = QObject::tr("Add to bookmark");
     actionKeys[MenuAction::Delete] = QObject::tr("Delete");
     actionKeys[MenuAction::CompleteDeletion] = QObject::tr("Delete");
@@ -847,7 +862,7 @@ void DFileMenuData::initData()
     actionKeys[MenuAction::ListView] = QObject::tr("List");
     actionKeys[MenuAction::ExtendView] = QObject::tr("Extend");
     actionKeys[MenuAction::SetAsWallpaper] = QObject::tr("Set as wallpaper");
-    actionKeys[MenuAction::ForgetPassword] = QObject::tr("Log out and unmount");
+    actionKeys[MenuAction::ForgetPassword] = QObject::tr("Clear saved password and unmount");
     actionKeys[MenuAction::DeletionDate] = QObject::tr("Time deleted");
     actionKeys[MenuAction::SourcePath] = QObject::tr("Source path");
     actionKeys[MenuAction::AbsolutePath] = QObject::tr("Path");
@@ -903,12 +918,15 @@ void DFileMenuData::initData()
         actionIcons[MenuAction::CreateSymlink] = QIcon::fromTheme("insert-link");
         actionIcons[MenuAction::Property] = QIcon::fromTheme("document-properties");
     }
+
+    actionKeys[MenuAction::RemoveStashedRemoteConn] = QObject::tr("Remove");
+    actionKeys[MenuAction::RefreshView] = QObject::tr("Refresh");
 }
 
 void DFileMenuData::initActions()
 {
     QList<MenuAction> unCachedActions;
-    unCachedActions << MenuAction::NewWindow;
+    unCachedActions << MenuAction::NewWindow << MenuAction::RefreshView;
     foreach (MenuAction key, actionKeys.keys()) {
         if (unCachedActions.contains(key)) {
             continue;
@@ -953,7 +971,28 @@ void DFileMenuData::initActions()
         actionToMenuAction.insert(action, key);
     }
 
-    additionalMenu = new DFMAdditionalMenu;
+    additionalMenu = new DFMAdditionalMenu();
+}
+
+/**
+ * @brief 谨慎调用!!! 该函数用于ut清理action用, 其它地方调用后果自负
+ * @param
+ * @return
+ */
+void DFileMenuData::clearActions()
+{
+    for (const auto &menu : actions.keys()) {
+        QAction *action = actions.take(menu);
+        actionToMenuAction.remove(action);
+        delete action;
+    }
+    actions.clear();
+    actionToMenuAction.clear();
+}
+
+bool DFileMenuManager::needDeleteAction()
+{
+    return false;
 }
 
 DFileMenu *DFileMenuManager::genereteMenuByKeys(const QVector<MenuAction> &keys,
@@ -976,10 +1015,12 @@ DFileMenu *DFileMenuManager::genereteMenuByKeys(const QVector<MenuAction> &keys,
             if (action) {
                 DFileMenuData::actionToMenuAction.remove(action);
             }
+            if (needDeleteAction())
+                delete action;
         }
     }
 
-    DFileMenu *menu = new DFileMenu;
+    DFileMenu *menu = new DFileMenu();
 
     if (!isRecursiveCall) {
         connect(menu, &DFileMenu::triggered, fileMenuManger, &DFileMenuManager::actionTriggered);
@@ -1194,6 +1235,44 @@ void DFileMenuManager::extendCustomMenu(DFileMenu *menu, bool isNormal, const DU
     }
 }
 
+void DFileMenuManager::extensionPluginCustomMenu(DFileMenu *menu,
+                                                 bool isNormal,
+                                                 const DUrl currentUrl,
+                                                 const DUrl focusFile,
+                                                 const DUrlList &selected,
+                                                 bool onDesktop)
+{
+    if(!menu)
+        return;
+
+    DFMGlobal::autoInitExtPluginManager();
+
+    std::string newCurrentUrl = currentUrl.toString().toStdString();
+    std::string newFocusUrl = focusFile.toString().toStdString();
+
+    //生命周期与DFileMene绑定
+    DFMExtMenuImplPrivate *extMenuImplPrivate = DFMExt_Get_MenuPrivate(menu);
+    DFMExtMenuImpl *extMenuImpl = nullptr;
+    if (!extMenuImplPrivate) {
+        extMenuImpl = DFileMenuData::createMenuImpl(menu);
+    } else {
+        extMenuImpl = extMenuImplPrivate->menuImpl();
+    }
+
+    for (auto val : DFMExtPluginManager::instance().menus()) {
+        val->initialize(DFMExtPluginManager::instance().pluginMenuProxy());
+        if (isNormal) {
+            std::list<std::string> newSection;
+            for (auto url : selected) { //导出所有的Durl到std::string
+                newSection.push_back(url.toString().toStdString());
+            }
+            val->buildNormalMenu(extMenuImpl, newCurrentUrl, newFocusUrl, newSection, onDesktop);
+        } else {
+            val->buildEmptyAreaMenu(extMenuImpl, newCurrentUrl, onDesktop);
+        }
+    }
+}
+
 /*
  * 自定义菜单在以下作用域时支持：
  * U盘盘内文件、移动硬盘盘内文件、桌面
@@ -1215,10 +1294,25 @@ bool DFileMenuManager::isCustomMenuSupported(const DUrl &viewRootUrl)
             && !viewRootUrl.isUserShareFile() //过滤共享文件
             && !deviceListener->isFileFromDisc(path) //过滤光盘
             && !viewRootUrl.isVaultFile() //过滤保险箱
-            && !viewRootUrl.isTrashFile();//过滤回收站
+            && !viewRootUrl.isTrashFile(); //过滤回收站
 
 }
 
+/*
+ * 需求，所有非虚拟路径下显示扩展菜单项(so菜单)
+*/
+bool DFileMenuManager::isExtensionsSupported(const DUrl &viewRootUrl)
+{
+    if (viewRootUrl.isTrashFile() || (VaultController::ins()->isVaultFile(viewRootUrl.path())))
+        return false;
+
+    DAbstractFileInfoPointer info = DFileService::instance()->createFileInfo(nullptr, viewRootUrl);
+    if ((!info) || info->isVirtualEntry())
+        return false;
+
+    return true;
+}
+
 void DFileMenuManager::addActionWhitelist(MenuAction action)
 {
     DFileMenuData::whitelist << action;
@@ -1337,6 +1431,11 @@ bool DFileMenuManager::whetherShowTagActions(const QList<DUrl> &urls)
     return true;
 }
 
+void DFileMenuManager::clearActions()
+{
+    DFileMenuData::clearActions();
+}
+
 void DFileMenuManager::actionTriggered(QAction *action)
 {
     qDebug() << action << action->data().isValid();
@@ -1413,7 +1512,16 @@ void DFileMenuManager::actionTriggered(QAction *action)
                 //批量标记操作耗时较长，同步事件处理会使menu.exec结束等待时间过长，频繁操作下会引起崩溃
                 //右键菜单本身对标记操作没有同步等待结果的需求，所以直接采用异步事件处理标记操作
                 if (type == MenuAction::TagFilesUseColor) {
-                    DFMEventDispatcher::instance()->processEventAsync(event);
+                    //异步事件处理存在menu对象先被析构的情况，这里将标记所需的数据先取出来放在event中
+                    //fileeventprocessor中直接从event中取数据
+                    QAction *action{ menu->actionAt("Add color tags") };
+                    if (QWidgetAction *widgetAction = qobject_cast<QWidgetAction *>(action)) {
+                        if (DTagActionWidget *tagWidget = qobject_cast<DTagActionWidget *>(widgetAction->defaultWidget())) {
+                            QList<QColor> colors{ tagWidget->checkedColorList() };
+                            event->setTagColors(colors);
+                            DFMEventDispatcher::instance()->processEventAsync(event);
+                        }
+                    }
                 } else {
                     DFMEventDispatcher::instance()->processEvent(event);
                 }
