@@ -69,7 +69,9 @@ class MenuActionEventHandler : public DFMAbstractEventHandler
 public:
     explicit MenuActionEventHandler(DFileViewHelper *helper)
         : DFMAbstractEventHandler(false)
-        , viewHelper(helper) {}
+        , viewHelper(helper)
+    {
+    }
 
     bool fmEventFilter(const QSharedPointer<DFMEvent> &event, DFMAbstractEventHandler *target, QVariant *resultData) override
     {
@@ -85,7 +87,10 @@ public:
         }
 
         const DFMMenuActionEvent &menu_event = dfmevent_cast<DFMMenuActionEvent>(*event.data());
-
+        if (menu_event.action() == DFMGlobal::MenuAction::RefreshView) {
+            viewHelper->viewFlicker();
+            return true;
+        }
         if (menu_event.action() != DFMGlobal::TagInfo)
             return false;
 
@@ -122,7 +127,7 @@ public:
     }
 
 private:
-    DFileViewHelper *viewHelper;
+    DFileViewHelper *viewHelper = nullptr;
 };
 
 class DFileViewHelperPrivate
@@ -138,6 +143,7 @@ public:
     ~DFileViewHelperPrivate()
     {
         delete menuEventHandler;
+        menuEventHandler = nullptr;
     }
 
     DFileViewHelperPrivate(DFileViewHelperPrivate &) = delete;
@@ -221,6 +227,12 @@ void DFileViewHelperPrivate::init()
     QObject::connect(cut_action, &QAction::triggered,
     q, [q] {
         // 只支持回收站根目录下的文件执行剪切
+        const DAbstractFileInfoPointer &rootInfo = fileService->createFileInfo(q, q->currentUrl());
+        if (!rootInfo || !rootInfo->isWritable()) {
+            qInfo() << "Read only folders do not support Ctrl + X operations！folders = " << q->currentUrl();
+            return;
+        }
+
         if (!q->selectedUrls().isEmpty()) {
             DUrl url = q->selectedUrls().first();
             if (url.isTrashFile() && url.parentUrl() != DUrl::fromTrashFile("/"))
@@ -280,8 +292,10 @@ QModelIndex DFileViewHelperPrivate::findIndex(const QByteArray &keys, bool match
     Q_Q(const DFileViewHelper);
 
     int row_count = q->parent()->model()->rowCount(q->parent()->rootIndex());
+    if (row_count == 0)
+        return QModelIndex();
 
-    for (int i = excludeCurrent ? 1 : 0; i < row_count; ++i) {
+    for (int i = excludeCurrent ? 1 : 0; i <= row_count; ++i) {
         int row = reverse_order ? row_count + current - i : current + i;
 
         row = row % row_count;
@@ -759,7 +773,7 @@ bool DFileViewHelper::isEmptyArea(const QPoint &pos) const
     return index.isValid();//true;
 }
 
-void DFileViewHelper:: preproccessDropEvent(QDropEvent *event) const
+void DFileViewHelper::preproccessDropEvent(QDropEvent *event) const
 {
     bool sameUser = DFMGlobal::isMimeDatafromCurrentUser(event->mimeData());
     if (event->source() == parent() && !DFMGlobal::keyCtrlIsPressed()) {
@@ -795,14 +809,20 @@ void DFileViewHelper:: preproccessDropEvent(QDropEvent *event) const
             default_action = Qt::MoveAction;
         } else if (!DFMGlobal::keyCtrlIsPressed()) {
             // 如果文件和目标路径在同一个分区下，默认为移动文件，否则默认为复制文件
-            if (DStorageInfo::inSameDevice(from, to) || to.isTrashFile()) {
+            if (DStorageInfo::inSameDevice(from, to)) {
                 default_action = Qt::MoveAction;
             }
         }
 
         //任意来源为回收站的drop操作均为move(统一回收站拖拽标准)
-        if (from.url().contains(".local/share/Trash/")) {
-            default_action = Qt::MoveAction;
+        bool isFromTrash = from.url().contains(".local/share/Trash/");
+        bool isToTrash = to.isTrashFile();
+        if (isFromTrash || isToTrash) {
+            if (!isFromTrash || !isToTrash) {
+                default_action = Qt::MoveAction;
+            } else {
+                return event->setDropAction(Qt::IgnoreAction);
+            }
         }
 
         if (event->possibleActions().testFlag(default_action)) {
@@ -824,24 +844,17 @@ void DFileViewHelper:: preproccessDropEvent(QDropEvent *event) const
             }
         }
 
-        // 保险箱时，修改DropAction为Qt::MoveAction
-        if (VaultController::isVaultFile(info->fileUrl().toString())
-                || VaultController::isVaultFile(urls[0].toString())) {
-            QString strFromPath = urls[0].toLocalFile();
-            QString strToPath = info->fileUrl().toLocalFile();
-            if (strFromPath.startsWith("/media") || strToPath.startsWith("/media")) { // 如果是从U盘拖拽文件到保险箱或者是从保险箱拖拽文件到U盘
-                event->setDropAction(Qt::CopyAction);
-            } else if (TRASH_SCHEME == info->fileUrl().scheme()) {  // 修复BUG-47739 保险箱拖拽到回收站时，忽略该操作
-                event->setDropAction(Qt::IgnoreAction);
-            } else if (strFromPath.startsWith("/run") && strFromPath.contains("/smb-share:server=")) {  // 修复BUG-59333 如果是smb拖拽到保险箱
-                event->setDropAction(Qt::CopyAction);
-            } else {
-                if (!DFMGlobal::keyCtrlIsPressed()) {
-                    event->setDropAction(Qt::MoveAction);
-                } else {
-                    event->setDropAction(Qt::CopyAction);
-                }
-            }
+        // 保险箱时，修改DropAction为Qt::CopyAction
+        if ((VaultController::isVaultFile(info->fileUrl().toString())
+             || VaultController::isVaultFile(urls[0].toString()))
+            && !isToTrash) {
+            event->setDropAction(Qt::CopyAction);
+        }
+
+        // 最近使用目录下的文件，只有拖拽到回收站为剪切，其他都为拷贝
+        if (from.isRecentFile()) {
+            default_action = isToTrash ? Qt::MoveAction : Qt::CopyAction;
+            event->setDropAction(default_action);
         }
     }
 }
@@ -879,29 +892,31 @@ void DFileViewHelper::preproccessDropEvent(QDropEvent *event, const QList<QUrl>
             default_action = Qt::MoveAction;
         } else if (!DFMGlobal::keyCtrlIsPressed()) {
             // 如果文件和目标路径在同一个分区下，默认为移动文件，否则默认为复制文件
-            if (DStorageInfo::inSameDevice(from, to) || to.isTrashFile()) {
+            if (DStorageInfo::inSameDevice(from, to)) {
                 default_action = Qt::MoveAction;
             }
         }
 
+        //任意来源为回收站的drop操作均为move(统一回收站拖拽标准)
+        bool isFromTrash = from.url().contains(".local/share/Trash/");
+        bool isToTrash = to.isTrashFile();
+
+        if (isFromTrash || isToTrash) {
+            if (!isFromTrash || !isToTrash) {
+                default_action = Qt::MoveAction;
+            } else {
+                return event->setDropAction(Qt::IgnoreAction);
+            }
+        }
+
         if (event->possibleActions().testFlag(default_action)) {
             event->setDropAction((default_action == Qt::MoveAction && !sameUser) ? Qt::IgnoreAction : default_action);
         }
 
-        // 保险箱时，修改DropAction为Qt::MoveAction
+        // 保险箱时，修改DropAction为Qt::CopyAction
         if (VaultController::isVaultFile(info->fileUrl().toString())
-                || VaultController::isVaultFile(urls[0].toString())) {
-            QString strFromPath = urls[0].toLocalFile();
-            QString strToPath = info->fileUrl().toLocalFile();
-            if (strFromPath.startsWith("/media") || strToPath.startsWith("/media")) { // 如果是从U盘拖拽文件到保险箱或者是从保险箱拖拽文件到U盘
-                event->setDropAction(Qt::CopyAction);
-            } else {
-                if (!DFMGlobal::keyCtrlIsPressed()) {
-                    event->setDropAction(sameUser ? Qt::MoveAction : Qt::IgnoreAction);
-                } else {
-                    event->setDropAction(Qt::CopyAction);
-                }
-            }
+            || VaultController::isVaultFile(urls[0].toString())) {
+            event->setDropAction(Qt::CopyAction);
         }
 
         if (!info->supportedDropActions().testFlag(event->dropAction())) {
@@ -918,6 +933,12 @@ void DFileViewHelper::preproccessDropEvent(QDropEvent *event, const QList<QUrl>
                 }
             }
         }
+
+        // 最近使用目录下的文件，只有拖拽到回收站为剪切，其他都为拷贝
+        if (from.isRecentFile()) {
+            default_action = isToTrash ? Qt::MoveAction : Qt::CopyAction;
+            event->setDropAction(default_action);
+        }
     }
 }
 
