@@ -339,7 +339,8 @@ public:
                          width() - TEXT_PADDING * 2 - margins.left() - margins.right(),
                          INT_MAX);
 
-        const QList<QRectF> &lines = delegate->drawText(index, &pa, option.text, label_rect, ICON_MODE_RECT_RADIUS,
+        QString str = delegate->displayFileName(index);
+        const QList<QRectF> &lines = delegate->drawText(index, &pa, str, label_rect, ICON_MODE_RECT_RADIUS,
                                                         option.palette.brush(QPalette::Normal, QPalette::Highlight),
                                                         QTextOption::WrapAtWordBoundaryOrAnywhere,
                                                         option.textElideMode, Qt::AlignCenter);
@@ -402,7 +403,8 @@ public:
                              width - TEXT_PADDING * 2,
                              INT_MAX);
 
-            const QList<QRectF> &lines = delegate->drawText(index, nullptr, option.text, label_rect, ICON_MODE_RECT_RADIUS, Qt::NoBrush,
+            QString str = delegate->displayFileName(index);
+            const QList<QRectF> &lines = delegate->drawText(index, nullptr, str, label_rect, ICON_MODE_RECT_RADIUS, Qt::NoBrush,
                                                             QTextOption::WrapAtWordBoundaryOrAnywhere, option.textElideMode, Qt::AlignCenter);
 
             textBounding = boundingRect(lines);
@@ -600,7 +602,13 @@ void DIconItemDelegate::paint(QPainter *painter,
             c.setAlpha(c.alpha() + 30);
         }
     } else if (option.state & QStyle::StateFlag::State_MouseOver) {
-        c = c.lighter();
+        DGuiApplicationHelper::ColorType ct = DGuiApplicationHelper::toColorType(base_color);
+        if (ct == DGuiApplicationHelper::DarkType) {
+            base_color = DGuiApplicationHelper::adjustColor(base_color, 0, 0, +5, 0, 0, 0, 0);
+            c = base_color;
+        }
+        else
+            c = c.lighter();
     } else if (!isCanvas) {
         c = base_color;
     }
@@ -654,7 +662,7 @@ void DIconItemDelegate::paint(QPainter *painter,
     /// draw file additional icon
 
     const QSizeF &cornerBaseSize = icon_rect.size() / 3;
-    QList<QRectF> cornerGeometryList = getCornerGeometryList(icon_rect, QSizeF(qMin(24.0, cornerBaseSize.width()), qMin(24.0, cornerBaseSize.height())));
+    QList<QRectF> cornerGeometryList = getCornerGeometryList(icon_rect, QSizeF(qMin(128.0, cornerBaseSize.width()), qMin(128.0, cornerBaseSize.height())));
     const QList<QIcon> &cornerIconList = parent()->additionalIcon(index);
 
     for (int i = 0; i < cornerIconList.count(); ++i) {
@@ -670,7 +678,7 @@ void DIconItemDelegate::paint(QPainter *painter,
         rc.moveTopRight(QPoint(option.rect.right() - 5, option.rect.top() + 5));
 
         DStyleOptionButton check;
-        check.state = DStyle::State_On;
+        check.state = DStyle::State_Enabled | DStyle::State_On;
         check.rect = rc;
 
         DApplication::style()->drawPrimitive(DStyle::PE_IndicatorItemViewItemCheck, &check, painter);
@@ -690,13 +698,20 @@ void DIconItemDelegate::paint(QPainter *painter,
         return;
     }
 
-    QString str = opt.text;
+    //icon模式下固定展示文件名
+    QString str = displayFileName(index);
 
     /// init file name geometry
     QRectF label_rect = opt.rect;
     label_rect.setTop(icon_rect.bottom() + TEXT_PADDING + ICON_MODE_ICON_SPACING);
-    label_rect.setWidth(opt.rect.width() - 2 * TEXT_PADDING - 2 * backgroundMargin - ICON_MODE_BACK_RADIUS);
-    label_rect.moveLeft(label_rect.left() + TEXT_PADDING + backgroundMargin + ICON_MODE_BACK_RADIUS / 2);
+    if (isCanvas) {
+        label_rect.setWidth(opt.rect.width() - 2 * TEXT_PADDING);
+        label_rect.moveLeft(label_rect.left() + TEXT_PADDING);
+    } else {
+        label_rect.setWidth(opt.rect.width() - 2 * TEXT_PADDING - 2 * backgroundMargin - ICON_MODE_BACK_RADIUS);
+        label_rect.moveLeft(label_rect.left() + TEXT_PADDING + backgroundMargin + ICON_MODE_BACK_RADIUS / 2);
+    }
+
     //限制当前文字在圆角背景之内，否则字体将超出背景绘制框
     label_rect.setBottom(path.boundingRect().toRect().bottom());
 
@@ -881,25 +896,6 @@ QWidget *DIconItemDelegate::createEditor(QWidget *parent, const QStyleOptionView
             return;
         }
 
-        //编辑字符的长度控制
-        int editTextMaxLen = item->maxCharSize();
-        int editTextCurrLen = item->edit->toPlainText().toLocal8Bit().size();
-        int editTextRangeOutLen = editTextCurrLen - editTextMaxLen;
-        if (editTextRangeOutLen > 0 && editTextMaxLen != INT_MAX) {
-            // fix bug 69627
-            QVector<uint> list = srcText.toUcs4();
-            int cursor_pos = item->edit->textCursor().position();
-            while (srcText.toLocal8Bit().size() > editTextMaxLen && cursor_pos > 0) {
-                list.removeAt(--cursor_pos);
-                srcText = QString::fromUcs4(list.data(), list.size());
-            }
-            item->edit->setPlainText(srcText);
-            QTextCursor cursor = item->edit->textCursor();
-            cursor.setPosition(cursor_pos);
-            item->edit->setTextCursor(cursor);
-            item->edit->setAlignment(Qt::AlignHCenter);
-        }
-
         //得到处理之后的文件名称
         QString dstText = DFMGlobal::preprocessingFileName(srcText);
 
@@ -920,9 +916,10 @@ QWidget *DIconItemDelegate::createEditor(QWidget *parent, const QStyleOptionView
 
             DFMGlobal::showAlertMessage(showPoint,
                                         color,
-                                        QObject::tr("\"\'/\\[]:|<>+=;,?* are not allowed"));
+                                        QObject::tr("%1 are not allowed").arg("|/\\*:\"'?<>"));
             //之前的光标Pos
             int srcCursorPos = item->edit->textCursor().position();
+            QSignalBlocker blocker(item->edit);
             item->edit->setPlainText(dstText);
             int endPos = srcCursorPos + (dstText.length() - srcText.length());
             //此处调整光标位置
@@ -932,6 +929,26 @@ QWidget *DIconItemDelegate::createEditor(QWidget *parent, const QStyleOptionView
             item->edit->setAlignment(Qt::AlignHCenter);
         }
 
+        //编辑字符的长度控制
+        int editTextMaxLen = item->maxCharSize();
+        int editTextCurrLen = dstText.toLocal8Bit().size();
+        int editTextRangeOutLen = editTextCurrLen - editTextMaxLen;
+        if (editTextRangeOutLen > 0 && editTextMaxLen != INT_MAX) {
+            // fix bug 69627
+            QVector<uint> list = dstText.toUcs4();
+            int cursor_pos = item->edit->textCursor().position();
+            while (dstText.toLocal8Bit().size() > editTextMaxLen && cursor_pos > 0) {
+                list.removeAt(--cursor_pos);
+                dstText = QString::fromUcs4(list.data(), list.size());
+            }
+            QSignalBlocker blocker(item->edit);
+            item->edit->setPlainText(dstText);
+            QTextCursor cursor = item->edit->textCursor();
+            cursor.setPosition(cursor_pos);
+            item->edit->setTextCursor(cursor);
+            item->edit->setAlignment(Qt::AlignHCenter);
+        }
+
         //根据文本调整edit高度
         item->resizeFromEditTextChanged();
 
@@ -1011,12 +1028,12 @@ void DIconItemDelegate::setEditorData(QWidget *editor, const QModelIndex &index)
         return;
 
     //获取当前是否显示文件后缀
-    bool donot_show_suffix{ DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffixOnRename).toBool() };
+    bool showSuffix{ DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffix).toBool() };
 
     if (item->edit->isReadOnly()) {
         item->edit->setPlainText(index.data(DFileSystemModel::FileDisplayNameRole).toString());
     } else {
-        if (donot_show_suffix) {
+        if (!showSuffix) {
             const QString &suffix = index.data(DFileSystemModel::FileSuffixOfRenameRole).toString();
 
             editor->setProperty("_d_whether_show_suffix", suffix);
@@ -1031,7 +1048,7 @@ void DIconItemDelegate::setEditorData(QWidget *editor, const QModelIndex &index)
 
     //　源文件名称不存在更改,此处会受到textChanged的更改出现光标重新计算(更改此处请慎重)
     QString srcText;
-    if (donot_show_suffix) {
+    if (!showSuffix) {
         srcText = index.data(DFileSystemModel::FileBaseNameOfRenameRole).toString();
     } else {
         srcText = index.data(DFileSystemModel::FileNameOfRenameRole).toString();
@@ -1060,7 +1077,7 @@ void DIconItemDelegate::setEditorData(QWidget *editor, const QModelIndex &index)
 
         DFMGlobal::showAlertMessage(showPoint,
                                     color,
-                                    QObject::tr("\"\'/\\[]:|<>+=;,?* are not allowed"));
+                                    QObject::tr("%1 are not allowed").arg("|/\\*:\"'?<>"));
 
         item->edit->setPlainText(dstText);
 
@@ -1119,9 +1136,13 @@ QList<QRect> DIconItemDelegate::paintGeomertys(const QStyleOptionViewItem &optio
     QRect label_rect = option.rect;
     bool isCanvas = parent()->property("isCanvasViewHelper").toBool();
     int backgroundMargin = isCanvas ? 0 : COLUMU_PADDING;
-
-    label_rect.setWidth(label_rect.width() - 2 * TEXT_PADDING - 2 * backgroundMargin - ICON_MODE_BACK_RADIUS);
-    label_rect.moveLeft(label_rect.left() + TEXT_PADDING + backgroundMargin + ICON_MODE_BACK_RADIUS / 2);
+    if (isCanvas) {
+        label_rect.setWidth(label_rect.width() - 2 * TEXT_PADDING);
+        label_rect.moveLeft(label_rect.left() + TEXT_PADDING);
+    } else {
+        label_rect.setWidth(label_rect.width() - 2 * TEXT_PADDING - 2 * backgroundMargin - ICON_MODE_BACK_RADIUS);
+        label_rect.moveLeft(label_rect.left() + TEXT_PADDING + backgroundMargin + ICON_MODE_BACK_RADIUS / 2);
+    }
     label_rect.setTop(icon_rect.bottom() + TEXT_PADDING + ICON_MODE_ICON_SPACING);
 
     QStyleOptionViewItem opt = option;
@@ -1291,6 +1312,18 @@ bool DIconItemDelegate::enabledTextShadow() const
     return d->enabledTextShadow;
 }
 
+QString DIconItemDelegate::displayFileName(const QModelIndex &index) const
+{
+    bool showSuffix{ DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffix).toBool() };
+    QString str = index.data(DFileSystemModel::FileDisplayNameRole).toString();
+    const QString &suffix = "." + index.data(DFileSystemModel::FileSuffixRole).toString();
+
+    if (!showSuffix && str.endsWith(suffix) && suffix != ".")
+        str = str.mid(0, str.length() - suffix.length());
+
+    return str;
+}
+
 void DIconItemDelegate::setFocusTextBackgroundBorderColor(QColor focusTextBackgroundBorderColor)
 {
     Q_D(DIconItemDelegate);
@@ -1321,6 +1354,7 @@ void DIconItemDelegate::initTextLayout(const QModelIndex &index, QTextLayout *la
                 const_cast<DIconItemDelegatePrivate *>(d)->document = new QTextDocument(const_cast<DIconItemDelegate *>(this));
 
             d->document->setPlainText(layout->text());
+            d->document->setDefaultFont(layout->font());
             layout->engine()->block = d->document->firstBlock();
         }
 
