@@ -23,6 +23,7 @@
 
 #include "dlistitemdelegate.h"
 #include "dfileviewhelper.h"
+#include "views/dfileview.h"
 #include "app/define.h"
 #include "dfilesystemmodel.h"
 #include "private/dstyleditemdelegate_p.h"
@@ -30,6 +31,8 @@
 #include "controllers/vaultcontroller.h"
 #include "dfmglobal.h"
 
+#include <DPalette>
+#include <DApplicationHelper>
 #include <QLabel>
 #include <QPainter>
 #include <QPainterPath>
@@ -39,13 +42,17 @@
 #include <QToolTip>
 #include <QPainterPath>
 
+#include <DPalette>
+#include <DApplicationHelper>
+
 #define ICON_SPACING 16
-#define LIST_MODE_RECT_RADIUS 2
+#define LIST_MODE_RECT_RADIUS 8
 #define LIST_EDITER_HEIGHT 22
 #define LIST_MODE_EDITOR_LEFT_PADDING -3
 #define LIST_VIEW_ICON_SIZE 24
 
 DFM_USE_NAMESPACE
+DWIDGET_USE_NAMESPACE
 
 class DListItemDelegatePrivate : public DFMStyledItemDelegatePrivate
 {
@@ -66,6 +73,59 @@ void DListItemDelegate::paint(QPainter *painter,
 {
     Q_D(const DListItemDelegate);
 
+    painter->save();//保存之前的绘制样式
+
+    //反走样抗锯齿
+    painter->setRenderHints(QPainter::Antialiasing
+                            |QPainter::TextAntialiasing
+                            |QPainter::SmoothPixmapTransform);
+    //绘制新的背景交替
+    if(option.widget){
+        //调色板获取
+        DPalette pl(DApplicationHelper::instance()->palette(option.widget));
+        //背板颜色获取
+        QColor baseColor = pl.color(DPalette::ColorGroup::Active, DPalette::ColorType::ItemBackground);
+        //获取item范围
+        auto itemRect = parent()->parent()->visualRect(index);
+        //左右间隔10 px UI设计要求 选中与交替渐变背景
+        QRect dstRect(itemRect.x() + LIST_MODE_LEFT_MARGIN,
+                      itemRect.y(),
+                      itemRect.width() - (LIST_MODE_LEFT_MARGIN + LIST_MODE_RIGHT_MARGIN),
+                      itemRect.height());
+        //取模设置当前的交替变化
+        if (index.row() % 2 == 1) {
+            //如果hover则设置高亮，不绘制交替色
+            if (option.state & QStyle::StateFlag::State_MouseOver) {
+                QColor adjustHoverItemColor = baseColor;//hover色 默认调整色保持背板颜色
+                //hover色保持背板%8
+                adjustHoverItemColor = DGuiApplicationHelper::adjustColor(baseColor, 0, 0, 0, 0, 0, 0, +8);
+                QPainterPath path;
+                path.addRoundedRect(dstRect, LIST_MODE_RECT_RADIUS, LIST_MODE_RECT_RADIUS);
+                painter->fillPath(path, adjustHoverItemColor);
+            } else { //绘制交替色
+                QColor adjustItemAlterColor = baseColor;//交替色 默认调整色保持背板颜色
+                //交替色保持背板色%5
+                adjustItemAlterColor = DGuiApplicationHelper::adjustColor(baseColor, 0, 0, 0, 0, 0, 0, +5);
+                QPainterPath path;
+                path.addRoundedRect(dstRect, LIST_MODE_RECT_RADIUS, LIST_MODE_RECT_RADIUS);//圆角8 UI要求
+                painter->fillPath(path, adjustItemAlterColor);
+            }
+        } else {
+            //如果hover则设置高亮，不保持默认背板
+            if (option.state & QStyle::StateFlag::State_MouseOver) {//设置hover高亮
+                QColor adjustHoverItemColor = baseColor;//hover色 默认调整色保持背板颜色
+                adjustHoverItemColor = DGuiApplicationHelper::adjustColor(baseColor, 0, 0, 0, 0, 0, 0, +8);
+                QPainterPath path;
+                path.addRoundedRect(dstRect, LIST_MODE_RECT_RADIUS, LIST_MODE_RECT_RADIUS);
+                //hover色保持背板%8
+                painter->fillPath(path, adjustHoverItemColor);
+            } else { //保持默认背板颜色
+                painter->setBrush(baseColor);
+            }
+        }
+    }
+    painter->restore(); //恢复之前的绘制，防止在此逻辑前的绘制丢失
+
     /// judgment way of the whether drag model(another way is: painter.devType() != 1)
     bool isDragMode = ((QPaintDevice *)parent()->parent()->viewport() != painter->device());
     bool isDropTarget = parent()->isDropTarget(index);
@@ -136,7 +196,6 @@ void DListItemDelegate::paint(QPainter *painter,
     opt.rect.setRight(opt.rect.right() - RIGHT_PADDING);
 
     /// draw icon
-
     QRect icon_rect = opt.rect;
 
     icon_rect.setSize(parent()->parent()->iconSize());
@@ -168,132 +227,98 @@ void DListItemDelegate::paint(QPainter *painter,
         cornerIconList.at(i).paint(painter, cornerGeometryList.at(i).toRect());
     }
 
-    column_x = icon_rect.right() + ICON_SPACING;
-
-    QRect rect = opt.rect;
-
-    rect.setLeft(column_x);
-
-    column_x = option.rect.x() + parent()->columnWidth(0) - 1 - parent()->fileViewViewportMargins().left();
-
-    rect.setRight(qMin(column_x, opt.rect.right()));
-
     if (columnRoleList.isEmpty())
         return;
-    int role = columnRoleList.at(0);
 
-    if (index != d->editingIndex || (role != DFileSystemModel::FileNameRole && role != DFileSystemModel::FileDisplayNameRole)) {
-        const QVariantHash &ep = index.data(DFileSystemModel::ExtraProperties).toHash();
-        const QList<QColor> &colors = qvariant_cast<QList<QColor>>(ep.value("colored"));
+    column_x = icon_rect.right();
 
-        if (!colors.isEmpty()) {
-            qreal diameter = 10;
-            QRectF tag_boundingRect(0, 0, (colors.size() + 1) * diameter / 2, diameter);
-
-            tag_boundingRect.moveCenter(rect.center());
-            tag_boundingRect.moveRight(rect.right());
-
-            paintCircleList(painter, tag_boundingRect, diameter, colors,
-                            (drawBackground || colors.size() > 1) ? Qt::white : QColor(0, 0, 0, 25));
-            rect.setRight(tag_boundingRect.left() - ICON_SPACING);
-        }
-
-        /// draw file name label
-        const QVariant &data = index.data(role);
-        painter->setPen(opt.palette.color(drawBackground ? QPalette::BrightText : QPalette::Text));
-        if (data.canConvert<QString>()) {
-            QString file_name;
-
-            do {
-                if (role != DFileSystemModel::FileNameRole && role != DFileSystemModel::FileDisplayNameRole) {
-                    break;
-                }
-
-                if (role == DFileSystemModel::FileDisplayNameRole) {
-                    const auto fileName = index.data(DFileSystemModel::FileNameRole);
-                    const auto file_display_name = index.data(DFileSystemModel::FileDisplayNameRole);
-
-                    if (fileName != file_display_name) {
-                        break;
-                    }
-                }
-
-                const QString &suffix = "." + index.data(DFileSystemModel::FileSuffixRole).toString();
-
-                if (suffix == ".") {
-                    break;
-                }
-
-                file_name = DFMGlobal::elideText(index.data(DFileSystemModel::FileBaseNameRole).toString().remove('\n'),
-                                                 QSize(rect.width() - opt.fontMetrics.width(suffix), rect.height()), QTextOption::WrapAtWordBoundaryOrAnywhere,
-                                                 opt.font, Qt::ElideRight,
-                                                 d->textLineHeight);
-                file_name.append(suffix);
-            } while (false);
-
-            if (file_name.isEmpty()) {
-                file_name = DFMGlobal::elideText(index.data(role).toString().remove('\n'),
-                                                 rect.size(), QTextOption::WrapAtWordBoundaryOrAnywhere,
-                                                 opt.font, Qt::ElideRight,
-                                                 d->textLineHeight);
-            }
-
-            painter->drawText(rect, Qt::Alignment(index.data(Qt::TextAlignmentRole).toInt()), file_name);
-        } else {
-            drawNotStringData(opt, d->textLineHeight, rect, data, drawBackground, painter, 0);
-        }
-    }
 
+    //绘制拖拽时的行
     if (isDragMode) {
+        QRect rect = opt.rect;
+        rect.setLeft(column_x);
+        column_x = option.rect.x() + parent()->columnWidth(0) - 1 - parent()->fileViewViewportMargins().left();
+        rect.setRight(qMin(column_x, opt.rect.right()));
+
+        for(const int &role : columnRoleList) {
+            if (role == DFileSystemModel::FileNameRole || role == DFileSystemModel::FileDisplayNameRole) {
+                paintFileName(painter, opt, index, role, rect, d->textLineHeight);
+                break;
+            }
+        }
         return;
     }
 
     const DFileSystemModel *model = qobject_cast<const DFileSystemModel *>(index.model());
-    if (isSelected)
-        painter->setPen(opt.palette.color(QPalette::Active, QPalette::HighlightedText));
-    else
-        painter->setPen(opt.palette.color(QPalette::Inactive, QPalette::Text));
 
-    for (int i = 1; i < columnRoleList.count(); ++i) {
+
+    for (int i = 0; i < columnRoleList.count(); ++i) {
         int column_width = parent()->columnWidth(i);
 
         if (column_width <= 0) {
             continue;
         }
 
-        QRect rec = opt.rect;
+        int rol = columnRoleList.at(i);
 
+        QRect rec = opt.rect;
         rec.setLeft(column_x + COLUMU_PADDING);
 
         if (rec.left() >= rec.right()) {
             break;
         }
 
-        column_x += column_width;
-
+        if (i == 0) {
+            column_x = option.rect.x() + column_width - 1 - parent()->fileViewViewportMargins().left();
+        } else {
+            column_x += column_width;
+        }
         rec.setRight(qMin(column_x, opt.rect.right()));
 
-        int rol = columnRoleList.at(i);
 
-        QModelIndex tmp_index = model->createIndex(index.row(), model->roleToColumn(rol), index.internalId());
+        if (rol == DFileSystemModel::FileNameRole || rol == DFileSystemModel::FileDisplayNameRole) {
+            //绘制标记
+            const QVariantHash &ep = index.data(DFileSystemModel::ExtraProperties).toHash();
+            const QList<QColor> &colors = qvariant_cast<QList<QColor>>(ep.value("colored"));
+            if (!colors.isEmpty()) {
+                qreal diameter = 10;
+                QRectF tag_boundingRect(0, 0, (colors.size() + 1) * diameter / 2, diameter);
 
-        const QVariant &data = index.data(rol);
+                tag_boundingRect.moveCenter(rec.center());
+                tag_boundingRect.moveRight(rec.right());
 
-        if (data.canConvert<QString>()) {
-            QString strInfo(index.data(rol).toString());
-            // 如果是文件路径项
-            if(rol == DFileSystemModel::FilePathRole) {
-                // 如果是保险箱路径,则不显示真实路径
-                if(VaultController::isVaultFile(strInfo))
-                    strInfo = VaultController::localPathToVirtualPath(index.data(rol).toString());
+                paintCircleList(painter, tag_boundingRect, diameter, colors,
+                                (drawBackground || colors.size() > 1) ? Qt::white : QColor(0, 0, 0, 25));
+                rec.setRight(tag_boundingRect.left() - ICON_SPACING);
             }
-            const QString &text = DFMGlobal::elideText(strInfo, rec.size(),
-                                                       QTextOption::NoWrap, opt.font,
-                                                       Qt::ElideRight, d->textLineHeight);
 
-            painter->drawText(rec, Qt::Alignment(tmp_index.data(Qt::TextAlignmentRole).toInt()), text);
+            paintFileName(painter, opt, index, rol, rec, d->textLineHeight);
         } else {
-            drawNotStringData(opt, d->textLineHeight, rec, data, drawBackground, painter, i);
+            if (isSelected)
+                painter->setPen(opt.palette.color(QPalette::Active, QPalette::HighlightedText));
+            else
+                painter->setPen(opt.palette.color(QPalette::Inactive, QPalette::Text));
+
+            QModelIndex tmp_index = model->createIndex(index.row(), model->roleToColumn(rol), index.internalId());
+
+            const QVariant &data = index.data(rol);
+
+            if (data.canConvert<QString>()) {
+                QString strInfo(index.data(rol).toString());
+                // 如果是文件路径项
+                if(rol == DFileSystemModel::FilePathRole) {
+                    // 如果是保险箱路径,则不显示真实路径
+                    if(VaultController::isVaultFile(strInfo))
+                        strInfo = VaultController::localPathToVirtualPath(index.data(rol).toString());
+                }
+                const QString &text = DFMGlobal::elideText(strInfo, rec.size(),
+                                                           QTextOption::NoWrap, opt.font,
+                                                           Qt::ElideRight, d->textLineHeight);
+
+                painter->drawText(rec, Qt::Alignment(tmp_index.data(Qt::TextAlignmentRole).toInt()), text);
+            } else {
+                drawNotStringData(opt, d->textLineHeight, rec, data, drawBackground, painter, i);
+            }
         }
     }
 
@@ -419,32 +444,14 @@ QWidget *DListItemDelegate::createEditor(QWidget *parent, const QStyleOptionView
         QString dstText = DFMGlobal::preprocessingFileName(srcText);
 
         //超出长度将不再被支持输入获取当前
-        bool donot_show_suffix{ DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffixOnRename).toBool() };
+        bool showSuffix{ DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffix).toBool() };
 
         //获取当前编辑框支持的最大文字长度
-        int textMaxLen = INT_MAX;
-        if (donot_show_suffix) {
+        int textMaxLen = MAX_FILE_NAME_CHAR_COUNT;
+        if (!showSuffix) {
             const QString &suffix = d->editingIndex.data(DFileSystemModel::FileSuffixOfRenameRole).toString();
             edit->setProperty("_d_whether_show_suffix", suffix);
             textMaxLen = MAX_FILE_NAME_CHAR_COUNT - suffix.toLocal8Bit().size() - (suffix.isEmpty() ? 0 : 1);
-        } else {
-            textMaxLen = MAX_FILE_NAME_CHAR_COUNT;
-        }
-
-        int textCurrLen = dstText.toLocal8Bit().size();
-        int textRangeOutLen = textCurrLen - textMaxLen;
-        //最大输入框字符控制逻辑
-        if (textRangeOutLen > 0) {
-            // fix bug 69627
-            QVector<uint> list = dstText.toUcs4();
-            int cursor_pos = edit->cursorPosition();
-            while (dstText.toLocal8Bit().size() > textMaxLen && cursor_pos > 0) {
-                list.removeAt(--cursor_pos);
-                dstText = QString::fromUcs4(list.data(), list.size());
-            }
-            edit->setText(dstText);
-            edit->setCursorPosition(cursor_pos);
-            return;
         }
 
         //如果存在非法字符且更改了当前的文本文件
@@ -467,12 +474,29 @@ QWidget *DListItemDelegate::createEditor(QWidget *parent, const QStyleOptionView
 
             DFMGlobal::showAlertMessage(showPoint,
                                         color,
-                                        QObject::tr("\"\'/\\[]:|<>+=;,?* are not allowed"));
+                                        QObject::tr("%1 are not allowed").arg("|/\\*:\"'?<>"));
 
             currPos += dstText.length() - srcText.length();
+            QSignalBlocker blocker(edit);
             edit->setText(dstText);
             edit->setCursorPosition(currPos);
         }
+
+        int textCurrLen = dstText.toLocal8Bit().size();
+        int textRangeOutLen = textCurrLen - textMaxLen;
+        //最大输入框字符控制逻辑
+        if (textRangeOutLen > 0) {
+            // fix bug 69627
+            QVector<uint> list = dstText.toUcs4();
+            int cursor_pos = edit->cursorPosition();
+            while (dstText.toLocal8Bit().size() > textMaxLen && cursor_pos > 0) {
+                list.removeAt(--cursor_pos);
+                dstText = QString::fromUcs4(list.data(), list.size());
+            }
+            QSignalBlocker blocker(edit);
+            edit->setText(dstText);
+            edit->setCursorPosition(cursor_pos);
+        }
     });
 
     edit->setFrame(false);
@@ -489,23 +513,27 @@ void DListItemDelegate::updateEditorGeometry(QWidget *editor, const QStyleOption
     int column_x = 0;
 
     /// draw icon
-
+    //计算编辑框左侧位置
     const QRect &opt_rect = option.rect + QMargins(-LIST_MODE_LEFT_MARGIN - LEFT_PADDING, 0, -LIST_MODE_RIGHT_MARGIN - RIGHT_PADDING, 0);
-
     QRect icon_rect = opt_rect;
-
     icon_rect.setSize(icon_size);
 
-    column_x = icon_rect.right() + ICON_SPACING + 1;
-
+    const QList<int> roleList = parent()->columnRoleList();
     QRect rect = opt_rect;
+    for (int i = 0; i < roleList.length(); ++i) {
+        if (roleList.at(i) == DFileSystemModel::FileNameRole || roleList.at(i) == DFileSystemModel::FileDisplayNameRole) {
+            int iconOffset = i == 0 ? icon_rect.right() + 1: 0;
 
-    rect.setLeft(column_x + LIST_MODE_EDITOR_LEFT_PADDING);
+            rect.setLeft(column_x + iconOffset);
+            column_x += parent()->columnWidth(i) - 1 - parent()->fileViewViewportMargins().left();
 
-    column_x = parent()->columnWidth(0) - 1 - parent()->fileViewViewportMargins().left();
-
-    rect.setRight(qMin(column_x, opt_rect.right()));
-    rect.setTop(opt_rect.y() + (opt_rect.height() - editor->height()) / 2);
+            rect.setRight(qMin(column_x, opt_rect.right()));
+            rect.setTop(opt_rect.y() + (opt_rect.height() - editor->height()) / 2);
+            break;
+        } else {
+            column_x += parent()->columnWidth(i);
+        }
+    }
 
     editor->setGeometry(rect);
 }
@@ -518,14 +546,12 @@ void DListItemDelegate::setEditorData(QWidget *editor, const QModelIndex &index)
         return;
     }
 
-    bool donot_show_suffix{ DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffixOnRename).toBool() };
-    QString text;
+    bool showSuffix{ DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffix).toBool() };
+    QString text = index.data(DFileSystemModel::FileNameOfRenameRole).toString();
 
-    if (donot_show_suffix) {
+    if (!showSuffix) {
         edit->setProperty("_d_whether_show_suffix", index.data(DFileSystemModel::FileSuffixOfRenameRole));
         text = index.data(DFileSystemModel::FileBaseNameOfRenameRole).toString();
-    } else {
-        text = index.data(DFileSystemModel::FileNameOfRenameRole).toString();
     }
 
     edit->setText(text);
@@ -639,13 +665,12 @@ bool DListItemDelegate::eventFilter(QObject *object, QEvent *event)
         if (!edit)
             return false;
 
-        bool notShowSuffix = DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffixOnRename).toBool();
+        bool showSuffix = DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffix).toBool();
         QString srcText;
-        if (notShowSuffix)
-        {
-            srcText = d->editingIndex.data(DFileSystemModel::FileBaseNameOfRenameRole).toString();
-        } else {
+        if (showSuffix) {
             srcText = d->editingIndex.data(DFileSystemModel::FileNameOfRenameRole).toString();
+        } else {
+            srcText = d->editingIndex.data(DFileSystemModel::FileBaseNameOfRenameRole).toString();
         }
 
         //得到处理之后的文件名称
@@ -655,7 +680,7 @@ bool DListItemDelegate::eventFilter(QObject *object, QEvent *event)
             //气泡提示
             DFMGlobal::showAlertMessage(edit->mapToGlobal(edit->pos()),
                                         parent()->parent()->palette().background().color(),
-                                        QObject::tr("\"\'/\\[]:|<>+=;,?* are not allowed"));
+                                        QObject::tr("%1 are not allowed").arg("|/\\*:\"'?<>"));
 
             //移动坐标
             auto srcBaseNameLength =  d->editingIndex.data(DFileSystemModel::FileBaseNameOfRenameRole).toString().length();
@@ -719,7 +744,22 @@ bool DListItemDelegate::helpEvent(QHelpEvent *event, QAbstractItemView *view, co
                 strtooltip.append("\n");
             }
             strtooltip.chop(1);
-            QToolTip::showText(event->globalPos(), strtooltip, view);
+
+            // fix bug 81894
+            const QList<QRect> &geometries = paintGeomertys(option, index);
+            const QList<int> colRoles = parent()->columnRoleList();
+            const QPoint &curPos = parent()->parent()->mapFromGlobal(event->globalPos());
+            for (int i = 1; i < geometries.length() && i <= colRoles.length(); ++i) {
+                auto curRect = geometries.at(i);
+
+                if (curRect.left() <= curPos.x() && curRect.right() >= curPos.x()) {
+                    // 真实的rect位置需要下移表头高度的距离
+                    int headerViewHeight = qobject_cast<DFileView *>(parent()->parent())->headerViewHeight();
+                    const QRect realRect(curRect.left(), curRect.top() + headerViewHeight, curRect.width(), curRect.height());
+                    QToolTip::showText(event->globalPos(), strtooltip, view, realRect);
+                    break;
+                }
+            }
         }
 
         return true;
@@ -727,3 +767,49 @@ bool DListItemDelegate::helpEvent(QHelpEvent *event, QAbstractItemView *view, co
 
     return DFMStyledItemDelegate::helpEvent(event, view, option, index);
 }
+
+void DListItemDelegate::paintFileName(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index, const int &role, const QRect &rect, const int &textLineHeight) const
+{
+    bool drawBackground =(option.state & QStyle::State_Selected) && option.showDecorationSelected;
+    const QVariant &data = index.data(role);
+    painter->setPen(option.palette.color(drawBackground ? QPalette::BrightText : QPalette::Text));
+    if (data.canConvert<QString>()) {
+        QString file_name;
+
+        do {
+            if (role != DFileSystemModel::FileNameRole && role != DFileSystemModel::FileDisplayNameRole)
+                break;
+
+            if (role == DFileSystemModel::FileDisplayNameRole) {
+                const auto fileName = index.data(DFileSystemModel::FileNameRole);
+                const auto file_display_name = index.data(DFileSystemModel::FileDisplayNameRole);
+
+                if (fileName != file_display_name)
+                    break;
+            }
+
+            const QString &suffix = "." + index.data(DFileSystemModel::FileSuffixRole).toString();
+            if (suffix == ".")
+                break;
+
+            file_name = DFMGlobal::elideText(index.data(DFileSystemModel::FileBaseNameRole).toString().remove('\n'),
+                                             QSize(rect.width() - option.fontMetrics.width(suffix), rect.height()), QTextOption::WrapAtWordBoundaryOrAnywhere,
+                                             option.font, Qt::ElideRight,
+                                             textLineHeight);
+            bool showSuffix{ DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffix).toBool() };
+            if (showSuffix)
+                file_name.append(suffix);
+        } while (false);
+
+        if (file_name.isEmpty()) {
+            file_name = DFMGlobal::elideText(index.data(role).toString().remove('\n'),
+                                             rect.size(), QTextOption::WrapAtWordBoundaryOrAnywhere,
+                                             option.font, Qt::ElideRight,
+                                             textLineHeight);
+        }
+
+        painter->drawText(rect, Qt::Alignment(index.data(Qt::TextAlignmentRole).toInt()), file_name);
+    } else {
+        drawNotStringData(option, textLineHeight, rect, data, drawBackground, painter, 0);
+    }
+}
