@@ -57,7 +57,8 @@ QSet<QString> schemeList = QSet<QString>() << QString(TRASH_SCHEME)
                            << QString(DAV_SCHEME)
                            << QString(TAG_SCHEME)
                            << QString(DFMVAULT_SCHEME) // 文件保险柜
-                           << QString(BURN_SCHEME);
+                           << QString(BURN_SCHEME)
+                           << QString(PLUGIN_SCHEME); // NOTE [XIAO]
 
 DUrl::DUrl()
     : QUrl()
@@ -242,6 +243,11 @@ bool DUrl::isVaultFile() const
     return (this->scheme() == DFMVAULT_SCHEME);
 }
 
+bool DUrl::isPluginFile() const
+{
+    return this->scheme() == PLUGIN_SCHEME;
+}
+
 QString DUrl::toString(QUrl::FormattingOptions options) const
 {
     if (!isValid()) {
