@@ -31,6 +31,7 @@
 #include "dfmrootfileinfo_p.h"
 #include "dfmapplication.h"
 #include "dfmsettings.h"
+#include "utils.h"
 
 #include <dgiofile.h>
 #include <dgiofileinfo.h>
@@ -159,6 +160,8 @@ bool DFMRootFileInfo::exists() const
         } else {
             return false;
         }
+    } else if (suffix() == SUFFIX_STASHED_REMOTE) {
+        return true;
     }
     return false; //默认返回false warning项
 }
@@ -185,6 +188,10 @@ QString DFMRootFileInfo::fileDisplayName() const
         return d->gmnt ? d->gmnt->name() : "";
     } else if (suffix() == SUFFIX_UDISKS) {
         return d->udispname;
+    } else if (suffix() == SUFFIX_STASHED_REMOTE) {
+        auto path = fileUrl().path();
+        path = RemoteMountsStashManager::normalizeConnUrl(path);
+        return RemoteMountsStashManager::getDisplayNameByConnUrl(path);
     }
     return baseName();
 }
@@ -300,6 +307,8 @@ DAbstractFileInfo::FileType DFMRootFileInfo::fileType() const
                 ret = ItemType::GvfsGPhoto2;
             }
         }
+    } else if (suffix() == SUFFIX_STASHED_REMOTE) {
+        ret = ItemType::NotConnRemote;
     } else if (d->mps.contains(QByteArray("/\0", 2))) {
         ret = ItemType::UDisksRoot;
     } else if (d->label == "_dde_data") {
@@ -351,6 +360,8 @@ QString DFMRootFileInfo::iconName() const
             }
         }
         return QString("drive-harddisk") + (d->encrypted ? "-encrypted" : "");
+    } else if (suffix() == SUFFIX_STASHED_REMOTE) {
+        return "folder-remote";
     }
     return "";
 }
@@ -365,7 +376,7 @@ QVector<MenuAction> DFMRootFileInfo::menuActionList(DAbstractFileInfo::MenuType
     if (suffix() == SUFFIX_USRDIR) {
         ret.push_back(MenuAction::OpenInNewWindow);
         ret.push_back(MenuAction::OpenInNewTab);
-    } else {
+    } else if (suffix() != SUFFIX_STASHED_REMOTE) { // DO NOT SHOW THESE ACTIONS FOR NOT CONNECTED REMOTE CONNECTION
         ret.push_back(MenuAction::OpenDiskInNewWindow);
         ret.push_back(MenuAction::OpenDiskInNewTab);
     }
@@ -438,6 +449,11 @@ QVector<MenuAction> DFMRootFileInfo::menuActionList(DAbstractFileInfo::MenuType
         }
     }
 
+    if (suffix() == SUFFIX_STASHED_REMOTE) {
+        ret.push_back(MenuAction::Mount);
+        ret.push_back(MenuAction::RemoveStashedRemoteConn);
+    }
+
     ret.push_back(MenuAction::Separator);
 
     ret.push_back(MenuAction::Property);
@@ -508,16 +524,18 @@ QVariantHash DFMRootFileInfo::extraProperties() const
         }
         ret["rooturi"] = d->gmnt && d->gmnt->getRootFile() ? d->gmnt->getRootFile()->uri() : "";
         ret["mounted"] = true;
+        ret["backer_url"] = d->backer_url;
     } else if (suffix() == SUFFIX_UDISKS) {
         if (d->mps.empty()) {
             ret["fsUsed"] = ~0ULL;
         } else {
             QStorageInfo si(d->mps.front());
-            ret["fsUsed"] = quint64(si.bytesTotal() - si.bytesFree());
-            ret["fsFreeSize"] = quint64(si.bytesFree());
+            ret["fsUsed"] = quint64(d->size) - quint64(si.bytesAvailable());
+            ret["fsFreeSize"] = quint64(si.bytesAvailable());
         }
         ret["fsSize"] = quint64(d->size);
         ret["fsType"] = d->fs;
+        ret["fsVersion"] = d->fsVersion;
         ret["encrypted"] = d->encrypted;
         ret["unlocked"] = !d->encrypted || d->ctblk;
         if (d->ctblk) {
@@ -578,59 +596,9 @@ void DFMRootFileInfo::checkCache()
     d->size = blk->size();
     d->label = blk->idLabel();
 
-    //FAT32的卷标编码为ascii，idLabel中取不到中文，这里需要从symlink中取出label
-    //symlink中的label编码有问题，这里做进一步处理
-    QString idVersion = blk->idVersion().toUpper();
-    if (idVersion == "FAT32") {
-        for (QByteArray ba : blk->symlinks()) {
-            QString link(ba);
-            if (link.contains("/by-label/") && link.contains("\\x")) {
-                QByteArray t_destByteArray;
-                QByteArray t_tmpByteArray;
-                for (int i = 0; i < ba.size(); i++) {
-                    if (92 == ba.at(i)) {
-                        if (4 == t_tmpByteArray.size()) {
-                            t_destByteArray.append(QByteArray::fromHex(t_tmpByteArray));
-                        } else {
-                            if (t_tmpByteArray.size() > 4) {
-                                t_destByteArray.append(QByteArray::fromHex(t_tmpByteArray.left(4)));
-                                t_destByteArray.append(t_tmpByteArray.mid(4));
-                            } else {
-                                t_destByteArray.append(t_tmpByteArray);
-                            }
-                        }
-                        t_tmpByteArray.clear();
-                        t_tmpByteArray.append(ba.at(i));
-                        continue;
-                    } else if (t_tmpByteArray.size() > 0) {
-                        t_tmpByteArray.append(ba.at(i));
-                        continue;
-                    } else {
-                        t_destByteArray.append(ba.at(i));
-                    }
-                }
-
-                if (4 == t_tmpByteArray.size()) {
-                    t_destByteArray.append(QByteArray::fromHex(t_tmpByteArray));
-                } else {
-                    if (t_tmpByteArray.size() > 4) {
-                        t_destByteArray.append(QByteArray::fromHex(t_tmpByteArray.left(4)));
-                        t_destByteArray.append(t_tmpByteArray.mid(4));
-                    } else {
-                        t_destByteArray.append(t_tmpByteArray);
-                    }
-                }
-
-                link = QTextCodec::codecForName("GBK")->toUnicode(t_destByteArray);
-
-                int idx = link.lastIndexOf("/", link.length() - 1);
-                d->label = link.mid(idx + 1);
-                break;
-            }
-        }
-    }
     loadDiskInfo();
     d->fs = blk->idType();
+    d->fsVersion = blk->idVersion();
     d->idUUID = blk->idUUID();
     d->udispname = canSetAlias() ? udisksDispalyAlias() : udisksDisplayName();
 
@@ -703,7 +671,9 @@ QString DFMRootFileInfo::udisksDisplayName()
 
     if (d->label.startsWith(ddeI18nSym)) {
         QString i18nKey = d->label.mid(ddeI18nSym.size(), d->label.size() - ddeI18nSym.size());
-        return qApp->translate("DeepinStorage", i18nMap.value(i18nKey, i18nKey.toUtf8().constData()));
+        auto &&bytes = i18nKey.toUtf8();
+        auto ret = qApp->translate("DeepinStorage", i18nMap.value(i18nKey, bytes.data()));
+        return ret;
     }
 
     if (d->mps.contains(QByteArray("/\0", 2))) {
@@ -798,17 +768,19 @@ bool DFMRootFileInfo::checkMpsStr(const QString &path) const
 bool DFMRootFileInfo::typeCompare(const DAbstractFileInfoPointer &a, const DAbstractFileInfoPointer &b)
 {
     static const QHash<ItemType, int> priomap = {
-        {ItemType::UserDirectory, -1},
-        {ItemType::UDisksRoot,  0},
-        {ItemType::UDisksData,  1},
-        {ItemType::UDisksFixed,  2},
-        {ItemType::UDisksRemovable,  3},
-        {ItemType::UDisksOptical,  4},
-        {ItemType::GvfsSMB,  5},
-        {ItemType::GvfsFTP,  5},
-        {ItemType::GvfsMTP,  6},
-        {ItemType::GvfsGPhoto2,  6},
-        {ItemType::GvfsGeneric,  7}
+        {ItemType::UserDirectory,   -1},
+        {ItemType::UDisksRoot,      0},
+        {ItemType::UDisksData,      1},
+        {ItemType::UDisksFixed,     2},
+        {ItemType::UDisksRemovable, 3},
+        {ItemType::UDisksOptical,   4},
+        {ItemType::GvfsSMB,         5},
+        {ItemType::NotConnRemote,   5},
+        {ItemType::GvfsFTP,         5},
+        {ItemType::GvfsMTP,         6},
+        {ItemType::GvfsGPhoto2,     6},
+        {ItemType::GvfsGeneric,     7},
+        {ItemType::AppEntry,        10}
     };
     // fix bug 64147 网络文件不去判断exists会卡顿
     if (!a)
@@ -829,17 +801,19 @@ bool DFMRootFileInfo::typeCompare(const DAbstractFileInfoPointer &a, const DAbst
 bool DFMRootFileInfo::typeCompareByUrl(const DAbstractFileInfoPointer &a, const DAbstractFileInfoPointer &b)
 {
     static const QHash<ItemType, int> priomap = {
-        {ItemType::UserDirectory, -1},
-        {ItemType::UDisksRoot,  0},
-        {ItemType::UDisksData,  1},
-        {ItemType::UDisksFixed,  2},
-        {ItemType::UDisksRemovable,  3},
-        {ItemType::UDisksOptical,  4},
-        {ItemType::GvfsMTP,  5},
-        {ItemType::GvfsGPhoto2,  5},
-        {ItemType::GvfsGeneric,  6},
-        {ItemType::GvfsSMB,  7},
-        {ItemType::GvfsFTP,  7}
+        {ItemType::UserDirectory,   -1},
+        {ItemType::UDisksRoot,      0},
+        {ItemType::UDisksData,      1},
+        {ItemType::UDisksFixed,     2},
+        {ItemType::UDisksRemovable, 3},
+        {ItemType::UDisksOptical,   4},
+        {ItemType::GvfsMTP,         5},
+        {ItemType::GvfsGPhoto2,     5},
+        {ItemType::GvfsGeneric,     6},
+        {ItemType::GvfsSMB,         7},
+        {ItemType::GvfsFTP,         7},
+        {ItemType::NotConnRemote,   7},
+        {ItemType::AppEntry,        10}
     };
     // fix bug 64147 网络文件不去判断exists会卡顿
     if (!a)
@@ -864,6 +838,11 @@ void DFMRootFileInfo::loadDiskInfo()
     if (d->mps.empty())
         return;
 
+    if (d->blk) {
+        auto drv = DDiskManager::createDiskDevice(d->blk->drive());
+        if (drv && drv->optical())
+            return;
+    }
     QDir dir(QString(d->mps.front()) + "/UOSICON");
     if (!dir.exists()) {
         return;
