@@ -41,8 +41,16 @@
 #include "views/dfmopticalmediawidget.h"
 #include "controllers/vaultcontroller.h"
 #include "models/avfsfileinfo.h"
+#include "dfmapplication.h"
+#include "dfmsettings.h"
+#include "usershare/usersharemanager.h"
+#include "usershare/shareinfo.h"
 
 #include <dstorageinfo.h>
+#include <dgiovolumemanager.h>
+#include <dgiomount.h>
+#include <dgiofile.h>
+#include <dgiovolume.h>
 
 #include <QDirIterator>
 #include <QUrl>
@@ -60,6 +68,7 @@
 #include <dabstractfilewatcher.h>
 #include <QApplication>
 #include <QScreen>
+#include <QNetworkInterface>
 #include <DRecentManager>
 
 #include <sys/vfs.h>
@@ -135,6 +144,51 @@ bool FileUtils::isAncestorUrl(const DUrl &ancestor, const DUrl &url)
     }
     return false;
 }
+/**
+ * @brief Check isNetworkAncestorUrl 检查挂载的目录是否是本机目录，是本地挂载转换为本地url，在判读是否是同一个目录
+ * 两个参数一个是本地，一个网络挂载文件，必须是目标文件是原文的父文件，就返回true
+ * @param ancestor
+ * @param
+ * @param
+ */
+bool FileUtils::isNetworkAncestorUrl(const DUrl &dest, const bool isDestGvfs, const DUrl &source, const bool isSourceGvfs)
+{
+    if ((isDestGvfs && isSourceGvfs) || (!isDestGvfs && !isSourceGvfs))
+        return false;
+
+    QString gvfsUrlStr = isDestGvfs ? dest.path() : source.path();
+
+    const QString &host = FileUtils::smbAttribute(gvfsUrlStr, FileUtils::SmbAttribute::kServer);
+    const QString &shareName = FileUtils::smbAttribute(gvfsUrlStr, FileUtils::SmbAttribute::kShareName);
+    const QString &path = FileUtils::smbAttribute(gvfsUrlStr, FileUtils::SmbAttribute::kSharePath);
+    // 获取本机ip判断是否是自己
+    bool selfIp = false;
+    const auto &allAddresses = QNetworkInterface::allAddresses();
+    for (const auto &address : allAddresses) {
+        const QString &ipAddr = address.toString();
+        if (ipAddr == host) {
+            selfIp = true;
+            break;
+        }
+    }
+
+    if (!selfIp)
+        return false;
+    //获取自己的共享路径
+    QString realPath;
+    if (!userShareManager->getsShareInfoByShareName(shareName).isValid())
+        return false;
+
+    realPath = userShareManager->getsShareInfoByShareName(shareName).path() + path;
+    DUrl realUrl = DUrl::fromLocalFile(realPath);
+    if (isDestGvfs && realUrl.parentUrl().path().contains(source.path()))
+        return true;
+
+    if (isSourceGvfs && dest.path().contains(realUrl.parentUrl().path()))
+        return true;
+
+    return false;
+}
 
 /**
  * @brief Collects all file names in given path (recursive)
@@ -194,6 +248,7 @@ QStringList FileUtils::filesList(const QString &dir)
  *
  * 通常情况下，一个空目录文件的大小是 4k （有文件的目录的大小随文件数量的增加而增加）
  * 但是不同的文件系统下，目录的大小是不同的 （如 exfat 是 32k，vfat 是 8k）
+ * 跑CI时发现, 空文件夹size返回了64B
  *
  * @return fts_* 函数获取的结果，默认为 4096
  */
@@ -429,7 +484,13 @@ QIcon FileUtils::searchAppIcon(const DesktopFile &app,
     // Resulting icon
     QIcon icon;
 
-    // First attempt, check whether icon is a valid file
+    // First attempt, try load icon from theme
+    icon = QIcon::fromTheme(app.getIcon());
+    if (!icon.isNull()) {
+        return icon;
+    }
+
+    // Second attempt, check whether icon is a valid file
     if (QFile(app.getIcon()).exists()) {
         icon = QIcon(app.getIcon());
         if (!icon.isNull()) {
@@ -437,12 +498,6 @@ QIcon FileUtils::searchAppIcon(const DesktopFile &app,
         }
     }
 
-    // Second attempt, try load icon from theme
-    icon = QIcon::fromTheme(app.getIcon());
-    if (!icon.isNull()) {
-        return icon;
-    }
-
     // Next, try luck with application name
     QString name = app.getFileName().remove(".desktop").split("/").last();
     icon = QIcon::fromTheme(name);
@@ -595,38 +650,16 @@ QString FileUtils::diskUsageString(quint64 &usedSize, quint64 &totalSize, QStrin
 QString FileUtils::defaultOpticalSize(const QString &tagName, quint64 &usedSize, quint64 &totalSize)
 {
     QString size{"0M"};
+    int burnStatus{DFMOpticalMediaWidget::BCSA_BurnCapacityStatusEjct};
+    quint64 curTotalSize{0}; // 光盘总大小
+    quint64 curUsedSize{0};  // 光盘已使用的大小
 
-    // todo: should be beautify, copy from `diskcontrolitem.cpp`
-    // 解析配置文件，获取光驱数据暂存的内容（包含挂载状态，大小）
-    QFile burnCapacityFile(QString("%1/dde-file-manager.json").arg(DFMStandardPaths::location(DFMStandardPaths::ApplicationConfigPath)));
-    if (burnCapacityFile.open(QIODevice::ReadOnly)) {
-        QByteArray burnCapacityData = burnCapacityFile.readAll();
-        burnCapacityFile.close();
+    if (DFMApplication::genericSetting()->keys(BURN_CAPACITY_ATTRIBUTE).contains(tagName)) {
+        const QMap<QString, QVariant> &info = DFMApplication::genericSetting()->value(BURN_CAPACITY_ATTRIBUTE, tagName).toMap();
+        burnStatus = info.value(BURN_CAPACITY_STATUS).toInt();
+        curTotalSize = static_cast<quint64>(info.value(BURN_CAPACITY_TOTAL_SIZE).toDouble());
+        curUsedSize = static_cast<quint64>(info.value(BURN_CAPACITY_USED_SIZE).toDouble());
 
-        QJsonParseError parseJsonErr;
-        QJsonDocument jsonDoc(QJsonDocument::fromJson(burnCapacityData, &parseJsonErr));
-        if (!(parseJsonErr.error == QJsonParseError::NoError)) {
-            qDebug() << "decode json file error！";
-            return size;
-        }
-
-        int burnStatus{DFMOpticalMediaWidget::BCSA_BurnCapacityStatusEjct};
-        quint64 curTotalSize{0}; // 光盘总大小
-        quint64 curUsedSize{0};  // 光盘已使用的大小
-        QJsonObject tempBurnObjs = jsonDoc.object();
-        if (tempBurnObjs.contains(QStringLiteral("BurnCapacityAttribute"))) {
-            QJsonValue jsonBurnValueList = tempBurnObjs.value(QStringLiteral("BurnCapacityAttribute"));
-            QJsonObject tagItem = jsonBurnValueList.toObject();
-            // 从配置文件读取光盘信息
-            if (tagItem.contains(tagName)) {
-                QJsonObject burnItem = tagItem[tagName].toObject();
-                curTotalSize = static_cast<quint64>(burnItem["BurnCapacityTotalSize"].toDouble());
-                curUsedSize = static_cast<quint64>(burnItem["BurnCapacityUsedSize"].toDouble());
-                burnStatus = burnItem["BurnCapacityStatus"].toInt();
-            }
-        }
-
-        // 光盘已挂载状态
         if (burnStatus == DFMOpticalMediaWidget::BCSA_BurnCapacityStatusAddMount && curUsedSize > 0 && curTotalSize > 8) {
             const qint64 kb = 1024;
             const qint64 mb = 1024 * kb;
@@ -636,6 +669,7 @@ QString FileUtils::defaultOpticalSize(const QString &tagName, quint64 &usedSize,
             totalSize = curTotalSize;
             size = QString("%1/%2").arg(FileUtils::formatSize(static_cast<qint64>(usedSize), true, 1, usedSize < mb ? 2 : -1, unitDisplayText),
                                         FileUtils::formatSize(static_cast<qint64>(totalSize), true, 1, totalSize < mb ? 2 : -1, unitDisplayText));
+
         }
     }
 
@@ -730,14 +764,21 @@ bool FileUtils::openFile(const QString &filePath)
         mimetype = getFileMimetype(filePath);
     }
     /*********************************************************/
-
+    QAtomicInteger<bool> isOpenNow = false;
     QString defaultDesktopFile = MimesAppsManager::getDefaultAppDesktopFileByMimeType(mimetype);
     if (defaultDesktopFile.isEmpty()) {
-        qDebug() << "no default application for" << filePath;
-        return false;
+        if (isSmbUnmountedFile(DUrl::fromLocalFile(filePath))) {
+            mimetype = QString("inode/directory");
+            defaultDesktopFile = MimesAppsManager::getDefaultAppDesktopFileByMimeType(mimetype);
+            isOpenNow = true;
+            mimetype = QString();
+        } else {
+            qDebug() << "no default application for" << filePath;
+            return false;
+        }
     }
     //此处会排除执行段(Exec=)包含dde-file-manager的desktop文件，需要对目录(inode/directory)类型及dde-open.desktop例外处理
-    if (isFileManagerSelf(defaultDesktopFile) && mimetype != "inode/directory" && !defaultDesktopFile.contains("/dde-open.desktop")) {
+    if (!isOpenNow && isFileManagerSelf(defaultDesktopFile) && mimetype != "inode/directory" && !defaultDesktopFile.contains("/dde-open.desktop")) {
         QStringList recommendApps = mimeAppsManager->getRecommendedApps(DUrl::fromLocalFile(filePath));
         recommendApps.removeOne(defaultDesktopFile);
         if (recommendApps.count() > 0) {
@@ -800,14 +841,21 @@ bool FileUtils::openFiles(const QStringList &filePaths)
         mimetype = getFileMimetype(filePath);
     }
     /*********************************************************/
-
+    bool isOpenNow = false;
     QString defaultDesktopFile = MimesAppsManager::getDefaultAppDesktopFileByMimeType(mimetype);
     if (defaultDesktopFile.isEmpty()) {
-        qDebug() << "no default application for" << rePath;
-        return false;
+        if (isSmbUnmountedFile(DUrl::fromLocalFile(filePath))) {
+            mimetype = QString("inode/directory");
+            defaultDesktopFile = MimesAppsManager::getDefaultAppDesktopFileByMimeType(mimetype);
+            isOpenNow = true;
+            mimetype = QString();
+        } else {
+            qDebug() << "no default application for" << filePath;
+            return false;
+        }
     }
 
-    if (isFileManagerSelf(defaultDesktopFile) && mimetype != "inode/directory") {
+    if (!isOpenNow && isFileManagerSelf(defaultDesktopFile) && mimetype != "inode/directory") {
         QStringList recommendApps = mimeAppsManager->getRecommendedApps(DUrl::fromLocalFile(filePath));
         recommendApps.removeOne(defaultDesktopFile);
         if (recommendApps.count() > 0) {
@@ -833,6 +881,8 @@ bool FileUtils::openFiles(const QStringList &filePaths)
             addRecentFile(file_path, df, mimetype);
         }
         return result;
+    } else if (isSmbUnmountedFile(DUrl::fromLocalFile(rePath[0]))) {
+        return false;
     }
 
     if (mimeAppsManager->getDefaultAppByFileName(filePath) == "org.gnome.font-viewer.desktop") {
@@ -884,14 +934,21 @@ bool FileUtils::openEnterFiles(const QStringList &filePaths)
         }
         mimetypeinfo.insert(DUrl::fromLocalFile(filePath).toString(), mimetype);
         /*********************************************************/
-
+        bool isOpenNow = false;
         QString defaultDesktopFile = MimesAppsManager::getDefaultAppDesktopFileByMimeType(mimetype);
         if (defaultDesktopFile.isEmpty()) {
-            qDebug() << "no default application for" << rePath;
-            continue;
+            if (isSmbUnmountedFile(DUrl::fromLocalFile(filePath))) {
+                mimetype = QString("inode/directory");
+                defaultDesktopFile = MimesAppsManager::getDefaultAppDesktopFileByMimeType(mimetype);
+                isOpenNow = true;
+                mimetype = QString();
+            } else {
+                qDebug() << "no default application for" << filePath;
+                continue;
+            }
         }
 
-        if (isFileManagerSelf(defaultDesktopFile) && mimetype != "inode/directory") {
+        if (!isOpenNow && isFileManagerSelf(defaultDesktopFile) && mimetype != "inode/directory") {
             QStringList recommendApps = mimeAppsManager->getRecommendedApps(DUrl::fromLocalFile(filePath));
             recommendApps.removeOne(defaultDesktopFile);
             if (recommendApps.count() > 0) {
@@ -911,6 +968,8 @@ bool FileUtils::openEnterFiles(const QStringList &filePaths)
     //未找到默认打开应用，需要返回false，让上层逻辑走选择默认打开程序的流程
     if (openinfo.isEmpty()) {
         return false;
+    } else if (isSmbUnmountedFile(DUrl::fromLocalFile(rePath[0]))) {
+        return false;
     }
 
     QStringList appAgrs;
@@ -958,6 +1017,7 @@ bool FileUtils::openEnterFiles(const QStringList &filePaths)
 
 bool FileUtils::launchApp(const QString &desktopFile, const QStringList &filePaths)
 {
+    QStringList newList(filePaths);
     if (isFileManagerSelf(desktopFile) && filePaths.count() > 1) {
         foreach (const QString &filePath, filePaths) {
             // fix bug#33577在桌面上，多选文件夹不能打开
@@ -971,9 +1031,17 @@ bool FileUtils::launchApp(const QString &desktopFile, const QStringList &filePat
         return true;
     }
 
-    bool ok = launchAppByDBus(desktopFile, filePaths);
+    if (isFileManagerSelf(desktopFile) && filePaths.count() == 1) {
+        DUrl fileUrl(filePaths[0]);
+        if (isSmbUnmountedFile(fileUrl)) {
+            newList.clear();
+            newList << durlFromLocalPath(filePaths[0]).toString();
+        }
+    }
+
+    bool ok = launchAppByDBus(desktopFile, newList);
     if (!ok) {
-        ok = launchAppByGio(desktopFile, filePaths);
+        ok = launchAppByGio(desktopFile, newList);
     }
     return ok;
 }
@@ -1195,6 +1263,11 @@ bool FileUtils::isFileExecutable(const QString &path)
 {
     QFile file(path);
 
+    // regard these type as unexecutable.
+    const static QStringList noValidateType {"txt", "md"};
+    if (noValidateType.contains(QFileInfo(file).suffix()))
+        return false;
+
     bool isExeUser = false;
 
     // Vault file need to use stat function to read file permission.
@@ -1575,6 +1648,13 @@ bool FileUtils::isGvfsMountFile(const QString &filePath, const bool &isEx)
     if (filePath.isEmpty())
         return false;
 
+    static const QString gvfsPath = QString("/run/user/") + QString::number(getuid()) + QString("/gvfs");
+
+    if (filePath.startsWith(gvfsPath) && filePath != gvfsPath)
+        return true;
+    if (filePath == gvfsPath)
+        return false;
+
     bool isgvfsfile = !DStorageInfo::isLocalDevice(filePath, isEx);
 
     return isgvfsfile;
@@ -1688,23 +1768,6 @@ void FileUtils::addRecentFile(const QString &filePath, const DesktopFile &deskto
     DRecentManager::addItem(filePath, recentData);
 }
 
-bool FileUtils::deviceShouldBeIgnore(const QString &devId)
-{
-    bool canConvert = false;
-    devId.chopped(1).toInt(&canConvert); // 设备以数字结束，代表有分区 （/dev/sdb1）
-    if (canConvert)
-        return false;
-
-    QString volTag = devId.mid(devId.lastIndexOf("/") + 1); // 当传入设备 id 是 /dev/sdb 时，如果包含 /dev/sdbN，则忽略 /dev/sdb
-    QProcess p;
-    p.start("bash", QStringList() << "-c"
-            << "ls /dev/ | grep " + volTag);
-    p.waitForFinished();
-    QString output(p.readAllStandardOutput());
-    QStringList devices = output.split("\n", QString::SkipEmptyParts);
-    return devices.count() > 1;
-}
-
 bool FileUtils::appendCompress(const DUrl &toUrl, const DUrlList &fromUrlList)
 {
     if (!fromUrlList.isEmpty()) {
@@ -1731,17 +1794,7 @@ int FileUtils::getMemoryPageSize()
 
 bool FileUtils::isFtpFile(const DUrl &url)
 {
-    static QRegularExpression regExp("^/run/user/\\d+/gvfs/.+$",
-                                     QRegularExpression::DotMatchesEverythingOption
-                                     | QRegularExpression::DontCaptureOption
-                                     | QRegularExpression::OptimizeOnFirstUsageOption);
-
-    if (!regExp.match(url.path(), 0, QRegularExpression::NormalMatch, QRegularExpression::DontCheckSubjectStringMatchOption).hasMatch()) {
-        return false;
-    }
-    if (url.path().contains("/ftp:host="))
-        return true;
-    return false;
+    return url.path().contains(QRegExp("/run/user/.+gvfs/ftp:.*host=.+"));
 }
 /**
  * @brief jugment file is local file(in system disk file)(使用gio判断挂载点是否可以卸载)
@@ -1768,6 +1821,303 @@ qint32 FileUtils::getCpuProcessCount()
                 4 : static_cast<int>(sysconf(_SC_NPROCESSORS_CONF));
     return cpuProcessCount;
 }
+/**
+ * @brief jugment file is mount 通过gioqt获取所有的挂载点，对比当前的url是否在挂载点中，只判断了smb和ftp
+ * @param url file url
+ */
+bool FileUtils::isNetworkUrlMounted(const DUrl &url)
+{
+    for (auto gvfsmp : DGioVolumeManager::getMounts()) {
+        auto rootFile = gvfsmp->getRootFile();
+        if (!rootFile || (!rootFile->uri().contains("smb")
+                && !rootFile->uri().contains("ftp")))
+            continue;
+
+        DUrl mountUrl;
+        mountUrl.setScheme(DFMROOT_SCHEME);
+        mountUrl.setPath("/" + QUrl::toPercentEncoding(rootFile->path()) + "." SUFFIX_GVFSMP);
+        if (mountUrl == url)
+            return true;
+    }
+    return false;
+}
+
+bool FileUtils::isSambaServiceRunning()
+{
+    QDBusInterface iface("org.freedesktop.systemd1",
+                         "/org/freedesktop/systemd1/unit/smbd_2eservice",
+                         "org.freedesktop.systemd1.Unit",
+                         QDBusConnection::systemBus());
+
+    if (iface.isValid()) {
+        const QVariant &variantStatus = iface.property("SubState"); // 获取属性 SubState，等同于 systemctl status smbd 结果 Active 值
+        if (variantStatus.isValid())
+            return "running" == variantStatus.toString();
+    }
+    return false;
+}
+
+bool FileUtils::isSmbUnmountedFile(const DUrl &url)
+{
+    return isSmbPath(url.path()) && DFileService::instance()->checkGvfsMountfileBusy(url, false);
+}
+
+bool FileUtils::isSmbPath(const QString &localPath)
+{
+    // like file:///run/user/1000/gvfs/smb-share:domain=ttt,server=xx.xx.xx.xx,share=io,user=uos/path
+    QRegExp reg("/run/user/.+gvfs/smb-share:.*server.+share.+");
+    int idx = reg.indexIn(localPath);
+
+    if(-1 == idx) {
+        // 传进来的可能是加密的路径
+        idx = reg.indexIn(QUrl::fromPercentEncoding(localPath.toLocal8Bit()));
+    }
+
+    if(-1 == idx) {
+        // like smb://ttt;uos:1@xx.xx.xx.xx/io/path
+        // maybe access by mapping addr, like smb://xxx.com/io
+        reg.setPattern("smb://.+");
+        idx = reg.indexIn(localPath);
+    }
+    return -1 != idx;
+}
+
+DUrl FileUtils::durlFromLocalPath(const QString &localPath)
+{
+    // file:///run/user/1000/gvfs/smb-share:domain=ttt,server=xx.xx.xx.xx,share=io,user=uos/path
+    // to
+    // smb://ttt;uos@xx.xx.xx.xx/io/path
+
+    const QString &doMain = smbAttribute(localPath, SmbAttribute::kDomain);
+    const QString &server = smbAttribute(localPath, SmbAttribute::kServer);
+    const QString &shareName = smbAttribute(localPath, SmbAttribute::kShareName);
+    const QString &sharePath = smbAttribute(localPath, SmbAttribute::kSharePath);
+    const QString &user = smbAttribute(localPath, SmbAttribute::kUser);
+
+    QString fullUrl = "smb://";
+    if(!doMain.isEmpty() && !user.isEmpty())
+        fullUrl.append(doMain+";");
+    if(!user.isEmpty())
+        fullUrl.append(user).append("@");
+    fullUrl.append(server).append("/");
+    fullUrl.append(shareName);
+    if(!sharePath.isEmpty())
+        fullUrl.append("/").append(sharePath);
+
+    qDebug() << fullUrl;
+
+    return DUrl(fullUrl);
+}
+
+QString extractSmbDomain(const QString &subLocalPath)
+{
+    QString doMain;
+    QRegExp reg("domain=(.*),");
+    reg.setMinimal(true);
+    int idx = reg.indexIn(subLocalPath);
+    if (idx != -1)
+        doMain = reg.cap(1);
+    return std::move(doMain);
+}
+
+QString extractSmbServer(const QString &subLocalPath)
+{
+    QString server;
+    QRegExp reg("server=(.*),");
+    reg.setMinimal(true);
+    int idx = reg.indexIn(subLocalPath);
+    if (idx != -1)
+        server = reg.cap(1);
+    return server;
+}
+
+QString extractSmbShareName(const QString &subLocalPath)
+{
+    QString shareName;
+    QRegExp reg("share=(.*),");
+    int idx = reg.indexIn(subLocalPath);
+    if (idx != -1) {
+        shareName = reg.cap(1);
+    } else {
+        reg.setPattern("share=(.*)");
+        reg.setMinimal(false);
+        idx = reg.indexIn(subLocalPath);
+        if (idx != -1)
+            shareName = reg.cap(1);
+        if(shareName.contains("/")) {
+            reg.setPattern("(.*)/");
+            reg.setMinimal(true);
+            idx = reg.indexIn(shareName);
+            auto list = reg.capturedTexts();
+            if (idx != -1){
+                shareName = reg.cap(1);
+            }
+        }
+    }
+    return shareName;
+}
+
+QString extractSmbSharePath(const QString &subLocalPath)
+{
+    QString fullShare;
+    QString sharePath;
+    QRegExp reg("share=(.*)");
+    int idx = reg.indexIn(subLocalPath);
+    if(idx != -1)
+        fullShare = reg.cap(1);
+
+    reg.setPattern("share=(.*)/");
+    reg.setMinimal(true);
+    idx = reg.indexIn(subLocalPath);
+    if(idx != -1) {
+        sharePath = reg.cap(1);
+        sharePath = fullShare.mid(sharePath.size() + 1); // remove '/' in head, function caller need deal itself
+    }
+    return sharePath;
+}
+
+QString extractSmbUser(const QString &subLocalPath)
+{
+    QString user;
+    QRegExp reg("user=(.*)");
+    reg.setMinimal(false);
+    int idx = reg.indexIn(subLocalPath);
+    if (idx != -1)
+        user = reg.cap(1);
+    if(user.contains("/")) {
+        reg.setPattern("(.*)/");
+        idx = reg.indexIn(user);
+        if (idx != -1){
+            user = reg.cap(1);
+        }
+    }
+    return user;
+}
+
+QString FileUtils::smbAttribute(const QString &localPath, FileUtils::SmbAttribute id)
+{
+    // file:///run/user/1000/gvfs/smb-share:domain=ttt,server=xx.xx.xx.xx,share=io,user=uos/path
+    // to
+    // smb://ttt;uos@xx.xx.xx.xx/io/path
+
+    QString smbMain;
+
+    QRegExp reg("gvfs/smb-share:(.+)");
+    int idx = reg.indexIn(localPath);
+    if(idx == -1)
+        return QString();
+    smbMain = reg.cap(1);
+    if(smbMain.endsWith("/"))
+        smbMain.chop(1);
+
+    QString tmpStr;
+    switch (id) {
+    case FileUtils::SmbAttribute::kDomain:{
+        tmpStr = extractSmbDomain(smbMain);
+        break;
+    }
+    case FileUtils::SmbAttribute::kServer:{
+        tmpStr = extractSmbServer(smbMain);
+        break;
+    }
+    case FileUtils::SmbAttribute::kShareName:{
+        tmpStr = extractSmbShareName(smbMain);
+        break;
+    }
+    case FileUtils::SmbAttribute::kSharePath:{
+        tmpStr = extractSmbSharePath(smbMain);
+        break;
+    }
+    case FileUtils::SmbAttribute::kUser:{
+        tmpStr = extractSmbUser(smbMain);
+        break;
+    }
+    }
+    std::string tmpStdStr = tmpStr.toStdString();
+    return QUrl::fromPercentEncoding(tmpStdStr.data());
+}
+
+QString FileUtils::bindPathTransform(const QString &path)
+{
+    QString transformPath = path;
+    QList<QStringList> bindPathInfoList = readBindPathInfo();
+
+    for (QStringList infos : bindPathInfoList) {
+        if(infos.count() >= 2) {
+            QString oldbindpath = infos.first();
+            QString bindPath = infos[1];
+            if (transformPath.contains(oldbindpath)) {
+                transformPath = transformPath.replace(oldbindpath, bindPath);
+                break;
+            }
+        }
+    }
+
+    return transformPath;
+}
+
+QList<QStringList> FileUtils::readBindPathInfo()
+{
+    static QList<QStringList> lists;
+    static bool flg = true;
+    if (flg) {
+        lists << bindPathInfo(QString("defaults,bind"));
+        flg = false;
+    }
+    return lists;
+}
+
+/*!
+ * \brief           获取挂载点路径映射关于信息
+ * \param grepData  需要查询信息的关键词
+ * \return          返回查询结果
+ */
+QList<QStringList> FileUtils::bindPathInfo(const QString &grepData)
+{
+    QList<QStringList> data = catFstabFileInfo(grepData);
+    if(data.isEmpty())
+        return QList<QStringList>();
+
+    QList<QStringList> infoList;
+
+    for (QStringList &sl : data) {
+        QStringList bindmount;
+        if (sl.count() >= 4) {
+            if (sl[3] == grepData) {
+                bindmount.append(QString("file://") + sl[0]);
+                bindmount.append(QString("file://") + sl[1]);
+                infoList.append(bindmount);
+            }
+        }
+    }
+    return infoList;
+}
+
+/*!
+ * \brief               使用cat获取/etc/fstab文件信息
+ * \param grepData      需要查询信息的关键词
+ * \return              返回查询结果
+ */
+QList<QStringList> FileUtils::catFstabFileInfo(const QString &grepData)
+{
+    QList<QStringList> listMountInfo;
+    QStringList options;
+    options << "-c";
+    options << QString("cat") + QString(" /etc/fstab | grep %1").arg(grepData);
+    QProcess process;
+    process.start("/bin/bash", options);
+    process.waitForStarted();
+    process.waitForReadyRead();
+    while(process.canReadLine()){
+        QString out = process.readLine();
+        QStringList outs = out.split(" ", QString::SkipEmptyParts);
+        listMountInfo.append(outs);
+    }
+    process.waitForFinished();
+    process.terminate();
+
+    return listMountInfo;
+}
 
 //优化苹果文件不卡显示，存在判断错误的可能，只能临时优化，需系统提升ios传输效率
 bool FileUtils::isDesktopFile(const QString &filePath)
