@@ -50,6 +50,9 @@
 #include "controllers/vaultcontroller.h"
 #include "accessibility/ac-lib-file-manager.h"
 #include "../shutil/fileutils.h"
+#include "views/dtoolbar.h"
+#include "drootfilemanager.h"
+#include "utils.h"
 
 #include <dslider.h>
 
@@ -97,8 +100,8 @@ protected:
                     if (!curIdx.isValid()) {
                         return true;
                     }
-                    // 目的是可移动设备的item重命名时，按enter键时，不应该进入对应的目录，因此直接返回false
-                    if (model->flags(curIdx) & Qt::ItemFlag::ItemIsEditable) {
+                    // when device is editing name, ignore enter event.
+                    if (model->data(curIdx, ComputerModel::DataRoles::IsEditingRole).toBool()) {
                         return false;
                     }
                     Q_EMIT entered(curIdx);
@@ -179,14 +182,32 @@ ComputerView::ComputerView(QWidget *parent) : QWidget(parent)
 
     connect(m_view, &QWidget::customContextMenuRequested, this, &ComputerView::contextMenu);
     auto enterfunc = [this](const QModelIndex & idx, int triggermatch) {
+
+        DUrl url = idx.data(ComputerModel::DataRoles::DFMRootUrlRole).value<DUrl>();
+        if (!url.isValid())
+            return;
+
+        //! 在点击计算机页面中的图标时，判断是否是保险箱以及保险箱是否解锁，如果解锁发送信号触发计算保险箱大小的线程
+        if(VaultController::Unlocked == VaultController::ins()->state() && url.isVaultFile()) {
+            emit VaultController::ins()->sigFinishedCopyFile();
+        }
+
         if (~triggermatch) {
             if (DFMApplication::instance()->appAttribute(DFMApplication::AA_OpenFileMode).toInt() != triggermatch) {
                 return;
             }
         }
-        DUrl url = idx.data(ComputerModel::DataRoles::DFMRootUrlRole).value<DUrl>();
-        if (!url.isValid())
-            return;
+
+        // searchBarTextEntered also invoke "checkGvfsMountFileBusy", forbit invoke twice
+        if (url.path().endsWith(SUFFIX_STASHED_REMOTE)) {
+            DFileManagerWindow *window = qobject_cast<DFileManagerWindow *>(this->window());
+            if (window) {
+                auto path = RemoteMountsStashManager::normalizeConnUrl(url.path());
+                window->getToolBar()->searchBarTextEntered(path);
+                return;
+            }
+        }
+
         //判断网络文件是否可以到达
         // fix bug 63803 这里是鼠标事件进入后，checkGvfsMountfileBusy需要很长时间，所以鼠标事件没有结束
         // 切换到其他界面，就析构了自己，当这个checkGvfsMountfileBusy退出，qt处理鼠标事件就崩溃了。
@@ -439,4 +460,13 @@ void ComputerListView::mouseMoveEvent(QMouseEvent *event)
     }
 }
 
+void ComputerListView::showEvent(QShowEvent *event)
+{
+    //! 显示计算机页面时，判断保险箱是否解锁，如果解锁发送信号触发计算保险箱大小的线程
+    if(VaultController::Unlocked == VaultController::ins()->state()) {
+        emit VaultController::ins()->sigFinishedCopyFile();
+    }
+    QListView::showEvent(event);
+}
+
 #include "computerview.moc"
