@@ -44,9 +44,19 @@
 #include "dfmapplication.h"
 #include "dfmstandardpaths.h"
 #include "dfmopticalmediawidget.h"
+#include "dfmevent.h"
+#include "xutil.h"
+#include "utils.h"
+#include "dfmadvancesearchbar.h"
+#include "dtagactionwidget.h"
+#include "droundbutton.h"
+#include "dfmrightdetailview.h"
+#include "drenamebar.h"
+#include "singleton.h"
+#include "dfileservices.h"
+#include "dfmsplitter.h"
 
 #include "app/define.h"
-#include "dfmevent.h"
 #include "app/filesignalmanager.h"
 #include "deviceinfo/udisklistener.h"
 #include "usershare/usersharemanager.h"
@@ -54,17 +64,7 @@
 #include "shutil/fileutils.h"
 #include "gvfs/networkmanager.h"
 #include "dde-file-manager/singleapplication.h"
-
-#include "xutil.h"
-#include "utils.h"
-#include "dfmadvancesearchbar.h"
-#include "dtagactionwidget.h"
-#include "droundbutton.h"
-#include "dfmrightdetailview.h"
-
-#include "drenamebar.h"
-#include "singleton.h"
-#include "dfileservices.h"
+#include "dialogs/dialogmanager.h"
 #include "controllers/appcontroller.h"
 #include "view/viewinterface.h"
 #include "plugins/pluginmanager.h"
@@ -72,13 +72,13 @@
 #include "controllers/filecontroller.h"
 #include "models/dfmrootfileinfo.h"
 #include "controllers/vaultcontroller.h"
-#include "dfmsplitter.h"
 #include "views/dfmvaultactiveview.h"
-#include "accessibility/ac-lib-file-manager.h"
+#include "vault/vaultglobaldefine.h"
+#include "dde-file-manager-daemon/dbusservice/dbusinterface/usershare_interface.h"
+#include "plugins/pluginemblemmanager.h"
 
 #include <DPlatformWindowHandle>
 #include <DTitlebar>
-
 #include <QScreen>
 #include <QStatusBar>
 #include <QFrame>
@@ -94,11 +94,14 @@
 #include <DAnchors>
 #include <DApplicationHelper>
 #include <DHorizontalLine>
+#include <QHostInfo>
+#include <QNetworkInterface>
 
 DWIDGET_USE_NAMESPACE
 
 std::unique_ptr<RecordRenameBarState>  DFileManagerWindow::renameBarState{ nullptr };
 std::atomic<bool> DFileManagerWindow::flagForNewWindowFromTab{ false };
+bool vaultMoveState = true;
 
 void DFileManagerWindowPrivate::setCurrentView(DFMBaseView *view)
 {
@@ -129,6 +132,21 @@ void DFileManagerWindowPrivate::setCurrentView(DFMBaseView *view)
     } else {
         tabBar->currentTab()->setFileView(view);
     }
+
+    //! 检测保险箱是否上锁，是否是已经移动保险箱了
+    if (vaultMoveState && VaultController::Unlocked != VaultController::ins()->state()) {
+        vaultRemove flg = moveVaultPath();
+        if(vaultRemove::SUCCESS == flg) {
+            qInfo() << "移动到新存储位置成功";
+        }
+        else if (vaultRemove::NOTEXIST == flg){
+            qInfo() << "文件不存在";
+        }
+        else {
+            qInfo() << "移动到新存储位置失败";
+        }
+        vaultMoveState = false;
+    }
 }
 
 bool DFileManagerWindowPrivate::processKeyPressEvent(QKeyEvent *event)
@@ -275,25 +293,28 @@ bool DFileManagerWindowPrivate::cdForTab(Tab *tab, const DUrl &fileUrl)
 {
     Q_Q(DFileManagerWindow);
     qInfo() << "  cd   to " << fileUrl;
+
+    // 每次切换目录，清空插件角标缓存
+    PluginEmblemManager::instance()->clearEmblemIconsMap();
+
     DFMBaseView *current_view = tab->fileView();
 
+    const QString &scheme = fileUrl.scheme();
+
     // fix 6942 取消判断先后请求地址差异判断
     // fix 28857 高频进入光驱会死锁
-    if (current_view && current_view->rootUrl() == fileUrl && fileUrl.scheme() == BURN_ROOT) {
+    if (current_view && current_view->rootUrl() == fileUrl && scheme == BURN_ROOT) {
         return false;
     }
 
-    if (fileUrl.scheme() == BURN_SCHEME) {
-
+    if (scheme == BURN_SCHEME) {
         // 如果当前设备正在执行刻录或擦除，激活进度窗口，拒绝跳转至文件列表页面
         QString strVolTag = DFMOpticalMediaWidget::getVolTag(fileUrl);
         if (!strVolTag.isEmpty() && DFMOpticalMediaWidget::g_mapCdStatusInfo[strVolTag].bBurningOrErasing) {
             emit fileSignalManager->activeTaskDlg();
             return false;
         }
-    }
-
-    if (fileUrl.scheme() == DFMROOT_SCHEME) {
+    } else if (scheme == DFMROOT_SCHEME) {
         DAbstractFileInfoPointer fi = DFileService::instance()->createFileInfo(q_ptr, fileUrl);
         if (fi->suffix() == SUFFIX_USRDIR) {
             return cdForTab(tab, fi->redirectedFileUrl());
@@ -304,8 +325,40 @@ bool DFileManagerWindowPrivate::cdForTab(Tab *tab, const DUrl &fileUrl)
                 qDebug() << "mount the device{" << blkDevicePath << " } at:" << blk->mount({});
             }
         }
+    } else if (scheme == SMB_SCHEME || (FileUtils::isSmbPath(fileUrl.path()))) {
+        // 需求 88316，smb 可能已经关闭 这里需求尝试启动
+
+        // 首先判断smb地址是否是自己ip
+        // 获取url里面的ip
+        QString urlIp;
+        QRegularExpression rx(R"((\d+.\d+.\d+.\d+))");
+        QRegularExpressionMatch match = rx.match(fileUrl.toString());
+        if (match.hasMatch())
+            urlIp = match.captured();
+
+        // 获取本机ip
+        bool selfIp = false;
+        const auto &allAddresses = QNetworkInterface::allAddresses();
+        qDebug() << allAddresses;
+        for (const auto &address : allAddresses) {
+            if (address.protocol() == QAbstractSocket::IPv4Protocol) {
+                const QString &ipAddr = address.toString();
+                if (ipAddr == urlIp) {
+                    selfIp = true;
+                    break;
+                }
+            }
+        }
+        if (selfIp) { // 自己ip再判断smb状态
+            if (!FileUtils::isSambaServiceRunning()) {
+                // 异步调启动smb窗口
+                q_ptr->startSambaServiceAsync(tab, fileUrl);
+                return false;
+            }
+        }
     }
-    if (fileUrl.scheme() == DFMVAULT_SCHEME ||
+
+    if (scheme == DFMVAULT_SCHEME ||
             VaultController::isVaultFile(fileUrl.fragment())) {
         if (VaultController::Unlocked != VaultController::ins()->state()
                 || fileUrl.host() == "delete") {
@@ -323,6 +376,7 @@ bool DFileManagerWindowPrivate::cdForTab(Tab *tab, const DUrl &fileUrl)
             return ret;
         }
     }
+
     if (!current_view || !DFMViewManager::instance()->isSuited(fileUrl, current_view)) {
         DFMBaseView *view = DFMViewManager::instance()->createViewByUrl(fileUrl);
         if (view) {
@@ -508,6 +562,50 @@ void DFileManagerWindowPrivate::resetRenameBar()
     renameBar->resetRenameBar();
 }
 
+DFileManagerWindowPrivate::vaultRemove DFileManagerWindowPrivate::moveVaultPath()
+{
+    QStringList vaultfilelist;
+    vaultfilelist << VAULT_BASE_PATH_OLD + "/" + VAULT_ENCRYPY_DIR_NAME
+                  << VAULT_BASE_PATH_OLD + "/" + VAULT_DECRYPT_DIR_NAME
+                  << VAULT_BASE_PATH_OLD + "/" + PASSWORD_FILE_NAME
+                  << VAULT_BASE_PATH_OLD + "/" + RSA_PUB_KEY_FILE_NAME
+                  << VAULT_BASE_PATH_OLD + "/" + RSA_CIPHERTEXT_FILE_NAME
+                  << VAULT_BASE_PATH_OLD + "/" + PASSWORD_HINT_FILE_NAME
+                  << VAULT_BASE_PATH_OLD + "/" + VAULT_CONFIG_FILE_NAME;
+
+    QString mvBinary = QStandardPaths::findExecutable("mv");
+    if (mvBinary.isEmpty()) return NOTEXIST;
+    QString vaultNewPath = VAULT_BASE_PATH;
+    QDir dir;
+    if(!dir.exists(vaultNewPath)) {
+        dir.mkdir(vaultNewPath);
+    }
+
+    DFileManagerWindowPrivate::vaultRemove flg = NOTEXIST;
+
+    for (QString & filepath : vaultfilelist) {
+        QFile file(filepath);
+        if(file.exists()) {
+            QStringList argments;
+            argments << filepath << vaultNewPath;
+            QProcess process;
+            process.start(mvBinary, argments);
+            process.waitForStarted();
+            process.waitForFinished();
+            process.terminate();
+
+            if(process.exitStatus() == QProcess::NormalExit && process.exitCode() == 0) {
+                flg = SUCCESS;
+            }
+            else {
+                flg = FAILED;
+            }
+        }
+    }
+
+    return flg;
+}
+
 void DFileManagerWindowPrivate::storeUrlListToRenameBar(const QList<DUrl> &list) noexcept
 {
     if (!renameBar) initRenameBar();
@@ -515,6 +613,38 @@ void DFileManagerWindowPrivate::storeUrlListToRenameBar(const QList<DUrl> &list)
     renameBar->storeUrlList(list);
 }
 
+void DFileManagerWindowPrivate::updateSelectUrl()
+{
+    DFileView *fv = dynamic_cast<DFileView *>(currentView);
+    if (detailView && fv) {
+        detailView->setUrl(fv->selectedUrls().value(0, fv->rootUrl()));
+        if (fv->selectedIndexCount() == 0)
+            detailView->setTagWidgetVisible(false);
+    }
+}
+
+void DFileManagerWindowPrivate::createRightDetailViewHolder()
+{
+    rightDetailViewHolder = new QFrame;
+    rightDetailViewHolder->setObjectName("rightviewHolder");
+    AC_SET_ACCESSIBLE_NAME(rightDetailViewHolder, AC_DM_RIGHT_VIEW_HOLDER);
+    rightDetailViewHolder->setAutoFillBackground(true);
+    rightDetailViewHolder->setBackgroundRole(QPalette::ColorRole::Base);
+    rightDetailViewHolder->setFixedWidth(320);
+    QHBoxLayout *rvLayout = new QHBoxLayout(rightDetailViewHolder);
+    rvLayout->setMargin(0);
+
+    detailView = new DFMRightDetailView(currentView ? currentView->rootUrl() : DUrl());
+    QFrame *rightDetailVLine = new QFrame;
+    AC_SET_OBJECT_NAME(rightDetailVLine, AC_DM_RIGHT_VIEW_DETAIL_VLINE);
+    AC_SET_ACCESSIBLE_NAME(rightDetailVLine, AC_DM_RIGHT_VIEW_DETAIL_VLINE);
+    rightDetailVLine->setFrameShape(QFrame::VLine);
+    rvLayout->addWidget(rightDetailVLine);
+    rvLayout->addWidget(detailView, 1);
+    midLayout->addWidget(rightDetailViewHolder, 1);
+    rightDetailViewHolder->setVisible(false); //不显示先
+}
+
 DFileManagerWindow::DFileManagerWindow(QWidget *parent)
     : DFileManagerWindow(DUrl(), parent)
 {
@@ -546,7 +676,7 @@ DFileManagerWindow::DFileManagerWindow(const DUrl &fileUrl, QWidget *parent)
     // 判断出入的url是否是一个目录，不是就取parentUrl
     DUrl newurl = fileUrl;
     //排除u盘自动挂载，并且自动打开，拖拽的文件都是FILE_SCHEME
-    if (newurl.scheme() == FILE_SCHEME) {
+    if (newurl.scheme() == FILE_SCHEME || newurl.scheme() == DFMVAULT_SCHEME) {
         const DAbstractFileInfoPointer &fileInfo = DFileService::instance()->createFileInfo(nullptr, fileUrl);
 
         if (fileInfo && !fileInfo->isDir()) {
@@ -820,8 +950,23 @@ bool DFileManagerWindow::cd(const DUrl &fileUrl)
         d->toolbar->addHistoryStack();
         d->tabBar->createTab(nullptr);
     }
+    // fix bug 99023 smb挂载成功后所有的标签页是访问smb网络地址的都需要切换到挂载点
+    DUrl tmpUrl;
+    if (fileUrl.scheme().contains(NETWORK_REDIRECT_SCHEME_EX)) {
+        tmpUrl.setScheme(fileUrl.scheme().replace(NETWORK_REDIRECT_SCHEME_EX, ""));
+        DUrl newworkUrl = DUrl(fileUrl.query());
+        tmpUrl.setPath(fileUrl.path());
+        for (int i = 0; i < d->tabBar->count(); ++i) {
+            if (i == d->tabBar->currentIndex())
+                continue;
+            if (d->tabBar->tabAt(i)->currentUrl() == newworkUrl)
+                d->cdForTab(d->tabBar->tabAt(i), tmpUrl);
+        }
+    } else {
+        tmpUrl = fileUrl;
+    }
 
-    if (!d->cdForTab(d->tabBar->currentTab(), fileUrl)) {
+    if (!d->cdForTab(d->tabBar->currentTab(), tmpUrl)) {
         return false;
     }
 
@@ -1045,7 +1190,7 @@ void DFileManagerWindow::initUI()
     D_DC(DFileManagerWindow);
 
     resize(DEFAULT_WINDOWS_WIDTH, DEFAULT_WINDOWS_HEIGHT);
-    setMinimumSize(680, 420);
+    setMinimumSize(760, 420);
     initTitleBar();
     initCentralWidget();
     setCentralWidget(d->centralWidget);
@@ -1260,34 +1405,15 @@ void DFileManagerWindow::initCentralWidget()
     QVBoxLayout *mainLayout = new QVBoxLayout;
 
     QWidget *midWidget = new QWidget;
-    QHBoxLayout *midLayout = new QHBoxLayout;
+    d->midLayout = new QHBoxLayout;
     AC_SET_OBJECT_NAME(midWidget, AC_VIEW_MID_WIDGET);
     AC_SET_ACCESSIBLE_NAME(midWidget, AC_VIEW_MID_WIDGET);
 
-    midWidget->setLayout(midLayout);
+    midWidget->setLayout(d->midLayout);
     //! lixiang start 设置后显示空间会大些
-    midLayout->setContentsMargins(0, 0, 0, 0);
+    d->midLayout->setContentsMargins(0, 0, 0, 0);
     //! lixiang end
-    midLayout->addWidget(d->splitter);
-
-    d->rightDetailViewHolder = new QFrame;
-    d->rightDetailViewHolder->setObjectName("rightviewHolder");
-    AC_SET_ACCESSIBLE_NAME(d->rightDetailViewHolder, AC_DM_RIGHT_VIEW_HOLDER);
-    d->rightDetailViewHolder->setAutoFillBackground(true);
-    d->rightDetailViewHolder->setBackgroundRole(QPalette::ColorRole::Base);
-    d->rightDetailViewHolder->setFixedWidth(320);
-    QHBoxLayout *rvLayout = new QHBoxLayout(d->rightDetailViewHolder);
-    rvLayout->setMargin(0);
-
-    d->detailView = new DFMRightDetailView(currentUrl());
-    QFrame *rightDetailVLine = new QFrame;
-    AC_SET_OBJECT_NAME(rightDetailVLine, AC_DM_RIGHT_VIEW_DETAIL_VLINE);
-    AC_SET_ACCESSIBLE_NAME(rightDetailVLine, AC_DM_RIGHT_VIEW_DETAIL_VLINE);
-    rightDetailVLine->setFrameShape(QFrame::VLine);
-    rvLayout->addWidget(rightDetailVLine);
-    rvLayout->addWidget(d->detailView, 1);
-    midLayout->addWidget(d->rightDetailViewHolder, 1);
-    d->rightDetailViewHolder->setVisible(false); //不显示先
+    d->midLayout->addWidget(d->splitter);
 
     mainLayout->addWidget(midWidget);
     mainLayout->setSpacing(0);
@@ -1355,20 +1481,28 @@ void DFileManagerWindow::initConnect()
 
     QObject::connect(fileSignalManager, &FileSignalManager::requestMultiFilesRename, this, &DFileManagerWindow::onShowRenameBar);
     QObject::connect(d->tabBar, &TabBar::currentChanged, this, &DFileManagerWindow::onTabBarCurrentIndexChange);
-    QObject::connect(d->toolbar, &DToolBar::detailButtonClicked, this, [d]() {
+    QObject::connect(d->toolbar, &DToolBar::detailButtonClicked, this, [this, d]() {
+        if (!d->rightDetailViewHolder) {
+            d->createRightDetailViewHolder();
+        }
+
         if (d->rightDetailViewHolder) {
             d->rightDetailViewHolder->setVisible(!d->rightDetailViewHolder->isVisible());
+            //! 触发resize事件，避免文件列表未自适应宽度
+            if (d->currentView && d->currentView->widget()) {
+                QSize variable(1, 1);
+                d->currentView->widget()->resize(d->currentView->widget()->size() - variable);
+                d->currentView->widget()->resize(d->currentView->widget()->size() + variable);
+            }
             qDebug() << "File information window on the right";
         }
+
+        // 这里需要更新 selectUrlChanged
+        d->updateSelectUrl();
     });
 
     QObject::connect(this, &DFileManagerWindow::selectUrlChanged, this, [d](/*const QList<DUrl> &urlList*/) {
-        DFileView *fv = dynamic_cast<DFileView *>(d->currentView);
-        if (d->detailView && fv) {
-            d->detailView->setUrl(fv->selectedUrls().value(0, fv->rootUrl()));
-            if (fv->selectedIndexCount() == 0)
-                d->detailView->setTagWidgetVisible(false);
-        }
+        d->updateSelectUrl();
     });
 
     //! redirect when tab root url changed.
@@ -1377,6 +1511,56 @@ void DFileManagerWindow::initConnect()
     QObject::connect(fileSignalManager, &FileSignalManager::cdFolder, this, &DFileManagerWindow::cd);
 }
 
+void DFileManagerWindow::startSambaServiceAsync(Tab *tab, const DUrl &fileUrl)
+{
+    QDBusInterface interface("org.freedesktop.systemd1",
+                             "/org/freedesktop/systemd1/unit/smbd_2eservice",
+                             "org.freedesktop.systemd1.Unit",
+                             QDBusConnection::systemBus());
+
+    QDBusPendingCall pcall = interface.asyncCall(QLatin1String("Start"), QString("replace"));
+
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(pcall, this);
+
+    QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, &DFileManagerWindow::callFinishedSlot);
+
+    m_currentTab = tab;
+    m_currentUrl = fileUrl;
+}
+
+void DFileManagerWindow::callFinishedSlot(QDBusPendingCallWatcher *watcher)
+{
+    QObject::disconnect(watcher, &QDBusPendingCallWatcher::finished, this, &DFileManagerWindow::callFinishedSlot);
+
+    QDBusPendingReply<> reply = *watcher;
+    watcher->deleteLater();
+    if (reply.isValid()) {
+        const QString &errorMsg = reply.reply().errorMessage();
+        if (errorMsg.isEmpty()) {
+            qDebug() << "smbd service start success";
+
+            // 自启动
+            // 这里创建链接文件 以便下次开机自启
+            UserShareInterface userShareInterface("com.deepin.filemanager.daemon",
+                                                  "/com/deepin/filemanager/daemon/UserShareManager",
+                                                  QDBusConnection::systemBus(),
+                                                  this);
+            QDBusReply<bool> reply = userShareInterface.createShareLinkFile();
+            if (reply.isValid()) {
+                qDebug() << "set usershare password:" << reply.value();
+                if(reply.value()) {
+                    Q_D(DFileManagerWindow);
+                    d->cdForTab(m_currentTab, m_currentUrl);
+                }
+            } else {
+                qDebug() << "set usershare password:" << reply.error();
+            }
+        }
+    } else {
+        dialogManager->showErrorDialog(QString(), QObject::tr("Failed to start Samba services"));
+    }
+}
+
 void DFileManagerWindow::moveCenterByRect(QRect rect)
 {
     QRect qr = frameGeometry();
@@ -1481,6 +1665,9 @@ void DFileManagerWindow::onRequestDestruct()
 
 void DFileManagerWindow::showEvent(QShowEvent *event)
 {
+    Q_D(DFileManagerWindow);
+    d->m_isNeedClosed = false;
+
     DMainWindow::showEvent(event);
 
     const QVariantMap &state = DFMApplication::appObtuselySetting()->value("WindowManager", "SplitterState").toMap();
@@ -1584,3 +1771,9 @@ bool DFileManagerWindow::getCanDestruct() const
     return true;
 }
 
+void DFileManagerWindow::clearActions()
+{
+    if (fileMenuManger)
+        fileMenuManger->clearActions();
+}
+
