@@ -28,13 +28,16 @@
 #include "singleton.h"
 #include "app/define.h"
 #include "drootfilemanager.h"
-
+#include "dtoolbar.h"
+#include "utils.h"
 #include "dfmsidebarmanager.h"
+#include "dfmsidebaritemdelegate.h"
+#include "dfmsidebaritem.h"
+#include "dfmopticalmediawidget.h"
+
 #include "interfaces/dfmsidebariteminterface.h"
 #include "views/dfmsidebarview.h"
 #include "models/dfmsidebarmodel.h"
-#include "dfmsidebaritemdelegate.h"
-#include "dfmsidebaritem.h"
 #include "models/dfmrootfileinfo.h"
 #include "controllers/dfmsidebardefaultitemhandler.h"
 #include "controllers/dfmsidebarbookmarkitemhandler.h"
@@ -44,10 +47,14 @@
 #include "controllers/vaultcontroller.h"
 #include "controllers/pathmanager.h"
 #include "app/filesignalmanager.h"
-#include "interfaces/dfilemenu.h"
-#include "dfmopticalmediawidget.h"
 #include "vault/vaulthelper.h"
+#include "interfaces/dfilemenu.h"
 #include "accessibility/ac-lib-file-manager.h"
+#include "deviceinfo/udisklistener.h"
+#include "shutil/fileutils.h"
+#include "dtoolbar.h"
+#include "utils.h"
+#include "controllers/bookmarkmanager.h"
 
 #include <DApplicationHelper>
 #include <QScrollBar>
@@ -62,6 +69,8 @@
 
 #include <algorithm>
 
+#include "plugins/schemepluginmanager.h"
+
 #define SIDEBAR_ITEMORDER_KEY "SideBar/ItemOrder"
 
 DFM_BEGIN_NAMESPACE
@@ -89,6 +98,8 @@ DFMSideBar::DFMSideBar(QWidget *parent)
     initRecentItem();
 
     //   DFMSideBarManager::instance();
+    //NOTE [XIAO] 从Plugin中导入SideBarItem
+    initItemFromPlugin();
 }
 
 DFMSideBar::~DFMSideBar()
@@ -114,9 +125,11 @@ void DFMSideBar::scrollToGroup(const QString &groupName)
     m_sidebarView->scrollTo(groupModelIndex(groupName));
 }
 
-void DFMSideBar::setCurrentUrl(const DUrl &url)
+void DFMSideBar::setCurrentUrl(const DUrl &url, bool changeUrl)
 {
-    int index = findItem(url, true);
+    QMutexLocker lk(&m_currentUrlMutex);
+    m_currentUrl = changeUrl ? url : m_currentUrl;
+    int index = findItem(m_currentUrl, true);
     if (index != -1) {
         m_sidebarView->setCurrentIndex(m_sidebarModel->index(index, 0));
         m_sidebarView->updateItemUniqueKey(m_sidebarView->currentIndex());
@@ -155,10 +168,13 @@ int DFMSideBar::findItem(const DFMSideBarItem *item) const
 
 int DFMSideBar::findItem(const DUrl &url, const QString &group) const
 {
-    for (int i = 0; i < m_sidebarModel->rowCount(); i++) {
+    for (int i = 0, nEnd = m_sidebarModel->rowCount(); i < nEnd; ++i) {
         DFMSideBarItem *item = m_sidebarModel->itemFromIndex(i);
-        if (item->itemType() == DFMSideBarItem::SidebarItem && item->groupName() == group) {
-            if (item->url() == url) {
+        const auto &itemType = item->itemType();
+        const auto &itemGroupName = item->groupName();
+        if (itemType == DFMSideBarItem::SidebarItem && itemGroupName == group) {
+            const auto &itemUrl = item->url();
+            if (itemUrl == url) {
                 return i;
             }
         }
@@ -374,8 +390,21 @@ void DFMSideBar::rootFileResult()
                 continue;
             }
             if (Singleton<PathManager>::instance()->isVisiblePartitionPath(fi)) {
-                addItem(DFMSideBarDeviceItemHandler::createItem(fi->fileUrl()), groupName(Device));
-                devitems.push_back(fi->fileUrl());
+                // 这里需要根据url进行排序
+                const auto &url = fi->fileUrl();
+                auto r = std::upper_bound(devitems.begin(), devitems.end(), url,
+                [](const DUrl & a, const DUrl & b) {
+                    DAbstractFileInfoPointer fia = fileService->createFileInfo(nullptr, a);
+                    DAbstractFileInfoPointer fib = fileService->createFileInfo(nullptr, b);
+                    return DFMRootFileInfo::typeCompare(fia, fib);
+                });
+                if (r == devitems.end()) {
+                    this->addItem(DFMSideBarDeviceItemHandler::createItem(url), this->groupName(Device));
+                    devitems.append(url);
+                } else {
+                    this->insertItem(this->findLastItem(this->groupName(Device)) - (devitems.end() - r) + 1, DFMSideBarDeviceItemHandler::createItem(url), this->groupName(Device));
+                    devitems.insert(r, url);
+                }
             }
         }
     }
@@ -396,6 +425,17 @@ void DFMSideBar::onItemActivated(const QModelIndex &index)
 
     QScopedPointer<DFMSideBarItemInterface> interface(DFMSideBarManager::instance()->createByIdentifier(identifierStr));
     if (interface) {
+        // searchBarTextEntered also invoke "checkGvfsMountFileBusy", forbit invoke twice
+        if (item->url().path().endsWith(SUFFIX_STASHED_REMOTE)) {
+            DFileManagerWindow *window = qobject_cast<DFileManagerWindow *>(this->window());
+            if (window) {
+                auto path = RemoteMountsStashManager::normalizeConnUrl(item->url().path());
+                window->getToolBar()->searchBarTextEntered(path);
+                return;
+            }
+        }
+
+
         //判断网络文件是否可以到达
         if (DFileService::instance()->checkGvfsMountfileBusy(item->url())) {
             return;
@@ -453,7 +493,6 @@ void DFMSideBar::onContextMenuRequested(const QPoint &pos)
         DFileService::instance()->setCursorBusyState(false);
     }
     DFileService::instance()->setCursorBusyState(false);
-    return;
 }
 
 void DFMSideBar::onRename(const QModelIndex &index, QString newName) const
@@ -465,6 +504,8 @@ void DFMSideBar::onRename(const QModelIndex &index, QString newName) const
     if (interface && !newName.isEmpty() && item->text() != newName) {
         interface->rename(item, newName);
     }
+    if(m_sidebarView)
+        m_sidebarView->update();
 }
 
 void DFMSideBar::initUI()
@@ -488,7 +529,9 @@ void DFMSideBar::initModelData()
     qRegisterMetaTypeStreamOperators<DUrl>("DUrl");
 
     static QList<DFMSideBar::GroupName> groups = {
-        GroupName::Common, GroupName::Device, GroupName::Bookmark, GroupName::Network, GroupName::Tag
+        //NOTE [REN] 添加Plugin类型，实现插件组的分割线
+
+        GroupName::Common, GroupName::Device, GroupName::Bookmark, GroupName::Network, GroupName::Tag, GroupName::Plugin
     };
 
     //bool hasSeparator = false;
@@ -508,6 +551,27 @@ void DFMSideBar::initModelData()
 
 void DFMSideBar::initConnection()
 {
+    connect(DFMApplication::instance(), &DFMApplication::reloadComputerModel, this, [this]{
+        bool vaultEnable = VaultHelper::isVaultEnabled();
+        if (vaultEnable) {
+            // if vault is enabled, check if it is exist in sidebar
+            int index = findItem([&](const DFMSideBarItem *item) {return item->url().scheme() == DFMVAULT_SCHEME;});
+            if (index > 0)
+                return;
+
+            // otherwise insert it just below computer item
+            index = findItem([&](const DFMSideBarItem *item) {return item->url().scheme() == COMPUTER_SCHEME;});
+            if (index > 0)
+                this->insertItem(index+1, DFMSideBarVaultItemHandler::createItem("Vault"), groupName(GroupName::Device));
+        } else {
+            // check if vault item is in sidebar
+            int index = findItem([&](const DFMSideBarItem *item) {return item->url().scheme() == DFMVAULT_SCHEME;});
+            if (index < 0)
+                return;
+            this->m_sidebarModel->removeRow(index);
+        }
+    });
+
     // drag to delete bookmark or tag
     connect(m_sidebarView, &DFMSideBarView::requestRemoveItem, this, [this]() {
         DFMSideBarItem *item = m_sidebarModel->itemFromIndex(m_sidebarView->currentIndex());
@@ -661,6 +725,8 @@ void DFMSideBar::initBookmarkConnection()
             }
         }
     });
+
+    bookmarkManager->refreshBookmark();
 }
 
 void DFMSideBar::initDeviceConnection()
@@ -718,12 +784,50 @@ void DFMSideBar::initDeviceConnection()
                 this->insertItem(this->findLastItem(this->groupName(Device)) - (devitems.end() - r) + 1, DFMSideBarDeviceItemHandler::createItem(url), this->groupName(Device));
                 devitems.insert(r, url);
             }
+            //还原url
+            if (m_currentUrl == fi->redirectedFileUrl())
+                setCurrentUrl(m_currentUrl, false);
         }
     });
     connect(devicesWatcher, &DAbstractFileWatcher::fileDeleted, this, [this](const DUrl & url) {
+        bool curUrlCanAccess = true; // 初始化为true 避免影响原有逻辑
+        auto fi = fileService->createFileInfo(nullptr, m_currentUrl);
+        if (fi)
+            curUrlCanAccess = fi->exists();
         int index = findItem(url, groupName(Device));
-        if (m_sidebarView->currentIndex().row() == index && index != -1) {
-            index = findItem(DUrl::fromLocalFile(QDir::homePath()), groupName(Common));
+        int curIndex = m_sidebarView->currentIndex().row();
+        if ((curIndex == index && index != -1)
+                || (!curUrlCanAccess)) {
+
+            DUrl urlSkip;
+            const QString &absFilePath = url.toAbsolutePathUrl().path();
+            QString localFilePath = QUrl::fromPercentEncoding(url.path().toLocal8Bit());
+            localFilePath = localFilePath.startsWith("//") ? localFilePath.mid(1) : localFilePath;
+
+            const auto &allDevice = deviceListener->getAllDeviceInfos();
+            bool blockDevice = false;
+            for (const auto &dev : allDevice.keys()) {
+                if (dev.contains(absFilePath.left(absFilePath.indexOf(".localdisk")))) {
+                    blockDevice = true;
+                    break;
+                }
+            }
+
+            // 判断删除的路径是否是外设路径，外设路径需要跳转到computer页面
+            bool turnToComputer = false;
+            if (deviceListener->isInDeviceFolder(absFilePath)
+                    || localFilePath.startsWith("/run/user")
+                    || localFilePath.startsWith("/media/")
+                    || blockDevice // like u disk
+                    || FileUtils::isGvfsMountFile(localFilePath)
+                    ) {
+                urlSkip = DUrl(COMPUTER_ROOT);
+                turnToComputer = true;
+            } else {
+                urlSkip = DUrl::fromLocalFile(QDir::homePath());
+            }
+
+            index = findItem(urlSkip, groupName(turnToComputer ? Device : Common));
             DFMSideBarItem *item = m_sidebarModel->itemFromIndex(index);
             if (item) {
                 QString identifierStr = item->registeredHandler(SIDEBAR_ID_INTERNAL_FALLBACK);
@@ -809,6 +913,25 @@ void DFMSideBar::initTagsConnection()
     //    });
 }
 
+//NOTE [XIAO] 从Plugin中导入SideBarItem
+void DFMSideBar::initItemFromPlugin()
+{
+    if (!m_disableUrlSchemes.contains(PLUGIN_SCHEME)) {
+        // tab标签页不会显示“我的手机”，因为路径初始化的时候还没有开始加载插件
+        // 在这里插件已经加载过所以调用initPaths再加载一下插件的路径 add by CL
+        Singleton<PathManager>::instance()->initPaths();
+        qInfo() << "[PLUGIN]" << "try to load plugin of sidebar item";
+        auto plugins = SchemePluginManager::instance()->schemePlugins();
+        for (auto plugin : plugins) {
+            qInfo() << "[PLUGIN]" << "load sidebar item from plugin:" << plugin.first;
+            DFMSideBarItem *item = plugin.second->createSideBarItem();
+            // NOTE [XIAO] 插件中的GroupName与文管版本中一致。
+            //this->addItem(item, item->groupName());
+            this->appendItem(item, item->groupName());
+        }
+    }
+}
+
 void DFMSideBar::applySidebarColor()
 {
     m_sidebarView->setBackgroundType(DStyledItemDelegate::BackgroundType(DStyledItemDelegate::RoundedBackground | DStyledItemDelegate::NoNormalState));
@@ -879,10 +1002,10 @@ void DFMSideBar::addGroupItems(DFMSideBar::GroupName groupType)
             break;
         }
 
-        QList<DAbstractFileInfoPointer> bookmarkInfos = DFileService::instance()->getChildren(this, DUrl(BOOKMARK_ROOT),                                                         QStringList(), QDir::AllEntries);
+        const DUrlList urlList = bookmarkManager->getBookmarkUrls();
         QList<DFMSideBarItem *> unsortedList;
-        for (const DAbstractFileInfoPointer &info : bookmarkInfos) {
-            unsortedList << DFMSideBarBookmarkItemHandler::createItem(info->fileUrl());
+        for (const DUrl &url : urlList) {
+            unsortedList << DFMSideBarBookmarkItemHandler::createItem(url);
         }
         appendItemWithOrder(unsortedList, savedItemOrder(groupNameStr), groupNameStr);
         break;
