@@ -27,6 +27,7 @@
 #include "dfmopticalmediawidget.h"
 #include "controllers/vaultcontroller.h"
 #include "accessibility/ac-lib-file-manager.h"
+#include "plugins/schemepluginmanager.h"
 
 #include <QDebug>
 #include <dstorageinfo.h>
@@ -38,7 +39,7 @@
 #include <unistd.h>
 
 //#define DRAG_EVENT_URLS "UrlsInDragEvent"
-#define DRAG_EVENT_URLS ((getuid()==0) ? (QString(getlogin())+"_RootUrlsInDragEvent") :(QString(getlogin())+"_UrlsInDragEvent"))
+#define DRAG_EVENT_URLS ((getuid() == 0) ? (QString(getlogin()) + "_RootUrlsInDragEvent") : (QString(getlogin()) + "_UrlsInDragEvent"))
 
 DFM_BEGIN_NAMESPACE
 
@@ -50,15 +51,15 @@ DFMSideBarView::DFMSideBarView(QWidget *parent)
 
     setVerticalScrollMode(ScrollPerPixel);
     setIconSize(QSize(16, 16));
-//    setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
+    //    setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
-    setMouseTracking(true); // sp3 feature 35，解除注释以便鼠标在移动时就能触发 mousemoveevent
+    setMouseTracking(true);   // sp3 feature 35，解除注释以便鼠标在移动时就能触发 mousemoveevent
 
     setDragDropMode(QAbstractItemView::InternalMove);
     setDragDropOverwriteMode(false);
     //QListView拖拽时会先插入后删除，于是可以通过rowCountChanged()信号来判断拖拽操作是否结束
-    connect(this, &DFMSideBarView::rowCountChanged, this, &DFMSideBarView::onRowCountChanged);  //Qt5风格
+    connect(this, &DFMSideBarView::rowCountChanged, this, &DFMSideBarView::onRowCountChanged);   //Qt5风格
     connect(this, static_cast<void (DListView::*)(const QModelIndex &)>(&DListView::currentChanged), this, &DFMSideBarView::currentChanged);
 
     m_lastOpTime = 0;
@@ -90,14 +91,24 @@ void DFMSideBarView::mousePressEvent(QMouseEvent *event)
 
 void DFMSideBarView::mouseMoveEvent(QMouseEvent *event)
 {
+    // Fix bug#106858
+    // 当侧边栏选中项不可拖拽，但用户执行拖拽移动操作时，直接返回
+    if (event->buttons() & Qt::LeftButton) {
+        DFMSideBarModel *mod = dynamic_cast<DFMSideBarModel *>(model());
+        if (mod) {
+            DFMSideBarItem *item = mod->itemFromIndex(currentIndex());
+            if (item && !item->isDragEnabled())
+                return;
+        }
+    }
     DListView::mouseMoveEvent(event);
     // sp3 feature 35，光标悬浮到光驱item上如果正在加载，需要显示为繁忙光标。添加判定避免额外操作
     if (event->button() == Qt::NoButton) {
         const QModelIndex &idx = indexAt(event->pos());
         QString voltag = idx.data(DFMSideBarItem::ItemVolTagRole).toString();
         if (!voltag.isEmpty() && voltag.startsWith("sr")
-                && DFMOpticalMediaWidget::g_mapCdStatusInfo.contains(voltag)
-                && DFMOpticalMediaWidget::g_mapCdStatusInfo[voltag].bLoading) {
+            && DFMOpticalMediaWidget::g_mapCdStatusInfo.contains(voltag)
+            && DFMOpticalMediaWidget::g_mapCdStatusInfo[voltag].bLoading) {
             // 设置光标为繁忙状态
             DFileService::instance()->setCursorBusyState(true);
         } else {
@@ -107,15 +118,15 @@ void DFMSideBarView::mouseMoveEvent(QMouseEvent *event)
 #if QT_CONFIG(draganddrop)
         if (state() == DraggingState) {
             startDrag(Qt::MoveAction);
-            setState(NoState); // the startDrag will return when the dnd operation is done
+            setState(NoState);   // the startDrag will return when the dnd operation is done
             stopAutoScroll();
             QPoint pt = mapFromGlobal(QCursor::pos());
             QRect rc = geometry();
             if (!rc.contains(pt)) {
-                emit requestRemoveItem(); //model()->removeRow(currentIndex().row());
+                emit requestRemoveItem();   //model()->removeRow(currentIndex().row());
             }
         }
-#endif // QT_CONFIG(draganddrop)
+#endif   // QT_CONFIG(draganddrop)
     }
 }
 
@@ -127,7 +138,12 @@ void DFMSideBarView::dragEnterEvent(QDragEnterEvent *event)
         //防止误判之前的url数据，这里清空缓存
         m_urlsForDragEvent.clear();
     } else {
-        fetchDragEventUrlsFromSharedMemory();
+        bool sameUser = DFMGlobal::isMimeDatafromCurrentUser(event->mimeData());
+        if (sameUser) {
+            fetchDragEventUrlsFromSharedMemory();
+        } else {
+            m_urlsForDragEvent = event->mimeData()->urls();
+        }
     }
 
     if (isAccepteDragEvent(event)) {
@@ -164,7 +180,7 @@ void DFMSideBarView::dropEvent(QDropEvent *event)
     }
 
     qDebug() << "source: " << event->mimeData()->urls();
-    qDebug() << "target item: " << item->groupName() << "|" << item->text() <<  "|" << item->url();
+    qDebug() << "target item: " << item->groupName() << "|" << item->text() << "|" << item->url();
 
     //wayland环境下QCursor::pos()在此场景中不能获取正确的光标当前位置，代替方案为直接使用QDropEvent::pos()
     //QDropEvent::pos() 实际上就是drop发生时光标在该widget坐标系中的position (mapFromGlobal(QCursor::pos()))
@@ -180,7 +196,7 @@ void DFMSideBarView::dropEvent(QDropEvent *event)
     // 主要有4种场景：1.都是可读写的场景; 2.文件夹是只读属性，子集是可读写的; 3.文件夹或文件是可读写的; 4.拖动的包含 可读写的和只读的
     DUrlList urls, copyUrls;
     for (const QUrl &url : event->mimeData()->urls()) {
-        if (DUrl(url).parentUrl() == item->url()) {
+        if (DUrl(url).parentUrl() == item->url() && !DFMGlobal::keyCtrlIsPressed()) {
             qDebug() << "skip the same dir file..." << url;
         } else {
             QString folderPath = DUrl(url).parentUrl().path();
@@ -190,19 +206,25 @@ void DFMSideBarView::dropEvent(QDropEvent *event)
             bool isFileWritable = false;
 
             if (VaultController::isVaultFile(folderPath)
-                    || VaultController::isVaultFile(filePath)) {
+                || VaultController::isVaultFile(filePath)) {
                 //! vault file get permissions separatly
                 isFolderWritable = VaultController::getPermissions(folderPath) & QFileDevice::WriteUser;
                 isFileWritable = VaultController::getPermissions(filePath) & QFileDevice::WriteUser;
             } else {
-                QFileInfo folderinfo(folderPath); // 判断上层文件是否是只读，有可能上层是只读，而里面子文件或文件夾又是可以写
+                QFileInfo folderinfo(folderPath);   // 判断上层文件是否是只读，有可能上层是只读，而里面子文件或文件夾又是可以写
                 QFileInfo fileinfo(filePath);
 
-                isFolderWritable = fileinfo.isWritable();
-                isFileWritable = folderinfo.isWritable();
+                isFileWritable = fileinfo.isWritable();
+                isFolderWritable = folderinfo.isWritable();
+
+                //fix 89245 选择Root权限的链接文件，拖拽到侧边栏回收站中，无法拖拽文件到回收站
+                if (isFolderWritable && fileinfo.isSymLink() && item->url().toString() == TRASH_ROOT) {
+                    urls << DUrl(url);
+                    continue;
+                }
             }
 
-            if (!isFolderWritable || !isFileWritable) {
+            if (!isFolderWritable) {
                 copyUrls << DUrl(url);
                 qDebug() << "this is a unwriteable case:" << url;
             } else {
@@ -218,13 +240,38 @@ void DFMSideBarView::dropEvent(QDropEvent *event)
             action = canDropMimeData(item, event->mimeData(), event->possibleActions());
         }
 
+        if (item->url().scheme() == PLUGIN_SCHEME) {   // 对我的手机目录执行的单独拖拽动作，拖拽目录固定 add by CL
+            for (auto plugin : SchemePluginManager::instance()->schemePlugins()) {
+                if ((item->url().host() == plugin.first) && plugin.second->isSideBarItemSupportedDrop()) {
+                    if (urls.size() > 0 && plugin.second->dropFileToPlugin(urls, item->url())) {
+                        event->setDropAction(action);
+                        isActionDone = true;
+                    }
+                    break;
+                }
+            }
+        }
+
         if (urls.size() > 0 && onDropData(urls, item->url(), action)) {
             event->setDropAction(action);
             isActionDone = true;
         }
     }
     if (!copyUrls.isEmpty()) {
-        if (onDropData(copyUrls, item->url(), Qt::CopyAction)) {  // 对于只读权限的，只能进行 copy动作
+        if (item->url().scheme() == PLUGIN_SCHEME) {   // 对我的手机目录执行的单独拖拽动作，拖拽目录固定 add by CL
+            for (auto plugin : SchemePluginManager::instance()->schemePlugins()) {
+                if ((item->url().host() == plugin.first) && plugin.second->isSideBarItemSupportedDrop()) {
+                    if (urls.size() > 0 && plugin.second->dropFileToPlugin(urls, item->url())) {
+                        event->setDropAction(Qt::CopyAction);
+                        isActionDone = true;
+                    }
+
+                    break;
+                }
+            }
+        }
+
+        if (onDropData(copyUrls, item->url(), Qt::CopyAction)) {   // 对于只读权限的，只能进行 copy动作
             event->setDropAction(Qt::CopyAction);
             isActionDone = true;
         }
@@ -260,12 +307,12 @@ QModelIndex DFMSideBarView::indexAt(const QPoint &p) const
 
 QModelIndex DFMSideBarView::getPreviousIndex() const
 {
-    return  m_previous;
+    return m_previous;
 }
 
 QModelIndex DFMSideBarView::getCurrentIndex() const
 {
-    return  m_current;
+    return m_current;
 }
 
 void DFMSideBarView::currentChanged(const QModelIndex &previous)
@@ -297,17 +344,35 @@ bool DFMSideBarView::onDropData(DUrlList srcUrls, DUrl dstUrl, Qt::DropAction ac
         dstUrl = dstInfo->rootSymLinkTarget();
     }
 
+    //这里不能全redirected例如ftp内的书签会有问题
+    if (dstInfo->canRedirectionFileUrl()) {
+        DUrl url = dstInfo->redirectedFileUrl();
+        if (url.burnIsOnDisc()) {
+            dstUrl = url;
+        }
+    }
+
     switch (action) {
     case Qt::CopyAction:
         // blumia: should run in another thread or user won't do another DnD opreation unless the copy action done.
-        QtConcurrent::run([ = ]() {
+        QtConcurrent::run([=]() {
             fileService->pasteFile(this, DFMGlobal::CopyAction, dstUrl, srcUrls);
         });
+
         break;
     case Qt::LinkAction:
         break;
     case Qt::MoveAction:
-        fileService->pasteFile(this, DFMGlobal::CutAction, dstUrl, srcUrls);
+        // fix bug 81143 ，开启普通文件删除提示功能后，打开最近使用和回收站两个窗口，拖拽最近使用到回收站，在还没有
+        // 弹出对话框的时候，快速框选最近访问窗口。这时弹窗出现(使用的runinMainThread)使用的exec就会开启一个本地事件循环，将框选事件加入本地循环
+        // 执行，框选事件又在等待drag事件结束（mousemove事件结束），本地事件又阻塞drag事件，相互等待。使用线程去执行
+        // 业务逻辑，让drop事件快速返回。
+        if (dstUrl.isTrashFile()) {
+            QtConcurrent::run([=]() {
+                fileService->moveToTrash(this, srcUrls);
+            });
+        } else
+            fileService->pasteFile(this, DFMGlobal::CutAction, dstUrl, srcUrls);
         break;
     default:
         return false;
@@ -347,12 +412,22 @@ Qt::DropAction DFMSideBarView::canDropMimeData(DFMSideBarItem *item, const QMime
     if (urls.empty()) {
         return Qt::IgnoreAction;
     }
+    const DAbstractFileInfoPointer &info = fileService->createFileInfo(this, item->url());
+    DUrl itemUrl = item->url();
+    if (itemUrl.isBookMarkFile() && info && info->canRedirectionFileUrl())
+        itemUrl = info->redirectedFileUrl();
 
     for (const QUrl &url : urls) {
         const DAbstractFileInfoPointer &fileInfo = fileService->createFileInfo(this, DUrl(url));
-        if (!fileInfo || !fileInfo->isReadable()) {
+        if (!fileInfo || !info)
             return Qt::IgnoreAction;
+
+        if (!itemUrl.isTaggedFile()) {
+            bool isInSameDevice = DStorageInfo::inSameDevice(fileInfo->fileUrl(), itemUrl);
+            if ((!isInSameDevice && !fileInfo->isReadable()) || (!DFMGlobal::keyCtrlIsPressed() && isInSameDevice && !fileInfo->canRename()))
+                return Qt::IgnoreAction;
         }
+
         //部分文件不能复制或剪切，需要在拖拽时忽略
         if (!fileInfo->canMoveOrCopy()) {
             return Qt::IgnoreAction;
@@ -363,35 +438,71 @@ Qt::DropAction DFMSideBarView::canDropMimeData(DFMSideBarItem *item, const QMime
         }
     }
 
-    const DAbstractFileInfoPointer &info = fileService->createFileInfo(this, item->url());
-
     if (!info || !info->canDrop()) {
+        for (auto plugin : SchemePluginManager::instance()->schemePlugins()) {
+            // 对我的手机item做临时处理，连接成功时允许向item拖拽
+            if ((item->url().scheme() == PLUGIN_SCHEME) && (item->url().host() == plugin.first) && plugin.second->isSideBarItemSupportedDrop()) {
+                return Qt::CopyAction;
+            }
+        }
+
         return Qt::IgnoreAction;
     }
-    Qt::DropAction action = Qt::IgnoreAction;
-    const Qt::DropActions support_actions = info->supportedDropActions() & actions;
 
-    if (DStorageInfo::inSameDevice(DUrl(urls.first()), item->url())) {
-        if (support_actions.testFlag(Qt::MoveAction)) {
+    Qt::DropAction action = Qt::CopyAction;
+    const Qt::DropActions support_actions = info->supportedDropActions() & actions;
+    const DUrl from = DUrl(urls.first());
+    DUrl to = info->fileUrl();
+
+    //fix bug#23703勾选自动整理，拖拽其他目录文件到桌面做得是复制操作
+    //因为自动整理的路径被DStorageInfo::inSameDevice判断为false，这里做转化
+    if (to.scheme() == BOOKMARK_SCHEME) {
+        if (info->canRedirectionFileUrl())
+            to = info->redirectedFileUrl();
+    }
+    //end
+
+    if (qApp->keyboardModifiers() == Qt::AltModifier) {
+        action = Qt::MoveAction;
+    } else if (!DFMGlobal::keyCtrlIsPressed()) {
+        // 如果文件和目标路径在同一个分区下，默认为移动文件，否则默认为复制文件
+        if (DStorageInfo::inSameDevice(from, to)) {
             action = Qt::MoveAction;
         }
     }
 
-    if (support_actions.testFlag(Qt::CopyAction)) {
+    //任意来源为回收站的drop操作均为move(统一回收站拖拽标准)
+    bool isFromTrash = from.url().contains(".local/share/Trash/");
+    bool isToTrash = to.isTrashFile();
+
+    if (isFromTrash || isToTrash) {
+        if (!isFromTrash || !isToTrash) {
+            action = Qt::MoveAction;
+        } else {
+            return Qt::IgnoreAction;
+        }
+    }
+
+    // 保险箱时，修改DropAction为Qt::CopyAction
+    if ((VaultController::isVaultFile(from.url())
+         || VaultController::isVaultFile(to.toString()))
+        && !isToTrash) {
         action = Qt::CopyAction;
     }
 
-    if (support_actions.testFlag(Qt::MoveAction)) {
-        action = Qt::MoveAction;
+    //跨用户的操作不允许修改原文件
+    if (!DFMGlobal::isMimeDatafromCurrentUser(data) && action == Qt::MoveAction)
+        action = Qt::CopyAction;
+
+    // 最近使用目录下的文件，只有拖拽到回收站为剪切，其他都为拷贝
+    if (from.isRecentFile())
+        action = isToTrash ? Qt::MoveAction : Qt::CopyAction;
+
+    if (support_actions.testFlag(action)) {
+        return action;
     }
 
-    if (support_actions.testFlag(Qt::LinkAction)) {
-        action = Qt::LinkAction;
-    }
-    if ((action == Qt::MoveAction) && DFMGlobal::keyCtrlIsPressed()) {
-        action = Qt::CopyAction;
-    }
-    return action;
+    return Qt::IgnoreAction;
 }
 
 bool DFMSideBarView::isAccepteDragEvent(DFMDragEvent *event)
@@ -402,6 +513,7 @@ bool DFMSideBarView::isAccepteDragEvent(DFMDragEvent *event)
     }
 
     bool accept = false;
+
     Qt::DropAction action = canDropMimeData(item, event->mimeData(), event->proposedAction());
     if (action == Qt::IgnoreAction) {
         action = canDropMimeData(item, event->mimeData(), event->possibleActions());
@@ -429,7 +541,7 @@ void DFMSideBarView::onRowCountChanged()
         QModelIndex currIdx = pModel->index(i, 0);
         if (pModel->data(currIdx, DFMSideBarItem::ItemUniqueKeyRole).toString() == m_strItemUniqueKey) {
             setCurrentIndex(currIdx);
-            QTimer::singleShot(50, this, [this] { m_strItemUniqueKey.clear(); }); // 发生拖拽排序的时候该函数会在短时间内触发两次，第二次才是准确数据，触发间隔时间 << 50ms，因此这里设置50ms后清空记录的key
+            QTimer::singleShot(50, this, [this] { m_strItemUniqueKey.clear(); });   // 发生拖拽排序的时候该函数会在短时间内触发两次，第二次才是准确数据，触发间隔时间 << 50ms，因此这里设置50ms后清空记录的key
             return;
         }
     }
@@ -454,10 +566,10 @@ bool DFMSideBarView::fetchDragEventUrlsFromSharedMemory()
     sm.lock();
     //用缓冲区得到共享内存关联后得到的数据和数据大小
     buffer.setData((char *)sm.constData(), sm.size());
-    buffer.open(QBuffer::ReadOnly);     //设置读取模式
-    in >> m_urlsForDragEvent;               //使用数据流从缓冲区获得共享内存的数据，然后输出到字符串中
-    sm.unlock();    //解锁
-    sm.detach();//与共享内存空间分离
+    buffer.open(QBuffer::ReadOnly);   //设置读取模式
+    in >> m_urlsForDragEvent;   //使用数据流从缓冲区获得共享内存的数据，然后输出到字符串中
+    sm.unlock();   //解锁
+    sm.detach();   //与共享内存空间分离
 
     return true;
 }
