@@ -30,16 +30,29 @@
 #include "views/dfmvaultactiveview.h"
 #include "views/dfilemanagerwindow.h"
 #include "dfilesystemmodel.h"
+#include "vaultglobaldefine.h"
+#include "app/define.h"
+#include "app/filesignalmanager.h"
+#include "singleton.h"
 
+#include <QDrag>
 
 DFMVaultFileView::DFMVaultFileView(QWidget *parent)
     : DFileView(parent)
 {
     connect(VaultController::ins(), &VaultController::signalLockVault, this, &DFMVaultFileView::onLeaveVault);
+    connect(fileSignalManager, &FileSignalManager::requestIgnoreDragEvent, this, &DFMVaultFileView::IgnoreDragEvent);
 }
 
 bool DFMVaultFileView::setRootUrl(const DUrl &url)
 {
+    if(!VaultController::ins()->isVaultVisiable()) {
+        DDialog dialog(tr("Hint"), tr("Cannot open this path"), this);
+        dialog.addButton(tr("OK"));
+        dialog.exec();
+        return false;
+    }
+
     VaultController::VaultState enState = VaultController::ins()->state();
 
     QWidget *wndPtr = widget()->topLevelWidget();
@@ -72,7 +85,8 @@ bool DFMVaultFileView::setRootUrl(const DUrl &url)
 
         //! 记录访问保险箱时间
         if (VaultController::isRootDirectory(url.toLocalFile())) {
-            DFM_NAMESPACE::DFMSettings setting(QString("vaultTimeConfig"));
+            VaultController::ins()->setVauleCurrentPageMark(VaultPageMark::VAULTPAGE);
+            DFM_NAMESPACE::DFMSettings setting(VAULT_TIME_CONFIG_FILE);
             setting.setValue(QString("VaultTime"), QString("InterviewTime"), QDateTime::currentDateTime().toString("yyyy-MM-dd hh:mm:ss"));
         }
     }
@@ -94,9 +108,15 @@ void DFMVaultFileView::onLeaveVault(int state)
 {
     if (state == 0) {
         this->cd(DUrl(COMPUTER_ROOT));
+        VaultController::ins()->setVauleCurrentPageMark(VaultPageMark::UNKNOWN);
     }
 }
 
+void DFMVaultFileView::IgnoreDragEvent()
+{
+    QDrag::cancel();
+}
+
 bool DFMVaultFileView::eventFilter(QObject *obj, QEvent *event)
 {
     if (event->type() == QEvent::HoverMove
@@ -111,3 +131,12 @@ bool DFMVaultFileView::eventFilter(QObject *obj, QEvent *event)
 
     return DFileView::eventFilter(obj, event);
 }
+
+void DFMVaultFileView::onRootUrlDeleted(const DUrl &rootUrl)
+{
+    // 修复bug-77747 保险箱上锁情况下会跳转到计算机页面，所以这里不用执行跳转
+    if (VaultController::ins()->state() == VaultController::Encrypted)
+        return;
+
+    DFileView::onRootUrlDeleted(rootUrl);
+}
