@@ -229,6 +229,18 @@ QString Tab::getDisplayNameByUrl(const DUrl &url) const
     if (url.isComputerFile()) {
         if (systemPathManager->isSystemPath(url.toString()))
             urlDisplayName = systemPathManager->getSystemPathDisplayNameByPath(url.toString());
+    }  //NOTE [REN] 这儿获取plugin插件的tab名
+    else if (url.isPluginFile()) {
+        if (systemPathManager->isSystemPath(url.toString())) {
+            urlDisplayName = systemPathManager->getSystemPathDisplayNameByPath(url.toString());
+        } else {
+            //NOTE [REN] plugin插件的非根目录的url也是存在plugin的，格式是plugin://***/***，也走这个判断流程
+            QString path = url.path();
+            if (path.contains("/")) {
+                QStringList listvalue = path.split("/");
+                urlDisplayName = listvalue.at(listvalue.size() - 1);
+            }
+        }
     } else if (url == DUrl::fromTrashFile("/")) {
         urlDisplayName = systemPathManager->getSystemPathDisplayName("Trash");
     } else if (PluginManager::instance()->getViewInterfacesMap().keys().contains(url.scheme())) {
@@ -302,8 +314,10 @@ void Tab::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidg
         painter->drawText((m_width - fm.width(str)) / 2, (m_height - fm.height()) / 2,
                           fm.width(str), fm.height(), 0, str);
     } else {
-        color = pal.color(QPalette::Active, QPalette::Base);
-        color = DGuiApplicationHelper::adjustColor(color, 0, 0, 0, 0, 0, 0, +51);
+        if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType)
+            color = QColor(235, 235, 235, 204);
+        else
+            color = QColor(30, 30, 30, 204);
         painter->fillRect(boundingRect(), color);
         painter->drawText((m_width - fm.width(str)) / 2, (m_height - fm.height()) / 2,
                           fm.width(str), fm.height(), 0, str);
@@ -933,11 +947,9 @@ void TabBar::updateScreen()
             animation->setDuration(100);
             animation->setStartValue(tab->geometry());
             animation->setEndValue(rect);
-            animation->start();
+            animation->start(QAbstractAnimation::DeleteWhenStopped);
 
             connect(animation, &QPropertyAnimation::finished, tab, [ = ] {
-                animation->deleteLater();
-
                 if (m_TabCloseButton->closingIndex() == counter)
                 {
                     m_TabCloseButton->setPos(tab->x() + tab->width() - 30, 6);
