@@ -60,10 +60,15 @@
 
 #define DESKTOP_BUTTON_ID "desktop"
 #define LOCK_SCREEN_BUTTON_ID "lock-screen"
+#define DESKTOP_AND_LOCKSCREEN_BUTTON_ID "desktop-lockscreen"
 #define SCREENSAVER_BUTTON_ID "screensaver"
 #define SessionManagerService "com.deepin.SessionManager"
 #define SessionManagerPath "/com/deepin/SessionManager"
 
+
+#define BUTTON_NARROW_WIDTH     79
+#define BUTTON_WIDE_WIDTH       164
+
 DWIDGET_USE_NAMESPACE
 DGUI_USE_NAMESPACE
 DCORE_USE_NAMESPACE
@@ -116,14 +121,12 @@ Frame::Frame(QString screenName, Mode mode, QWidget *parent)
     initUI();
     initSize();
 
-    connect(m_mouseArea, &DRegionMonitor::buttonPress, [this](const QPoint & p, const int button) {
+    connect(m_mouseArea, &DRegionMonitor::buttonPress, this, [this](const QPoint & p, const int button) {
         if (button == 4) {
             m_wallpaperList->prevPage();
         } else if (button == 5) {
             m_wallpaperList->nextPage();
         } else {
-            qDebug() << "button pressed on blank area, quit.";
-
             qreal scale = devicePixelRatioF();
             if(!ScreenHelper::screenManager()->screen(m_screenName)){
                 qCritical() << "lost screen " << m_screenName << "closed";
@@ -137,8 +140,11 @@ Frame::Frame(QString screenName, Mode mode, QWidget *parent)
             nativeRect.setSize(nativeRect.size() * scale);
 
             if (!nativeRect.contains(p)) {
+                qDebug() << "button pressed on blank area quit.";
                 hide();
             }
+
+            activateWindow();
         }
     });
 
@@ -188,6 +194,16 @@ Frame::~Frame()
         delete m_itemwait;
         m_itemwait = nullptr;
     }
+
+    if (m_toolLayout) {
+        delete m_toolLayout;
+        m_toolLayout = nullptr;
+    }
+
+    if (m_wallpaperCarouselLayout) {
+        delete m_wallpaperCarouselLayout;
+        m_wallpaperCarouselLayout = nullptr;
+    }
 }
 
 void Frame::show()
@@ -227,8 +243,6 @@ void Frame::show()
 
 void Frame::hide()
 {
-    emit aboutHide();
-
     DBlurEffectWidget::hide();
 }
 
@@ -255,7 +269,7 @@ void Frame::setMode(Frame::Mode mode)
 
 QPair<QString, QString> Frame::desktopBackground() const
 {
-    return QPair<QString, QString>(m_screenName, m_desktopWallpaper);
+    return QPair<QString, QString>(m_screenName, m_cureentWallpaper);
 }
 
 void Frame::handleNeedCloseButton(QString path, QPoint pos)
@@ -321,16 +335,9 @@ void Frame::hideEvent(QHideEvent *event)
     m_mouseArea->unregisterRegion();
 
     if (m_mode == WallpaperMode) {
-        if (!m_desktopWallpaper.isEmpty()){
-            setBackground();
-        }
-
-        else if (m_dbusDeepinWM)
+        if (!m_cureentWallpaper.isEmpty() && m_dbusDeepinWM)
             m_dbusDeepinWM->SetTransientBackground("");
 
-        if (!m_lockWallpaper.isEmpty())
-            m_dbusAppearance->Set("greeterbackground", m_lockWallpaper);
-
         if (ThumbnailManager *manager = ThumbnailManager::instance(devicePixelRatioF()))
             manager->stop();
     }
@@ -1018,8 +1025,9 @@ void Frame::refreshList()
                     WallpaperItem *item = m_wallpaperList->addWallpaper(path);
                     item->setData(item->getPath());
                     item->setDeletable(m_deletableInfo.value(path));
-                    item->addButton(DESKTOP_BUTTON_ID, tr("Only desktop"));
-                    item->addButton(LOCK_SCREEN_BUTTON_ID, tr("Only lock screen"));
+                    item->addButton(DESKTOP_BUTTON_ID, tr("Desktop","button"), BUTTON_NARROW_WIDTH, 0, 0, 1, 1);
+                    item->addButton(LOCK_SCREEN_BUTTON_ID, tr("Lock Screen","button"), BUTTON_NARROW_WIDTH, 0, 1, 1, 1);
+                    item->addButton(DESKTOP_AND_LOCKSCREEN_BUTTON_ID, tr("Both"), BUTTON_WIDE_WIDTH, 1, 0, 1, 2);
                     item->show();
                     connect(item, &WallpaperItem::buttonClicked, this, &Frame::onItemButtonClicked);
                     connect(item, &WallpaperItem::tab, this, [=](){
@@ -1050,10 +1058,6 @@ void Frame::refreshList()
                         return;
                     } else if (path.remove("file://") == currentPath.remove("file://")) { //均有机会出现头部为file:///概率
                         item->pressed();
-
-                        //清除item pressed设置的数据
-                        m_desktopWallpaper.clear();
-                        m_lockWallpaper.clear();
                     }
                 }
 
@@ -1071,6 +1075,7 @@ void Frame::refreshList()
         }
 
         const QStringList &saverNameList = m_dbusScreenSaver->allScreenSaver();
+        const QString &currentScreensaver = m_dbusScreenSaver->currentScreenSaver();
         if (saverNameList.isEmpty() && !m_dbusScreenSaver->isValid()) {
             qWarning() << "com.deepin.ScreenSaver allScreenSaver fail. retry";
             m_loadTimer.start(5000);
@@ -1085,18 +1090,19 @@ void Frame::refreshList()
             m_itemwait = nullptr;
         }
 
+        bool isPressed = false; //记录当前设置的屏保是否已被选中
         for (const QString &name : saverNameList) {
             if("flurry" == name){
                 continue;//临时屏蔽名字为flurry的屏保
             }
 
-            const QString &cover_path = m_dbusScreenSaver->GetScreenSaverCover(name);
+            const QString &coverPath = m_dbusScreenSaver->GetScreenSaverCover(name);
 
-            WallpaperItem *item = m_wallpaperList->addWallpaper(cover_path);
+            WallpaperItem *item = m_wallpaperList->addWallpaper(coverPath);
             item->setData(name);
             item->setUseThumbnailManager(false);
             item->setDeletable(false);
-            item->addButton(SCREENSAVER_BUTTON_ID, tr("Apply"));
+            item->addButton(SCREENSAVER_BUTTON_ID, tr("Apply","button"), BUTTON_WIDE_WIDTH, 0, 0, 1, 2);
             item->show();
             connect(item, &WallpaperItem::tab, this, [=]() {
                 if (m_mode == WallpaperMode) {
@@ -1110,10 +1116,15 @@ void Frame::refreshList()
             });
             connect(item, &WallpaperItem::buttonClicked, this, &Frame::onItemButtonClicked);
             //首次进入时，选中当前设置屏保
-            if(cover_path == m_dbusScreenSaver->GetScreenSaverCover(m_dbusScreenSaver->currentScreenSaver())) {
+            if(!isPressed && !name.isEmpty() && name == currentScreensaver) {
                 item->pressed();
+                isPressed = true;
             }
         }
+        if (!isPressed && m_wallpaperList->count() > 0) {
+            qWarning() << "no screen saver item selected,and select default 0.";
+            m_wallpaperList->setCurrentIndex(0);
+        }
 
         m_wallpaperList->setFixedWidth(width());
         m_wallpaperList->updateItemThumb();
@@ -1131,8 +1142,7 @@ void Frame::onItemPressed(const QString &data)
         if (m_backgroundManager)
             m_backgroundManager->setBackgroundImage(m_screenName, data);
 
-        m_desktopWallpaper = data;
-        m_lockWallpaper = data;
+        m_cureentWallpaper = data;
 
         // 点击当前壁纸不显示删除按钮
         if (m_closeButton && m_closeButton->isVisible()) {
@@ -1178,9 +1188,15 @@ void Frame::onItemButtonClicked(const QString &buttonID)
         return;
 
     if (buttonID == DESKTOP_BUTTON_ID) {
-        m_lockWallpaper.clear();
+        // 设置桌面
+        applyToDesktop();
     } else if (buttonID == LOCK_SCREEN_BUTTON_ID) {
-        m_desktopWallpaper.clear();
+        // 设置锁屏
+        applyToGreeter();
+    } else if (buttonID == DESKTOP_AND_LOCKSCREEN_BUTTON_ID) {
+        // 同时设置桌面和锁屏
+        applyToDesktop();
+        applyToGreeter();
     }
 #ifndef DISABLE_SCREENSAVER
     else if (buttonID == SCREENSAVER_BUTTON_ID) {
@@ -1211,7 +1227,7 @@ QStringList Frame::processListReply(const QString &reply)
 
 QString Frame::getWallpaperSlideShow()
 {
-    if(nullptr == m_dbusAppearance) {
+    if (nullptr == m_dbusAppearance) {
         qWarning() << "m_dbusAppearance is nullptr";
         return QString();
     }
@@ -1223,7 +1239,7 @@ QString Frame::getWallpaperSlideShow()
 
 void Frame::setWallpaperSlideShow(QString slideShow)
 {
-    if(nullptr == m_dbusAppearance) {
+    if (nullptr == m_dbusAppearance) {
         qWarning() << "m_dbusAppearance is nullptr";
         return;
     }
@@ -1232,13 +1248,36 @@ void Frame::setWallpaperSlideShow(QString slideShow)
     m_dbusAppearance->SetWallpaperSlideShow(m_screenName, slideShow);
 }
 
-void Frame::setBackground()
+void Frame::applyToDesktop()
 {
-    if(nullptr == m_dbusAppearance) {
+    if (nullptr == m_dbusAppearance) {
         qWarning() << "m_dbusAppearance is nullptr";
         return;
     }
 
-    qInfo() << "dbus Appearance SetMonitorBackground is called " << m_screenName << " " << m_desktopWallpaper;
-    m_dbusAppearance->SetMonitorBackground(m_screenName, m_desktopWallpaper);
+    if (m_cureentWallpaper.isEmpty()) {
+        qWarning() << "cureentWallpaper is empty";
+        return;
+    }
+
+    qInfo() << "dbus Appearance SetMonitorBackground is called " << m_screenName << " " << m_cureentWallpaper;
+    m_dbusAppearance->SetMonitorBackground(m_screenName, m_cureentWallpaper);
+
+    emit backgroundChanged();
+}
+
+void Frame::applyToGreeter()
+{
+    if (nullptr == m_dbusAppearance) {
+        qWarning() << "m_dbusAppearance is nullptr";
+        return;
+    }
+
+    if (m_cureentWallpaper.isEmpty()) {
+        qWarning() << "cureentWallpaper is empty";
+        return;
+    }
+
+    qInfo() << "dbus Appearance greeterbackground is called " << m_cureentWallpaper;
+    m_dbusAppearance->Set("greeterbackground", m_cureentWallpaper);
 }
