@@ -81,14 +81,6 @@ DFileCopyMoveJob::Action ErrorHandle::handleError(DFileCopyMoveJob *job, DFileCo
         emit job->currentJobChanged(fromUrl, toUrl, true);
     }
     break;
-    case DFileCopyMoveJob::UnknowUrlError: {
-        DDialog dialog("Error", QCoreApplication::translate("DTaskDialog", "This action is not supported"));
-        dialog.setIcon(QIcon::fromTheme("dialog-error"));
-        dialog.exec();
-    }
-    // fall-through
-    case DFileCopyMoveJob::UnknowError:
-        return DFileCopyMoveJob::CancelAction;
     default:
         DUrl fromUrl = sourceInfo ? sourceInfo->fileUrl() : DUrl();
         DUrl toUrl = targetInfo ? targetInfo->fileUrl() : DUrl();
@@ -556,7 +548,8 @@ DFileCopyMoveJob::Handle *DTaskDialog::addTaskJob(DFileCopyMoveJob *job, const b
                 bool supprotRetry = job->supportActions(job->error()).testFlag(DFileCopyMoveJob::RetryAction);
                 data["supprotRetry"] = supprotRetry ? "true" : "false";
                 data["errorMsg"] = job->errorString();
-                qInfo() << "dfilecopymovejob error and errorMsg = " << job->errorString();
+                if (job->error() != DFileCopyMoveJob::CancelError)
+                    qInfo() << "dfilecopymovejob error and errorMsg = " << job->errorString();
             }
         }
 
@@ -580,7 +573,7 @@ DFileCopyMoveJob::Handle *DTaskDialog::addTaskJob(DFileCopyMoveJob *job, const b
                 emit closed();
             }
         }
-    });
+    }, Qt::QueuedConnection);
     connect(job, &DFileCopyMoveJob::errorChanged, wid, [wid](DFileCopyMoveJob::Error error) {
         wid->getButton(DFMTaskWidget::PAUSE)->setEnabled(error == DFileCopyMoveJob::NoError);
     }, Qt::QueuedConnection);
@@ -613,6 +606,8 @@ DFileCopyMoveJob::Handle *DTaskDialog::addTaskJob(DFileCopyMoveJob *job, const b
         }
     }
 
+    showDialogOnTop();
+
     return handle;
 }
 void DTaskDialog::adjustSize()
@@ -708,7 +703,7 @@ void DTaskDialog::removeTaskImmediately(const QMap<QString, QString> &jobDetail)
 
 void DTaskDialog::delayRemoveTask(const QMap<QString, QString> &jobDetail)
 {
-    QTimer::singleShot(2000, this, [ = ]() {
+    QTimer::singleShot(1500, this, [ = ]() {
         removeTask(jobDetail);
     });
 }
@@ -821,10 +816,10 @@ void DTaskDialog::updateData(DFMTaskWidget *wid, const QMap<QString, QString> &d
 
             if (QFileInfo(srcPath).isDir() &&
                     QFileInfo(targetPath).isDir()) {
-                wid->setButtonText(DFMTaskWidget::REPLACE, tr("Merge"));
+                wid->setButtonText(DFMTaskWidget::REPLACE, tr("Merge","button"));
 
             } else {
-                wid->setButtonText(DFMTaskWidget::REPLACE, tr("Replace"));
+                wid->setButtonText(DFMTaskWidget::REPLACE, tr("Replace","button"));
             }
         } else if (status == "error") {
             QString supprotRetry = data.value("supprotRetry"); // 这个需要新加字段
@@ -858,6 +853,7 @@ bool DTaskDialog::haveNotCompletedVaultTask()
 
 void DTaskDialog::showDialogOnTop()
 {
+    this->show();
     this->activateWindow();
     dialogManager->taskDialog()->showNormal();
 }
