@@ -48,6 +48,7 @@
 #include "app/define.h"
 #include "app/filesignalmanager.h"
 #include "dialogs/dialogmanager.h"
+#include "shutil/fileutils.h"
 #include "ddialog.h"
 
 DWIDGET_USE_NAMESPACE
@@ -125,7 +126,8 @@ ShareInfo UserShareManager::getShareInfoByPath(const QString &path) const
 
 ShareInfo UserShareManager::getsShareInfoByShareName(const QString &shareName) const
 {
-    return m_shareInfos.value(shareName);
+    std::string stdStr = shareName.toStdString();
+    return m_shareInfos.value(QUrl::fromPercentEncoding(stdStr.data()));
 }
 
 QString UserShareManager::getShareNameByPath(const QString &path) const
@@ -186,6 +188,20 @@ void UserShareManager::updateFileAttributeInfo(const QString &filePath) const
     DAbstractFileWatcher::ghostSignal(fileInfo->parentUrl(), &DAbstractFileWatcher::fileAttributeChanged, fileUrl);
 }
 
+void UserShareManager::startSambaServiceAsync()
+{
+    QDBusInterface interface("org.freedesktop.systemd1",
+                             "/org/freedesktop/systemd1/unit/smbd_2eservice",
+                             "org.freedesktop.systemd1.Unit",
+                             QDBusConnection::systemBus());
+
+    QDBusPendingCall pcall = interface.asyncCall(QLatin1String("Start"), QString("replace"));
+
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(pcall, this);
+
+    QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, &UserShareManager::callFinishedSlot);
+}
+
 void UserShareManager::writeCacheToFile(const QString &path, const QString &content)
 {
     QFile file(path);
@@ -301,7 +317,7 @@ void UserShareManager::updateUserShareInfo(bool sendSignal)
                 info.insert(key, value);
             }
         }
-        QString shareName = info.value("sharename");
+        QString shareName = info.value("sharename").toLower();
         QString sharePath = info.value("path");
         QString share_acl = info.value("usershare_acl");
         if (!shareName.isEmpty() &&
@@ -376,6 +392,13 @@ void UserShareManager::setSambaPassword(const QString &userName, const QString &
 
 bool UserShareManager::addUserShare(const ShareInfo &info)
 {
+    if (!FileUtils::isSambaServiceRunning()) {
+        m_currentInfo = info;
+        startSambaServiceAsync();
+
+        return false;
+    }
+
     // check if we got `net` (in `samba-common-bin` package) installed
     QString samba_common_bin_path = QStandardPaths::findExecutable("net");
     if (samba_common_bin_path.isEmpty()) {
@@ -387,6 +410,11 @@ bool UserShareManager::addUserShare(const ShareInfo &info)
     ShareInfo oldInfo = getOldShareInfoByNewInfo(info);
     qDebug() << oldInfo << info;
     if (!info.shareName().isEmpty() && QFile(info.path()).exists()) {
+        // 共享文件的共享名不能以-开头
+        if (info.shareName().startsWith("-") || info.shareName().endsWith(" ")) {
+            dialogManager->showErrorDialog(tr("The share name must not contain %1, and cannot start with a dash (-) or whitespace, or end with whitespace.").arg("%<>*?|/\\+=;:,\""), "");
+            return false;
+        }
         QString cmd = "net";
         QStringList args;
         ShareInfo _info = info;
@@ -422,7 +450,7 @@ bool UserShareManager::addUserShare(const ShareInfo &info)
 
             // 共享文件的共享名输入特殊字符会报这个错误信息
             if (err.contains("contains invalid characters")) {
-                dialogManager->showErrorDialog(tr("The share name must not contain %<>*?|/\\+=;:,\""), "");
+                dialogManager->showErrorDialog(tr("The share name must not contain %1, and cannot start with a dash (-) or whitespace, or end with whitespace.").arg("%<>*?|/\\+=;:,\""), "");
                 return false;
             }
 
@@ -444,6 +472,7 @@ bool UserShareManager::addUserShare(const ShareInfo &info)
             }
 
             qWarning() << err << "err code = " << QString::number(process.exitCode());
+
             dialogManager->showErrorDialog(QString(), err);
             return false;
         }
@@ -494,6 +523,33 @@ void UserShareManager::usershareCountchanged()
     emit userShareCountChanged(count);
 }
 
+void UserShareManager::callFinishedSlot(QDBusPendingCallWatcher *watcher)
+{
+    QObject::disconnect(watcher, &QDBusPendingCallWatcher::finished, this, &UserShareManager::callFinishedSlot);
+
+    QDBusPendingReply<> reply = *watcher;
+    watcher->deleteLater();
+    if (reply.isValid()) {
+        const QString &errorMsg = reply.reply().errorMessage();
+        if (errorMsg.isEmpty()) {
+            qDebug() << "smbd service start success";
+
+            // 自启动
+            // 这里创建链接文件 以便下次开机自启
+            QDBusReply<bool> reply = m_userShareInterface->createShareLinkFile();
+            if (reply.isValid()) {
+                qDebug() << "set usershare password:" << reply.value();
+                if(reply.value())
+                    addUserShare(m_currentInfo);
+            } else {
+                qDebug() << "set usershare password:" << reply.error();
+            }
+        }
+    } else {
+        dialogManager->showErrorDialog(QString(), QObject::tr("Failed to start Samba services"));
+    }
+}
+
 void UserShareManager::deleteUserShareByShareName(const QString &shareName)
 {
     QDBusReply<bool> reply = m_userShareInterface->closeSmbShareByShareName(shareName, true);
