@@ -14,6 +14,7 @@
 #include <QDialog>
 #include <QVariant>
 #include <ddiskdevice.h>
+#include <QApplication>
 
 #include <ddiskmanager.h>
 #include <dblockdevice.h>
@@ -22,6 +23,7 @@
 #include "ddialog.h"
 #define private public
 #define protected public
+#include "views/dtagedit.h"
 #include "tag/tagmanager.h"
 #include "testhelper.h"
 #include "stub.h"
@@ -37,6 +39,7 @@
 #include "gvfs/secretmanager.h"
 #include "controllers/appcontroller.h"
 #include "interfaces/dumountmanager.h"
+#include "utils.h"
 
 DFM_USE_NAMESPACE
 
@@ -542,9 +545,9 @@ TEST_F(AppControllerTest,start_actionBookmarkandother){
     EXPECT_NO_FATAL_FAILURE(controller->actionSendToBluetooth());
     QAction action;
     action.connect(&action,&QAction::triggered,controller,&AppController::actionSendToBluetooth);
-    emit action.triggered();
     void (*sendToBluetoothlamda)(const DUrlList &) = [](const DUrlList &){};
     stl.set(ADDR(DFileService,sendToBluetooth),sendToBluetoothlamda);
+    emit action.triggered();
     EXPECT_NO_FATAL_FAILURE(controller->actionSendToBluetooth());
     bool (*deleteFileslamda)(const QObject *, const DUrlList &, bool, bool, bool) = []
             (const QObject *, const DUrlList &, bool, bool, bool){
@@ -995,7 +998,32 @@ TEST_F(AppControllerTest, start_actionGetTagsThroughFiles){
     };
     stl.set(ADDR(TagManager,getColorNameByColor),getColorNameByColorlamda);
     controller->actionChangeTagColor(dMakeEventPointer<DFMChangeTagColorEvent>(nullptr,Qt::red, url));
+
+    stub_ext::StubExt stub; //在不影响原有覆盖率下打桩
+    stub.set_lamda(&AppController::showTagEdit, [=](){
+        QRect parentRect(0,0,0,0);
+        QPoint globalPos(0,0);
+        DUrlList fileList{url};
+        DTagEdit *tagEdit = new DTagEdit();
+        auto subValue = parentRect.height() - globalPos.y();
+        if (subValue < 98) {
+            tagEdit->setArrowDirection(DArrowRectangle::ArrowDirection::ArrowBottom);
+        }
+        tagEdit->setBaseSize(160, 98);
+        tagEdit->setFilesForTagging(fileList);
+        tagEdit->setFocusOutSelfClosing(true);
+        QList<QString> sameTagsInDiffFiles{ DFileService::instance()->getTagsThroughFiles(nullptr, fileList) };
+        tagEdit->setDefaultCrumbs(sameTagsInDiffFiles);
+        tagEdit->show(globalPos.x(), globalPos.y());
+        tagEdit->close();
+        if (tagEdit) {
+            delete tagEdit;
+            tagEdit = nullptr;
+        }
+    });
+
     controller->showTagEdit(QRect(0,0,0,0),QPoint(0,0),DUrlList() << url);
+    QApplication::closeAllWindows();
 }
 
 TEST_F(AppControllerTest, start_doSubscriberAction){
@@ -1037,3 +1065,19 @@ TEST_F(AppControllerTest, start_showErrorDialog){
     TestHelper::runInLoop([=](){
     });
 }
+
+TEST_F(AppControllerTest, start_actionRemoveStashedMount) {
+    RemoteMountsStashManager::stashRemoteMount("/run/user/1000/gvfs/smb-share:server=1.2.3.4,share=test", "test");
+
+    auto e = dMakeEventPointer<DFMUrlBaseEvent>(nullptr, DUrl("dfmroot:///smb://1.2.3.4/test.remote"));
+    EXPECT_NO_FATAL_FAILURE(controller->actionRemoveStashedMount(e));
+
+    // cover RemoteMountsStashManager
+    RemoteMountsStashManager::stashRemoteMount("/run/user/1000/gvfs/smb-share:server=1.2.3.4,share=test", "test");
+    auto mounts = RemoteMountsStashManager::remoteMounts();
+    EXPECT_TRUE(1 == mounts.size());
+    EXPECT_TRUE("test" == RemoteMountsStashManager::getDisplayNameByConnUrl("smb://1.2.3.4/test"));
+    EXPECT_TRUE("smb://1.2.3.4/test" == RemoteMountsStashManager::normalizeConnUrl("/smb://1.2.3.4/test.remote"));
+    EXPECT_NO_FATAL_FAILURE(RemoteMountsStashManager::clearRemoteMounts());
+    EXPECT_NO_FATAL_FAILURE(RemoteMountsStashManager::stashCurrentMounts());
+}
