@@ -20,6 +20,8 @@
 #include <QSharedPointer>
 #include <QTimer>
 #include <QDirIterator>
+#include <QDialog>
+#include <DDialog>
 
 #include "stub.h"
 #include "../stub-ext/stubext.h"
@@ -475,33 +477,22 @@ TEST_F(TestVaultController, tst_renameFile)
 
     QString cmdTouch = QString("touch ") + testFile;
     QString cmdRm = QString("rm ") + testFile + " " + testRenameFile;
-
     QProcess::execute(cmdTouch);
 
+    Stub stl;
+    typedef int(*fptr)(QDialog*);
+    fptr pQDialogExec = (fptr)(&QDialog::exec);
+    fptr pDDialogExec = (fptr)(&Dtk::Widget::DDialog::exec);
+    int (*stub_DDialog_exec)(void) = [](void)->int{return QDialog::Accepted;};
+    stl.set(pQDialogExec, stub_DDialog_exec);
+    stl.set(pDDialogExec, stub_DDialog_exec);
+
     QSharedPointer<DFMRenameEvent> event = dMakeEventPointer<DFMRenameEvent>(nullptr, testFile, testRenameFile);
     m_controller->renameFile(event);
 
     QProcess::execute(cmdRm);
 }
 
-TEST_F(TestVaultController, tst_share_unshare_Folder)
-{
-    QString testFile = DFMStandardPaths::location(DFMStandardPaths::PicturesPath) + "/utFile";
-
-    QString cmdTouch = QString("touch ") + testFile;
-    QString cmdRm = QString("rm ") + testFile;
-
-    QProcess::execute(cmdTouch);
-
-    QSharedPointer<DFMFileShareEvent> event = dMakeEventPointer<DFMFileShareEvent>(nullptr, testFile, "utFile");
-    EXPECT_FALSE(m_controller->shareFolder(event));
-
-    QSharedPointer<DFMCancelFileShareEvent> cancelEvent = dMakeEventPointer<DFMCancelFileShareEvent>(nullptr, testFile);
-    EXPECT_TRUE(m_controller->unShareFolder(cancelEvent));
-
-    QProcess::execute(cmdRm);
-}
-
 TEST_F(TestVaultController, tst_openTerminal)
 {
     QString testFile = DFMStandardPaths::location(DFMStandardPaths::PicturesPath) + "/utFile";
