@@ -69,7 +69,6 @@ public:
             m_manager->startMonitor();
             inited = true;
         }
-        gioError.message = strdup("123");
 
     }
 
@@ -77,7 +76,6 @@ public:
     {
     }
 
-    GError gioError;
     char errBuffer[2];
 };
 }
@@ -558,7 +556,9 @@ TEST_F(TestGvfsMountManager, mount_device)
                     GError                    **error)->GMount*{
 
         GMount* mt = get_fisrt_usable_mount();
-        *error = &(this->gioError);
+        GError *gerror = g_slice_new(GError);
+        gerror->message = g_strdup("123");
+        *error = gerror;
         return mt;
     });
 
@@ -621,7 +621,9 @@ TEST_F(TestGvfsMountManager, eject_mounted)
 
         GMount* mt = get_fisrt_usable_mount();
 
-        *error = &(this->gioError);
+        GError *gerror = g_slice_new(GError);
+        gerror->message = g_strdup("123");
+        *error = gerror;
         return mt;
     });
 
@@ -908,7 +910,7 @@ TEST_F(TestGvfsMountManager, stop_with_device_file_cb)
     GvfsMountManager::stop_with_device_file_cb(object, res, user_data);
     stub.reset(g_mount_unmount_with_operation_finish);
 }
-
+#ifndef __arm__
 TEST_F(TestGvfsMountManager, initConnect)
 {
     stub_ext::StubExt stu;
@@ -916,3 +918,4 @@ TEST_F(TestGvfsMountManager, initConnect)
     m_manager->initConnect();
     stu.reset(&DFMGlobal::isRootUser);
 }
+#endif
